html_content = '''<!doctype html>
<html lang="en">
  <head>
    <meta charset="UTF-8" />
    <link rel="icon" type="image/svg+xml" href="/vanna.svg" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <link href="https://fonts.googleapis.com/css2?family=Roboto+Slab:wght@350&display=swap" rel="stylesheet">
    <script src="https://cdn.plot.ly/plotly-latest.min.js" type="text/javascript"></script>
    <title>Vanna.AI</title>
    <script type="module" crossorigin src="/assets/index-3e6e2a81.js"></script>
    <link rel="stylesheet" href="/assets/index-6f848993.css">
  </head>
  <body class="bg-white dark:bg-slate-900">
    <div id="app"></div>
    
  </body>
</html>
'''

css_content = '''.nav-title{font-family:Roboto Slab,serif}*,:before,:after{box-sizing:border-box;border-width:0;border-style:solid;border-color:#e5e7eb}:before,:after{--tw-content: ""}html{line-height:1.5;-webkit-text-size-adjust:100%;-moz-tab-size:4;-o-tab-size:4;tab-size:4;font-family:ui-sans-serif,system-ui,-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Helvetica Neue,Arial,Noto Sans,sans-serif,"Apple Color Emoji","Segoe UI Emoji",Segoe UI Symbol,"Noto Color Emoji";font-feature-settings:normal;font-variation-settings:normal}body{margin:0;line-height:inherit}hr{height:0;color:inherit;border-top-width:1px}abbr:where([title]){-webkit-text-decoration:underline dotted;text-decoration:underline dotted}h1,h2,h3,h4,h5,h6{font-size:inherit;font-weight:inherit}a{color:inherit;text-decoration:inherit}b,strong{font-weight:bolder}code,kbd,samp,pre{font-family:ui-monospace,SFMono-Regular,Menlo,Monaco,Consolas,Liberation Mono,Courier New,monospace;font-size:1em}small{font-size:80%}sub,sup{font-size:75%;line-height:0;position:relative;vertical-align:baseline}sub{bottom:-.25em}sup{top:-.5em}table{text-indent:0;border-color:inherit;border-collapse:collapse}button,input,optgroup,select,textarea{font-family:inherit;font-feature-settings:inherit;font-variation-settings:inherit;font-size:100%;font-weight:inherit;line-height:inherit;color:inherit;margin:0;padding:0}button,select{text-transform:none}button,[type=button],[type=reset],[type=submit]{-webkit-appearance:button;background-color:transparent;background-image:none}:-moz-focusring{outline:auto}:-moz-ui-invalid{box-shadow:none}progress{vertical-align:baseline}::-webkit-inner-spin-button,::-webkit-outer-spin-button{height:auto}[type=search]{-webkit-appearance:textfield;outline-offset:-2px}::-webkit-search-decoration{-webkit-appearance:none}::-webkit-file-upload-button{-webkit-appearance:button;font:inherit}summary{display:list-item}blockquote,dl,dd,h1,h2,h3,h4,h5,h6,hr,figure,p,pre{margin:0}fieldset{margin:0;padding:0}legend{padding:0}ol,ul,menu{list-style:none;margin:0;padding:0}dialog{padding:0}textarea{resize:vertical}input::-moz-placeholder,textarea::-moz-placeholder{opacity:1;color:#9ca3af}input::placeholder,textarea::placeholder{opacity:1;color:#9ca3af}button,[role=button]{cursor:pointer}:disabled{cursor:default}img,svg,video,canvas,audio,iframe,embed,object{display:block;vertical-align:middle}img,video{max-width:100%;height:auto}[hidden]{display:none}*,:before,:after{--tw-border-spacing-x: 0;--tw-border-spacing-y: 0;--tw-translate-x: 0;--tw-translate-y: 0;--tw-rotate: 0;--tw-skew-x: 0;--tw-skew-y: 0;--tw-scale-x: 1;--tw-scale-y: 1;--tw-pan-x: ;--tw-pan-y: ;--tw-pinch-zoom: ;--tw-scroll-snap-strictness: proximity;--tw-gradient-from-position: ;--tw-gradient-via-position: ;--tw-gradient-to-position: ;--tw-ordinal: ;--tw-slashed-zero: ;--tw-numeric-figure: ;--tw-numeric-spacing: ;--tw-numeric-fraction: ;--tw-ring-inset: ;--tw-ring-offset-width: 0px;--tw-ring-offset-color: #fff;--tw-ring-color: rgb(59 130 246 / .5);--tw-ring-offset-shadow: 0 0 #0000;--tw-ring-shadow: 0 0 #0000;--tw-shadow: 0 0 #0000;--tw-shadow-colored: 0 0 #0000;--tw-blur: ;--tw-brightness: ;--tw-contrast: ;--tw-grayscale: ;--tw-hue-rotate: ;--tw-invert: ;--tw-saturate: ;--tw-sepia: ;--tw-drop-shadow: ;--tw-backdrop-blur: ;--tw-backdrop-brightness: ;--tw-backdrop-contrast: ;--tw-backdrop-grayscale: ;--tw-backdrop-hue-rotate: ;--tw-backdrop-invert: ;--tw-backdrop-opacity: ;--tw-backdrop-saturate: ;--tw-backdrop-sepia: }::backdrop{--tw-border-spacing-x: 0;--tw-border-spacing-y: 0;--tw-translate-x: 0;--tw-translate-y: 0;--tw-rotate: 0;--tw-skew-x: 0;--tw-skew-y: 0;--tw-scale-x: 1;--tw-scale-y: 1;--tw-pan-x: ;--tw-pan-y: ;--tw-pinch-zoom: ;--tw-scroll-snap-strictness: proximity;--tw-gradient-from-position: ;--tw-gradient-via-position: ;--tw-gradient-to-position: ;--tw-ordinal: ;--tw-slashed-zero: ;--tw-numeric-figure: ;--tw-numeric-spacing: ;--tw-numeric-fraction: ;--tw-ring-inset: ;--tw-ring-offset-width: 0px;--tw-ring-offset-color: #fff;--tw-ring-color: rgb(59 130 246 / .5);--tw-ring-offset-shadow: 0 0 #0000;--tw-ring-shadow: 0 0 #0000;--tw-shadow: 0 0 #0000;--tw-shadow-colored: 0 0 #0000;--tw-blur: ;--tw-brightness: ;--tw-contrast: ;--tw-grayscale: ;--tw-hue-rotate: ;--tw-invert: ;--tw-saturate: ;--tw-sepia: ;--tw-drop-shadow: ;--tw-backdrop-blur: ;--tw-backdrop-brightness: ;--tw-backdrop-contrast: ;--tw-backdrop-grayscale: ;--tw-backdrop-hue-rotate: ;--tw-backdrop-invert: ;--tw-backdrop-opacity: ;--tw-backdrop-saturate: ;--tw-backdrop-sepia: }.sr-only{position:absolute;width:1px;height:1px;padding:0;margin:-1px;overflow:hidden;clip:rect(0,0,0,0);white-space:nowrap;border-width:0}.collapse{visibility:collapse}.static{position:static}.fixed{position:fixed}.absolute{position:absolute}.relative{position:relative}.sticky{position:sticky}.inset-0{top:0;right:0;bottom:0;left:0}.inset-x-px{left:1px;right:1px}.bottom-0{bottom:0}.bottom-px{bottom:1px}.left-0{left:0}.top-0{top:0}.z-10{z-index:10}.z-50{z-index:50}.z-\[60\]{z-index:60}.-m-1{margin:-.25rem}.-m-1\.5{margin:-.375rem}.m-3{margin:.75rem}.mx-auto{margin-left:auto;margin-right:auto}.mb-1{margin-bottom:.25rem}.mb-2{margin-bottom:.5rem}.mb-2\.5{margin-bottom:.625rem}.mb-auto{margin-bottom:auto}.ml-3{margin-left:.75rem}.ml-4{margin-left:1rem}.mr-1{margin-right:.25rem}.mr-1\.5{margin-right:.375rem}.mr-3{margin-right:.75rem}.mt-0{margin-top:0}.mt-0\.5{margin-top:.125rem}.mt-1{margin-top:.25rem}.mt-16{margin-top:4rem}.mt-2{margin-top:.5rem}.mt-3{margin-top:.75rem}.mt-5{margin-top:1.25rem}.mt-6{margin-top:1.5rem}.mt-auto{margin-top:auto}.block{display:block}.inline-block{display:inline-block}.inline{display:inline}.flex{display:flex}.inline-flex{display:inline-flex}.table{display:table}.grid{display:grid}.hidden{display:none}.h-1{height:.25rem}.h-1\.5{height:.375rem}.h-3{height:.75rem}.h-3\.5{height:.875rem}.h-4{height:1rem}.h-5{height:1.25rem}.h-6{height:1.5rem}.h-7{height:1.75rem}.h-8{height:2rem}.h-\[2\.375rem\]{height:2.375rem}.h-auto{height:auto}.h-full{height:100%}.h-px{height:1px}.h-screen{height:100vh}.min-h-\[15rem\]{min-height:15rem}.min-h-\[calc\(100\%-3\.5rem\)\]{min-height:calc(100% - 3.5rem)}.w-0{width:0px}.w-1{width:.25rem}.w-1\.5{width:.375rem}.w-28{width:7rem}.w-3{width:.75rem}.w-3\.5{width:.875rem}.w-4{width:1rem}.w-6{width:1.5rem}.w-64{width:16rem}.w-8{width:2rem}.w-\[2\.375rem\]{width:2.375rem}.w-\[3\.25rem\]{width:3.25rem}.w-full{width:100%}.w-px{width:1px}.min-w-full{min-width:100%}.max-w-2xl{max-width:42rem}.max-w-4xl{max-width:56rem}.max-w-7xl{max-width:80rem}.max-w-\[50rem\]{max-width:50rem}.max-w-\[85rem\]{max-width:85rem}.max-w-sm{max-width:24rem}.flex-1{flex:1 1 0%}.flex-auto{flex:1 1 auto}.flex-none{flex:none}.flex-shrink-0,.shrink-0{flex-shrink:0}.grow{flex-grow:1}.-translate-x-full{--tw-translate-x: -100%;transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skew(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.transform{transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skew(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}@keyframes bounce{0%,to{transform:translateY(-25%);animation-timing-function:cubic-bezier(.8,0,1,1)}50%{transform:none;animation-timing-function:cubic-bezier(0,0,.2,1)}}.animate-bounce{animation:bounce 1s infinite}@keyframes ping{75%,to{transform:scale(2);opacity:0}}.animate-ping{animation:ping 1s cubic-bezier(0,0,.2,1) infinite}@keyframes pulse{50%{opacity:.5}}.animate-pulse{animation:pulse 2s cubic-bezier(.4,0,.6,1) infinite}@keyframes spin{to{transform:rotate(360deg)}}.animate-spin{animation:spin 1s linear infinite}.cursor-pointer{cursor:pointer}.resize{resize:both}.appearance-none{-webkit-appearance:none;-moz-appearance:none;appearance:none}.flex-col{flex-direction:column}.items-start{align-items:flex-start}.items-center{align-items:center}.justify-end{justify-content:flex-end}.justify-center{justify-content:center}.justify-between{justify-content:space-between}.gap-1{gap:.25rem}.gap-1\.5{gap:.375rem}.gap-2{gap:.5rem}.gap-3{gap:.75rem}.gap-x-1{-moz-column-gap:.25rem;column-gap:.25rem}.gap-x-2{-moz-column-gap:.5rem;column-gap:.5rem}.gap-x-3{-moz-column-gap:.75rem;column-gap:.75rem}.-space-y-px>:not([hidden])~:not([hidden]){--tw-space-y-reverse: 0;margin-top:calc(-1px * calc(1 - var(--tw-space-y-reverse)));margin-bottom:calc(-1px * var(--tw-space-y-reverse))}.space-y-1>:not([hidden])~:not([hidden]){--tw-space-y-reverse: 0;margin-top:calc(.25rem * calc(1 - var(--tw-space-y-reverse)));margin-bottom:calc(.25rem * var(--tw-space-y-reverse))}.space-y-1\.5>:not([hidden])~:not([hidden]){--tw-space-y-reverse: 0;margin-top:calc(.375rem * calc(1 - var(--tw-space-y-reverse)));margin-bottom:calc(.375rem * var(--tw-space-y-reverse))}.space-y-3>:not([hidden])~:not([hidden]){--tw-space-y-reverse: 0;margin-top:calc(.75rem * calc(1 - var(--tw-space-y-reverse)));margin-bottom:calc(.75rem * var(--tw-space-y-reverse))}.space-y-5>:not([hidden])~:not([hidden]){--tw-space-y-reverse: 0;margin-top:calc(1.25rem * calc(1 - var(--tw-space-y-reverse)));margin-bottom:calc(1.25rem * var(--tw-space-y-reverse))}.divide-y>:not([hidden])~:not([hidden]){--tw-divide-y-reverse: 0;border-top-width:calc(1px * calc(1 - var(--tw-divide-y-reverse)));border-bottom-width:calc(1px * var(--tw-divide-y-reverse))}.divide-gray-200>:not([hidden])~:not([hidden]){--tw-divide-opacity: 1;border-color:rgb(229 231 235 / var(--tw-divide-opacity))}.overflow-hidden{overflow:hidden}.overflow-x-auto{overflow-x:auto}.overflow-y-auto{overflow-y:auto}.overflow-x-hidden{overflow-x:hidden}.overflow-y-hidden{overflow-y:hidden}.truncate{overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.whitespace-nowrap{white-space:nowrap}.whitespace-pre-wrap{white-space:pre-wrap}.whitespace-break-spaces{white-space:break-spaces}.rounded-full{border-radius:9999px}.rounded-lg{border-radius:.5rem}.rounded-md{border-radius:.375rem}.rounded-xl{border-radius:.75rem}.rounded-b-md{border-bottom-right-radius:.375rem;border-bottom-left-radius:.375rem}.border{border-width:1px}.border-2{border-width:2px}.border-\[3px\]{border-width:3px}.border-b{border-bottom-width:1px}.border-r{border-right-width:1px}.border-t{border-top-width:1px}.border-blue-600{--tw-border-opacity: 1;border-color:rgb(37 99 235 / var(--tw-border-opacity))}.border-current{border-color:currentColor}.border-gray-200{--tw-border-opacity: 1;border-color:rgb(229 231 235 / var(--tw-border-opacity))}.border-gray-300{--tw-border-opacity: 1;border-color:rgb(209 213 219 / var(--tw-border-opacity))}.border-green-200{--tw-border-opacity: 1;border-color:rgb(187 247 208 / var(--tw-border-opacity))}.border-red-200{--tw-border-opacity: 1;border-color:rgb(254 202 202 / var(--tw-border-opacity))}.border-transparent{border-color:transparent}.border-yellow-200{--tw-border-opacity: 1;border-color:rgb(254 240 138 / var(--tw-border-opacity))}.border-t-transparent{border-top-color:transparent}.bg-blue-500{--tw-bg-opacity: 1;background-color:rgb(59 130 246 / var(--tw-bg-opacity))}.bg-blue-600{--tw-bg-opacity: 1;background-color:rgb(37 99 235 / var(--tw-bg-opacity))}.bg-gray-100{--tw-bg-opacity: 1;background-color:rgb(243 244 246 / var(--tw-bg-opacity))}.bg-gray-50{--tw-bg-opacity: 1;background-color:rgb(249 250 251 / var(--tw-bg-opacity))}.bg-gray-600{--tw-bg-opacity: 1;background-color:rgb(75 85 99 / var(--tw-bg-opacity))}.bg-gray-900{--tw-bg-opacity: 1;background-color:rgb(17 24 39 / var(--tw-bg-opacity))}.bg-green-600{--tw-bg-opacity: 1;background-color:rgb(22 163 74 / var(--tw-bg-opacity))}.bg-white{--tw-bg-opacity: 1;background-color:rgb(255 255 255 / var(--tw-bg-opacity))}.bg-yellow-50{--tw-bg-opacity: 1;background-color:rgb(254 252 232 / var(--tw-bg-opacity))}.bg-opacity-50{--tw-bg-opacity: .5}.p-1{padding:.25rem}.p-1\.5{padding:.375rem}.p-2{padding:.5rem}.p-2\.5{padding:.625rem}.p-3{padding:.75rem}.p-4{padding:1rem}.px-3{padding-left:.75rem;padding-right:.75rem}.px-4{padding-left:1rem;padding-right:1rem}.px-6{padding-left:1.5rem;padding-right:1.5rem}.px-7{padding-left:1.75rem;padding-right:1.75rem}.py-10{padding-top:2.5rem;padding-bottom:2.5rem}.py-2{padding-top:.5rem;padding-bottom:.5rem}.py-2\.5{padding-top:.625rem;padding-bottom:.625rem}.py-3{padding-top:.75rem;padding-bottom:.75rem}.py-4{padding-top:1rem;padding-bottom:1rem}.py-5{padding-top:1.25rem;padding-bottom:1.25rem}.pb-12{padding-bottom:3rem}.pl-7{padding-left:1.75rem}.pr-4{padding-right:1rem}.pr-9{padding-right:2.25rem}.text-left{text-align:left}.text-center{text-align:center}.text-start{text-align:start}.align-middle{vertical-align:middle}.font-mono{font-family:ui-monospace,SFMono-Regular,Menlo,Monaco,Consolas,Liberation Mono,Courier New,monospace}.text-2xl{font-size:1.5rem;line-height:2rem}.text-3xl{font-size:1.875rem;line-height:2.25rem}.text-7xl{font-size:4.5rem;line-height:1}.text-sm{font-size:.875rem;line-height:1.25rem}.text-xl{font-size:1.25rem;line-height:1.75rem}.text-xs{font-size:.75rem;line-height:1rem}.font-bold{font-weight:700}.font-medium{font-weight:500}.font-semibold{font-weight:600}.uppercase{text-transform:uppercase}.leading-none{line-height:1}.tracking-wide{letter-spacing:.025em}.text-blue-600{--tw-text-opacity: 1;color:rgb(37 99 235 / var(--tw-text-opacity))}.text-gray-500{--tw-text-opacity: 1;color:rgb(107 114 128 / var(--tw-text-opacity))}.text-gray-600{--tw-text-opacity: 1;color:rgb(75 85 99 / var(--tw-text-opacity))}.text-gray-700{--tw-text-opacity: 1;color:rgb(55 65 81 / var(--tw-text-opacity))}.text-gray-800{--tw-text-opacity: 1;color:rgb(31 41 55 / var(--tw-text-opacity))}.text-green-500{--tw-text-opacity: 1;color:rgb(34 197 94 / var(--tw-text-opacity))}.text-green-600{--tw-text-opacity: 1;color:rgb(22 163 74 / var(--tw-text-opacity))}.text-red-500{--tw-text-opacity: 1;color:rgb(239 68 68 / var(--tw-text-opacity))}.text-slate-700{--tw-text-opacity: 1;color:rgb(51 65 85 / var(--tw-text-opacity))}.text-white{--tw-text-opacity: 1;color:rgb(255 255 255 / var(--tw-text-opacity))}.text-yellow-400{--tw-text-opacity: 1;color:rgb(250 204 21 / var(--tw-text-opacity))}.text-yellow-700{--tw-text-opacity: 1;color:rgb(161 98 7 / var(--tw-text-opacity))}.text-yellow-800{--tw-text-opacity: 1;color:rgb(133 77 14 / var(--tw-text-opacity))}.opacity-0{opacity:0}.shadow-sm{--tw-shadow: 0 1px 2px 0 rgb(0 0 0 / .05);--tw-shadow-colored: 0 1px 2px 0 var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000),var(--tw-ring-shadow, 0 0 #0000),var(--tw-shadow)}.ring-1{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}.ring-transparent{--tw-ring-color: transparent}.ring-offset-white{--tw-ring-offset-color: #fff}.blur{--tw-blur: blur(8px);filter:var(--tw-blur) var(--tw-brightness) var(--tw-contrast) var(--tw-grayscale) var(--tw-hue-rotate) var(--tw-invert) var(--tw-saturate) var(--tw-sepia) var(--tw-drop-shadow)}.filter{filter:var(--tw-blur) var(--tw-brightness) var(--tw-contrast) var(--tw-grayscale) var(--tw-hue-rotate) var(--tw-invert) var(--tw-saturate) var(--tw-sepia) var(--tw-drop-shadow)}.transition{transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,-webkit-backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter,-webkit-backdrop-filter;transition-timing-function:cubic-bezier(.4,0,.2,1);transition-duration:.15s}.transition-all{transition-property:all;transition-timing-function:cubic-bezier(.4,0,.2,1);transition-duration:.15s}.transition-colors{transition-property:color,background-color,border-color,text-decoration-color,fill,stroke;transition-timing-function:cubic-bezier(.4,0,.2,1);transition-duration:.15s}.duration-200{transition-duration:.2s}.duration-300{transition-duration:.3s}.ease-in-out{transition-timing-function:cubic-bezier(.4,0,.2,1)}.ease-out{transition-timing-function:cubic-bezier(0,0,.2,1)}.before\:inline-block:before{content:var(--tw-content);display:inline-block}.before\:h-6:before{content:var(--tw-content);height:1.5rem}.before\:w-6:before{content:var(--tw-content);width:1.5rem}.before\:translate-x-0:before{content:var(--tw-content);--tw-translate-x: 0px;transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skew(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.before\:transform:before{content:var(--tw-content);transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skew(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.before\:rounded-full:before{content:var(--tw-content);border-radius:9999px}.before\:bg-white:before{content:var(--tw-content);--tw-bg-opacity: 1;background-color:rgb(255 255 255 / var(--tw-bg-opacity))}.before\:shadow:before{content:var(--tw-content);--tw-shadow: 0 1px 3px 0 rgb(0 0 0 / .1), 0 1px 2px -1px rgb(0 0 0 / .1);--tw-shadow-colored: 0 1px 3px 0 var(--tw-shadow-color), 0 1px 2px -1px var(--tw-shadow-color);box-shadow:var(--tw-ring-offset-shadow, 0 0 #0000),var(--tw-ring-shadow, 0 0 #0000),var(--tw-shadow)}.before\:ring-0:before{content:var(--tw-content);--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(0px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}.before\:transition:before{content:var(--tw-content);transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,-webkit-backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter;transition-property:color,background-color,border-color,text-decoration-color,fill,stroke,opacity,box-shadow,transform,filter,backdrop-filter,-webkit-backdrop-filter;transition-timing-function:cubic-bezier(.4,0,.2,1);transition-duration:.15s}.before\:duration-200:before{content:var(--tw-content);transition-duration:.2s}.before\:ease-in-out:before{content:var(--tw-content);transition-timing-function:cubic-bezier(.4,0,.2,1)}.first\:mt-0:first-child{margin-top:0}.first\:rounded-t-lg:first-child{border-top-left-radius:.5rem;border-top-right-radius:.5rem}.last\:rounded-b-lg:last-child{border-bottom-right-radius:.5rem;border-bottom-left-radius:.5rem}.checked\:bg-blue-600:checked{--tw-bg-opacity: 1;background-color:rgb(37 99 235 / var(--tw-bg-opacity))}.checked\:bg-none:checked{background-image:none}.checked\:before\:translate-x-full:checked:before{content:var(--tw-content);--tw-translate-x: 100%;transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skew(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.checked\:before\:bg-blue-200:checked:before{content:var(--tw-content);--tw-bg-opacity: 1;background-color:rgb(191 219 254 / var(--tw-bg-opacity))}.hover\:border-green-500:hover{--tw-border-opacity: 1;border-color:rgb(34 197 94 / var(--tw-border-opacity))}.hover\:border-red-500:hover{--tw-border-opacity: 1;border-color:rgb(239 68 68 / var(--tw-border-opacity))}.hover\:bg-blue-50:hover{--tw-bg-opacity: 1;background-color:rgb(239 246 255 / var(--tw-bg-opacity))}.hover\:bg-blue-500:hover{--tw-bg-opacity: 1;background-color:rgb(59 130 246 / var(--tw-bg-opacity))}.hover\:bg-blue-600:hover{--tw-bg-opacity: 1;background-color:rgb(37 99 235 / var(--tw-bg-opacity))}.hover\:bg-blue-700:hover{--tw-bg-opacity: 1;background-color:rgb(29 78 216 / var(--tw-bg-opacity))}.hover\:bg-gray-100:hover{--tw-bg-opacity: 1;background-color:rgb(243 244 246 / var(--tw-bg-opacity))}.hover\:bg-gray-50:hover{--tw-bg-opacity: 1;background-color:rgb(249 250 251 / var(--tw-bg-opacity))}.hover\:bg-green-500:hover{--tw-bg-opacity: 1;background-color:rgb(34 197 94 / var(--tw-bg-opacity))}.hover\:bg-red-500:hover{--tw-bg-opacity: 1;background-color:rgb(239 68 68 / var(--tw-bg-opacity))}.hover\:text-blue-500:hover{--tw-text-opacity: 1;color:rgb(59 130 246 / var(--tw-text-opacity))}.hover\:text-blue-600:hover{--tw-text-opacity: 1;color:rgb(37 99 235 / var(--tw-text-opacity))}.hover\:text-blue-800:hover{--tw-text-opacity: 1;color:rgb(30 64 175 / var(--tw-text-opacity))}.hover\:text-gray-400:hover{--tw-text-opacity: 1;color:rgb(156 163 175 / var(--tw-text-opacity))}.hover\:text-red-600:hover{--tw-text-opacity: 1;color:rgb(220 38 38 / var(--tw-text-opacity))}.hover\:text-white:hover{--tw-text-opacity: 1;color:rgb(255 255 255 / var(--tw-text-opacity))}.focus\:z-10:focus{z-index:10}.focus\:border-blue-500:focus{--tw-border-opacity: 1;border-color:rgb(59 130 246 / var(--tw-border-opacity))}.focus\:border-blue-600:focus{--tw-border-opacity: 1;border-color:rgb(37 99 235 / var(--tw-border-opacity))}.focus\:outline-none:focus{outline:2px solid transparent;outline-offset:2px}.focus\:ring-2:focus{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(2px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}.focus\:ring-blue-500:focus{--tw-ring-opacity: 1;--tw-ring-color: rgb(59 130 246 / var(--tw-ring-opacity))}.focus\:ring-blue-600:focus{--tw-ring-opacity: 1;--tw-ring-color: rgb(37 99 235 / var(--tw-ring-opacity))}.focus\:ring-gray-400:focus{--tw-ring-opacity: 1;--tw-ring-color: rgb(156 163 175 / var(--tw-ring-opacity))}.focus\:ring-green-200:focus{--tw-ring-opacity: 1;--tw-ring-color: rgb(187 247 208 / var(--tw-ring-opacity))}.focus\:ring-red-200:focus{--tw-ring-opacity: 1;--tw-ring-color: rgb(254 202 202 / var(--tw-ring-opacity))}.focus\:ring-red-500:focus{--tw-ring-opacity: 1;--tw-ring-color: rgb(239 68 68 / var(--tw-ring-opacity))}.focus\:ring-offset-2:focus{--tw-ring-offset-width: 2px}.focus\:ring-offset-white:focus{--tw-ring-offset-color: #fff}.disabled\:pointer-events-none:disabled{pointer-events:none}.disabled\:opacity-50:disabled{opacity:.5}.open.hs-overlay-open\:mt-7{margin-top:1.75rem}.open.hs-overlay-open\:translate-x-0{--tw-translate-x: 0px;transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skew(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.open.hs-overlay-open\:opacity-100{opacity:1}.open.hs-overlay-open\:duration-500{transition-duration:.5s}.open .hs-overlay-open\:mt-7{margin-top:1.75rem}.open .hs-overlay-open\:translate-x-0{--tw-translate-x: 0px;transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skew(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.open .hs-overlay-open\:opacity-100{opacity:1}.open .hs-overlay-open\:duration-500{transition-duration:.5s}@media (prefers-color-scheme: dark){.dark\:divide-gray-700>:not([hidden])~:not([hidden]){--tw-divide-opacity: 1;border-color:rgb(55 65 81 / var(--tw-divide-opacity))}.dark\:border-blue-500{--tw-border-opacity: 1;border-color:rgb(59 130 246 / var(--tw-border-opacity))}.dark\:border-gray-600{--tw-border-opacity: 1;border-color:rgb(75 85 99 / var(--tw-border-opacity))}.dark\:border-gray-700{--tw-border-opacity: 1;border-color:rgb(55 65 81 / var(--tw-border-opacity))}.dark\:bg-gray-700{--tw-bg-opacity: 1;background-color:rgb(55 65 81 / var(--tw-bg-opacity))}.dark\:bg-gray-800{--tw-bg-opacity: 1;background-color:rgb(31 41 55 / var(--tw-bg-opacity))}.dark\:bg-slate-800{--tw-bg-opacity: 1;background-color:rgb(30 41 59 / var(--tw-bg-opacity))}.dark\:bg-slate-900{--tw-bg-opacity: 1;background-color:rgb(15 23 42 / var(--tw-bg-opacity))}.dark\:bg-opacity-80{--tw-bg-opacity: .8}.dark\:text-blue-500{--tw-text-opacity: 1;color:rgb(59 130 246 / var(--tw-text-opacity))}.dark\:text-gray-200{--tw-text-opacity: 1;color:rgb(229 231 235 / var(--tw-text-opacity))}.dark\:text-gray-300{--tw-text-opacity: 1;color:rgb(209 213 219 / var(--tw-text-opacity))}.dark\:text-gray-400{--tw-text-opacity: 1;color:rgb(156 163 175 / var(--tw-text-opacity))}.dark\:text-gray-500{--tw-text-opacity: 1;color:rgb(107 114 128 / var(--tw-text-opacity))}.dark\:text-slate-400{--tw-text-opacity: 1;color:rgb(148 163 184 / var(--tw-text-opacity))}.dark\:text-white{--tw-text-opacity: 1;color:rgb(255 255 255 / var(--tw-text-opacity))}.dark\:placeholder-gray-400::-moz-placeholder{--tw-placeholder-opacity: 1;color:rgb(156 163 175 / var(--tw-placeholder-opacity))}.dark\:placeholder-gray-400::placeholder{--tw-placeholder-opacity: 1;color:rgb(156 163 175 / var(--tw-placeholder-opacity))}.dark\:shadow-slate-700\/\[\.7\]{--tw-shadow-color: rgb(51 65 85 / .7);--tw-shadow: var(--tw-shadow-colored)}.dark\:before\:bg-gray-400:before{content:var(--tw-content);--tw-bg-opacity: 1;background-color:rgb(156 163 175 / var(--tw-bg-opacity))}.dark\:checked\:border-blue-500:checked{--tw-border-opacity: 1;border-color:rgb(59 130 246 / var(--tw-border-opacity))}.dark\:checked\:bg-blue-500:checked{--tw-bg-opacity: 1;background-color:rgb(59 130 246 / var(--tw-bg-opacity))}.dark\:checked\:bg-blue-600:checked{--tw-bg-opacity: 1;background-color:rgb(37 99 235 / var(--tw-bg-opacity))}.dark\:checked\:before\:bg-blue-200:checked:before{content:var(--tw-content);--tw-bg-opacity: 1;background-color:rgb(191 219 254 / var(--tw-bg-opacity))}.dark\:hover\:border-blue-400:hover{--tw-border-opacity: 1;border-color:rgb(96 165 250 / var(--tw-border-opacity))}.dark\:hover\:bg-gray-900:hover{--tw-bg-opacity: 1;background-color:rgb(17 24 39 / var(--tw-bg-opacity))}.dark\:hover\:bg-slate-800:hover{--tw-bg-opacity: 1;background-color:rgb(30 41 59 / var(--tw-bg-opacity))}.dark\:hover\:text-blue-400:hover{--tw-text-opacity: 1;color:rgb(96 165 250 / var(--tw-text-opacity))}.dark\:hover\:text-blue-500:hover{--tw-text-opacity: 1;color:rgb(59 130 246 / var(--tw-text-opacity))}.dark\:hover\:text-red-500:hover{--tw-text-opacity: 1;color:rgb(239 68 68 / var(--tw-text-opacity))}.dark\:hover\:text-slate-300:hover{--tw-text-opacity: 1;color:rgb(203 213 225 / var(--tw-text-opacity))}.dark\:hover\:text-white:hover{--tw-text-opacity: 1;color:rgb(255 255 255 / var(--tw-text-opacity))}.dark\:focus\:border-blue-500:focus{--tw-border-opacity: 1;border-color:rgb(59 130 246 / var(--tw-border-opacity))}.dark\:focus\:outline-none:focus{outline:2px solid transparent;outline-offset:2px}.dark\:focus\:ring-1:focus{--tw-ring-offset-shadow: var(--tw-ring-inset) 0 0 0 var(--tw-ring-offset-width) var(--tw-ring-offset-color);--tw-ring-shadow: var(--tw-ring-inset) 0 0 0 calc(1px + var(--tw-ring-offset-width)) var(--tw-ring-color);box-shadow:var(--tw-ring-offset-shadow),var(--tw-ring-shadow),var(--tw-shadow, 0 0 #0000)}.dark\:focus\:ring-blue-500:focus{--tw-ring-opacity: 1;--tw-ring-color: rgb(59 130 246 / var(--tw-ring-opacity))}.dark\:focus\:ring-gray-600:focus{--tw-ring-opacity: 1;--tw-ring-color: rgb(75 85 99 / var(--tw-ring-opacity))}.dark\:focus\:ring-gray-700:focus{--tw-ring-opacity: 1;--tw-ring-color: rgb(55 65 81 / var(--tw-ring-opacity))}.dark\:focus\:ring-red-600:focus{--tw-ring-opacity: 1;--tw-ring-color: rgb(220 38 38 / var(--tw-ring-opacity))}.dark\:focus\:ring-offset-gray-800:focus{--tw-ring-offset-color: #1f2937}}@media (min-width: 640px){.sm\:mx-auto{margin-left:auto;margin-right:auto}.sm\:mb-3{margin-bottom:.75rem}.sm\:mt-10{margin-top:2.5rem}.sm\:w-auto{width:auto}.sm\:w-full{width:100%}.sm\:max-w-lg{max-width:32rem}.sm\:flex-row{flex-direction:row}.sm\:gap-3{gap:.75rem}.sm\:gap-x-4{-moz-column-gap:1rem;column-gap:1rem}.sm\:p-4{padding:1rem}.sm\:px-6{padding-left:1.5rem;padding-right:1.5rem}.sm\:py-4{padding-top:1rem;padding-bottom:1rem}.sm\:py-6{padding-top:1.5rem;padding-bottom:1.5rem}.sm\:text-3xl{font-size:1.875rem;line-height:2.25rem}.sm\:text-4xl{font-size:2.25rem;line-height:2.5rem}.sm\:text-9xl{font-size:8rem;line-height:1}}@media (min-width: 768px){.md\:flex{display:flex}.md\:items-center{align-items:center}.md\:justify-between{justify-content:space-between}.md\:p-10{padding:2.5rem}.md\:p-5{padding:1.25rem}}@media (min-width: 1024px){.lg\:bottom-0{bottom:0}.lg\:right-auto{right:auto}.lg\:block{display:block}.lg\:hidden{display:none}.lg\:translate-x-0{--tw-translate-x: 0px;transform:translate(var(--tw-translate-x),var(--tw-translate-y)) rotate(var(--tw-rotate)) skew(var(--tw-skew-x)) skewY(var(--tw-skew-y)) scaleX(var(--tw-scale-x)) scaleY(var(--tw-scale-y))}.lg\:px-8{padding-left:2rem;padding-right:2rem}.lg\:py-14{padding-top:3.5rem;padding-bottom:3.5rem}.lg\:pl-64{padding-left:16rem}}
'''

js_content = '''var Fr=Object.defineProperty;var Jr=(o,e,n)=>e in o?Fr(o,e,{enumerable:!0,configurable:!0,writable:!0,value:n}):o[e]=n;var bn=(o,e,n)=>(Jr(o,typeof e!="symbol"?e+"":e,n),n);(function(){const e=document.createElement("link").relList;if(e&&e.supports&&e.supports("modulepreload"))return;for(const r of document.querySelectorAll('link[rel="modulepreload"]'))t(r);new MutationObserver(r=>{for(const i of r)if(i.type==="childList")for(const s of i.addedNodes)s.tagName==="LINK"&&s.rel==="modulepreload"&&t(s)}).observe(document,{childList:!0,subtree:!0});function n(r){const i={};return r.integrity&&(i.integrity=r.integrity),r.referrerPolicy&&(i.referrerPolicy=r.referrerPolicy),r.crossOrigin==="use-credentials"?i.credentials="include":r.crossOrigin==="anonymous"?i.credentials="omit":i.credentials="same-origin",i}function t(r){if(r.ep)return;r.ep=!0;const i=n(r);fetch(r.href,i)}})();function K(){}function Yr(o,e){for(const n in e)o[n]=e[n];return o}function Pr(o){return o()}function zn(){return Object.create(null)}function gt(o){o.forEach(Pr)}function Mt(o){return typeof o=="function"}function ye(o,e){return o!=o?e==e:o!==e||o&&typeof o=="object"||typeof o=="function"}function Kr(o){return Object.keys(o).length===0}function qr(o,...e){if(o==null){for(const t of e)t(void 0);return K}const n=o.subscribe(...e);return n.unsubscribe?()=>n.unsubscribe():n}function pt(o){let e;return qr(o,n=>e=n)(),e}function et(o,e,n){o.$$.on_destroy.push(qr(e,n))}function rn(o,e,n,t){if(o){const r=Ar(o,e,n,t);return o[0](r)}}function Ar(o,e,n,t){return o[1]&&t?Yr(n.ctx.slice(),o[1](t(e))):n.ctx}function on(o,e,n,t){if(o[2]&&t){const r=o[2](t(n));if(e.dirty===void 0)return r;if(typeof r=="object"){const i=[],s=Math.max(e.dirty.length,r.length);for(let a=0;a<s;a+=1)i[a]=e.dirty[a]|r[a];return i}return e.dirty|r}return e.dirty}function sn(o,e,n,t,r,i){if(r){const s=Ar(e,n,t,i);o.p(s,r)}}function ln(o){if(o.ctx.length>32){const e=[],n=o.ctx.length/32;for(let t=0;t<n;t++)e[t]=-1;return e}return-1}function _(o,e){o.appendChild(e)}function N(o,e,n){o.insertBefore(e,n||null)}function B(o){o.parentNode&&o.parentNode.removeChild(o)}function tt(o,e){for(let n=0;n<o.length;n+=1)o[n]&&o[n].d(e)}function O(o){return document.createElement(o)}function Ke(o){return document.createElementNS("http://www.w3.org/2000/svg",o)}function ge(o){return document.createTextNode(o)}function F(){return ge(" ")}function ze(){return ge("")}function Le(o,e,n,t){return o.addEventListener(e,n,t),()=>o.removeEventListener(e,n,t)}function g(o,e,n){n==null?o.removeAttribute(e):o.getAttribute(e)!==n&&o.setAttribute(e,n)}function Xr(o){let e;return{p(...n){e=n,e.forEach(t=>o.push(t))},r(){e.forEach(n=>o.splice(o.indexOf(n),1))}}}function eo(o){return Array.from(o.childNodes)}function Ne(o,e){e=""+e,o.data!==e&&(o.data=e)}function mt(o,e){o.value=e??""}function en(o,e,n,t){n==null?o.style.removeProperty(e):o.style.setProperty(e,n,t?"important":"")}let Ut;function Gt(o){Ut=o}function to(){if(!Ut)throw new Error("Function called outside component initialization");return Ut}function Mr(o){to().$$.on_mount.push(o)}const At=[],_n=[];let Dt=[];const wn=[],no=Promise.resolve();let $n=!1;function ro(){$n||($n=!0,no.then(Dr))}function kn(o){Dt.push(o)}function oo(o){wn.push(o)}const vn=new Set;let Pt=0;function Dr(){if(Pt!==0)return;const o=Ut;do{try{for(;Pt<At.length;){const e=At[Pt];Pt++,Gt(e),io(e.$$)}}catch(e){throw At.length=0,Pt=0,e}for(Gt(null),At.length=0,Pt=0;_n.length;)_n.pop()();for(let e=0;e<Dt.length;e+=1){const n=Dt[e];vn.has(n)||(vn.add(n),n())}Dt.length=0}while(At.length);for(;wn.length;)wn.pop()();$n=!1,vn.clear(),Gt(o)}function io(o){if(o.fragment!==null){o.update(),gt(o.before_update);const e=o.dirty;o.dirty=[-1],o.fragment&&o.fragment.p(o.ctx,e),o.after_update.forEach(kn)}}function so(o){const e=[],n=[];Dt.forEach(t=>o.indexOf(t)===-1?e.push(t):n.push(t)),n.forEach(t=>t()),Dt=e}const tn=new Set;let xt;function je(){xt={r:0,c:[],p:xt}}function Pe(){xt.r||gt(xt.c),xt=xt.p}function L(o,e){o&&o.i&&(tn.delete(o),o.i(e))}function M(o,e,n,t){if(o&&o.o){if(tn.has(o))return;tn.add(o),xt.c.push(()=>{tn.delete(o),t&&(n&&o.d(1),t())}),o.o(e)}else t&&t()}function xe(o){return(o==null?void 0:o.length)!==void 0?o:Array.from(o)}function lo(o,e,n){const t=o.$$.props[e];t!==void 0&&(o.$$.bound[t]=n,n(o.$$.ctx[t]))}function Q(o){o&&o.c()}function Z(o,e,n){const{fragment:t,after_update:r}=o.$$;t&&t.m(e,n),kn(()=>{const i=o.$$.on_mount.map(Pr).filter(Mt);o.$$.on_destroy?o.$$.on_destroy.push(...i):gt(i),o.$$.on_mount=[]}),r.forEach(kn)}function U(o,e){const n=o.$$;n.fragment!==null&&(so(n.after_update),gt(n.on_destroy),n.fragment&&n.fragment.d(e),n.on_destroy=n.fragment=null,n.ctx=[])}function ao(o,e){o.$$.dirty[0]===-1&&(At.push(o),ro(),o.$$.dirty.fill(0)),o.$$.dirty[e/31|0]|=1<<e%31}function _e(o,e,n,t,r,i,s,a=[-1]){const c=Ut;Gt(o);const l=o.$$={fragment:null,ctx:[],props:i,update:K,not_equal:r,bound:zn(),on_mount:[],on_destroy:[],on_disconnect:[],before_update:[],after_update:[],context:new Map(e.context||(c?c.$$.context:[])),callbacks:zn(),dirty:a,skip_bound:!1,root:e.target||c.$$.root};s&&s(l.root);let p=!1;if(l.ctx=n?n(o,e.props||{},(y,C,...S)=>{const A=S.length?S[0]:C;return l.ctx&&r(l.ctx[y],l.ctx[y]=A)&&(!l.skip_bound&&l.bound[y]&&l.bound[y](A),p&&ao(o,y)),C}):[],l.update(),p=!0,gt(l.before_update),l.fragment=t?t(l.ctx):!1,e.target){if(e.hydrate){const y=eo(e.target);l.fragment&&l.fragment.l(y),y.forEach(B)}else l.fragment&&l.fragment.c();e.intro&&L(o.$$.fragment),Z(o,e.target,e.anchor),Dr()}Gt(c)}class we{constructor(){bn(this,"$$");bn(this,"$$set")}$destroy(){U(this,1),this.$destroy=K}$on(e,n){if(!Mt(n))return K;const t=this.$$.callbacks[e]||(this.$$.callbacks[e]=[]);return t.push(n),()=>{const r=t.indexOf(n);r!==-1&&t.splice(r,1)}}$set(e){this.$$set&&!Kr(e)&&(this.$$.skip_bound=!0,this.$$set(e),this.$$.skip_bound=!1)}}const co="4";typeof window<"u"&&(window.__svelte||(window.__svelte={v:new Set})).v.add(co);function Vn(o,e,n){const t=o.slice();return t[4]=e[n],t[6]=n,t}function Gn(o){let e;return{c(){e=O("span"),e.innerHTML="",g(e,"class","inline")},m(n,t){N(n,e,t)},d(n){n&&B(e)}}}function Zn(o){let e,n=o[4]+"",t,r,i,s,a=o[6]<o[0]&&Gn();return{c(){e=O("span"),t=ge(n),i=F(),a&&a.c(),s=ze(),g(e,"class",r=o[6]<o[0]?"inline":"hidden")},m(c,l){N(c,e,l),_(e,t),N(c,i,l),a&&a.m(c,l),N(c,s,l)},p(c,l){l&1&&r!==(r=c[6]<c[0]?"inline":"hidden")&&g(e,"class",r),c[6]<c[0]?a||(a=Gn(),a.c(),a.m(s.parentNode,s)):a&&(a.d(1),a=null)},d(c){c&&(B(e),B(i),B(s)),a&&a.d(c)}}}function uo(o){let e,n=xe(o[1]),t=[];for(let r=0;r<n.length;r+=1)t[r]=Zn(Vn(o,n,r));return{c(){for(let r=0;r<t.length;r+=1)t[r].c();e=ze()},m(r,i){for(let s=0;s<t.length;s+=1)t[s]&&t[s].m(r,i);N(r,e,i)},p(r,[i]){if(i&3){n=xe(r[1]);let s;for(s=0;s<n.length;s+=1){const a=Vn(r,n,s);t[s]?t[s].p(a,i):(t[s]=Zn(a),t[s].c(),t[s].m(e.parentNode,e))}for(;s<t.length;s+=1)t[s].d(1);t.length=n.length}},i:K,o:K,d(r){r&&B(e),tt(t,r)}}}function fo(o,e,n){let{text:t}=e,r=t.split(" "),i=0;return setInterval(()=>{i<r.length&&n(0,i++,i)},100),o.$$set=a=>{"text"in a&&n(2,t=a.text)},[i,r,t]}class po extends we{constructor(e){super(),_e(this,e,fo,uo,ye,{text:2})}}const qt=[];function lt(o,e=K){let n;const t=new Set;function r(a){if(ye(o,a)&&(o=a,n)){const c=!qt.length;for(const l of t)l[1](),qt.push(l,o);if(c){for(let l=0;l<qt.length;l+=2)qt[l][0](qt[l+1]);qt.length=0}}}function i(a){r(a(o))}function s(a,c=K){const l=[a,c];return t.add(l),t.size===1&&(n=e(r,i)||K),a(o),()=>{t.delete(l),t.size===0&&n&&(n(),n=null)}}return{set:r,update:i,subscribe:s}}let Rt=lt(""),Ht=lt([]),xn=lt(null),an=lt(null),cn=lt(!1),Zt=lt(!1),Wt=lt("chat"),Sn=lt([]),Qt=lt(""),Rr=lt(!1),St=lt({logo:"",title:"Welcome to Vanna.AI",subtitle:"Loading...",show_training_data:!0,suggested_questions:!0,sql:!0,table:!0,csv_download:!0,chart:!0,redraw_chart:!0,auto_fix_sql:!0,ask_results_correct:!0,followup_questions:!0,summarization:!0});function un(){Ht.set([]),cn.set(!1),Zt.set(!1)}async function On(o){un();let e=pt(St);ue({type:"user_question",question:o}),cn.set(!0);const n=await Se("generate_sql","GET",{question:o});if(ue(n),n.type!=="sql")return;window.location.hash=n.id,Rt.set(n.id),Qt.set(n.text);const t=await Se("run_sql","GET",{id:n.id});if(ue(t),t.type!=="df")return;const r=await Se("generate_plotly_figure","GET",{id:t.id});if(ue(r),r.type==="plotly_figure"){if(Sn.update(i=>[...i,{question:o,id:r.id}]),e.summarization){const i=await Se("generate_summary","GET",{id:r.id});ue(i)}ue({type:"feedback_question"}),ue({type:"feedback_buttons"})}}async function mo(o){let e=pt(St);if(ue(o),o.type!=="sql")return;window.location.hash=o.id,Rt.set(o.id),Qt.set(o.text);const n=await Se("run_sql","GET",{id:o.id});if(ue(n),n.type!=="df")return;const t=await Se("generate_plotly_figure","GET",{id:n.id});if(ue(t),t.type==="plotly_figure"){if(e.summarization){const r=await Se("generate_summary","GET",{id:t.id});ue(r)}ue({type:"feedback_question"}),ue({type:"feedback_buttons"})}}function go(o){ue({type:"user_question",question:"Re-run the SQL"}),Se("run_sql","GET",{id:o}).then(ue).then(e=>{e.type==="df"&&Se("generate_plotly_figure","GET",{id:e.id}).then(ue).then(n=>{n.type==="plotly_figure"&&Se("generate_followup_questions","GET",{id:n.id}).then(ue)})})}function ho(){Se("get_question_history","GET",[]).then($o)}function yo(){Se("get_config","GET",[]).then(wo)}function Hr(){window.location.hash="training-data",Wt.set("training-data"),Se("get_training_data","GET",[]).then(nn)}function Br(){window.location.hash="",Wt.set("chat"),un(),pt(xn)===null&&Se("generate_questions","GET",[]).then(_o)}function bo(o){window.location.hash=o,Wt.set("chat"),un(),cn.set(!0),Se("load_question","GET",{id:o}).then(ue)}function vo(o){an.set(null),Se("remove_training_data","POST",{id:o}).then(e=>{Se("get_training_data","GET",[]).then(nn)})}function ue(o){return Ht.update(e=>[...e,o]),xo(),o}function nn(o){return an.set(o),o.type==="df"&&JSON.parse(o.df).length===0&&Wt.set("no-training-data"),o}function _o(o){return xn.set(o),o}function wo(o){return o.type==="config"&&St.set(o.config),o}function $o(o){return o.type==="question_history"&&Sn.set(o.questions),o}function ko(o,e){an.set(null);let n={};n[e]=o,Se("train","POST",n).then(nn).then(t=>{t.type!=="error"&&Se("get_training_data","GET",[]).then(nn)})}async function Se(o,e,n){try{Zt.set(!0);let t="",r;if(e==="GET")t=Object.entries(n).filter(([s,a])=>s!=="endpoint"&&s!=="addMessage").map(([s,a])=>`${encodeURIComponent(s)}=${encodeURIComponent(a)}`).join("&"),r=await fetch(`/api/v0/${o}?${t}`);else{let s=JSON.stringify(n);r=await fetch(`/api/v0/${o}`,{method:"POST",headers:{"Content-Type":"application/json"},body:s})}if(!r.ok)throw new Error("The server returned an error. See the server logs for more details.");const i=await r.json();return Zt.set(!1),i}catch(t){return Zt.set(!1),{type:"error",error:String(t)}}}function xo(){setTimeout(()=>{window.scrollTo({top:document.body.scrollHeight,behavior:"smooth"})},100)}function So(){let o=pt(Ht),e=o.find(n=>n.type==="user_question");if(e&&e.type==="user_question"){let n=o.find(t=>t.type==="sql");if(n&&n.type==="sql")return{question:e.question,sql:n.text}}return null}function fn(o){Ht.update(e=>e.filter(n=>n.type!==o))}function Oo(o){Se("fix_sql","POST",{id:pt(Rt),error:o}).then(mo)}function Co(o){let n=pt(Ht).find(t=>t.type==="user_question");n&&n.type==="user_question"&&(Se("update_sql","POST",{id:pt(Rt),sql:o}).then(ue).then(t=>{t.type==="sql"&&(Qt.set(t.text),Se("run_sql","GET",{id:t.id}).then(ue).then(r=>{r.type==="df"?JSON.parse(r.df).length>1?Se("generate_plotly_figure","GET",{id:r.id}).then(ue).then(s=>{ue({type:"feedback_question"}),ue({type:"feedback_buttons"})}):(ue({type:"feedback_question"}),ue({type:"feedback_buttons"})):(ue({type:"feedback_question"}),ue({type:"feedback_buttons"}))}))}),fn("user_sql"))}function Lo(){ue({type:"chart_modification"})}function Eo(){fn("feedback_buttons"),ue({type:"feedback_correct"});let o=So();o&&(Se("train","POST",o),Se("generate_followup_questions","GET",{id:pt(Rt)}).then(ue))}function Un(){fn("feedback_buttons"),ue({type:"feedback_incorrect"}),ue({type:"user_sql"})}function To(o){fn("chart_modification"),ue({type:"user_question",question:"Update the chart with these instructions: "+o}),Se("generate_plotly_figure","GET",{id:pt(Rt),chart_instructions:o}).then(ue)}function Qn(o,e,n){const t=o.slice();return t[3]=e[n],t}function Wn(o){let e,n,t,r;return{c(){e=O("li"),n=O("button"),n.innerHTML=`<svg class="w-3.5 h-3.5" fill="none" stroke="currentColor" stroke-width="1.5" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg" aria-hidden="true"><path stroke-linecap="round" stroke-linejoin="round" d="M4.26 10.147a60.436 60.436 0 00-.491 6.347A48.627 48.627 0 0112 20.904a48.627 48.627 0 018.232-4.41 60.46 60.46 0 00-.491-6.347m-15.482 0a50.57 50.57 0 00-2.658-.813A59.905 59.905 0 0112 3.493a59.902 59.902 0 0110.399 5.84c-.896.248-1.783.52-2.658.814m-15.482 0A50.697 50.697 0 0112 13.489a50.702 50.702 0 017.74-3.342M6.75 15a.75.75 0 100-1.5.75.75 0 000 1.5zm0 0v-3.675A55.378 55.378 0 0112 8.443m-7.007 11.55A5.981 5.981 0 006.75 15.75v-1.5"></path></svg>
              Training Data`,g(n,"class","flex items-center gap-x-3 py-2 px-3 text-sm text-slate-700 rounded-md hover:bg-gray-100 dark:hover:bg-gray-900 dark:text-slate-400 dark:hover:text-slate-300 border-t border-b border-gray-200 dark:border-gray-700 w-full")},m(i,s){N(i,e,s),_(e,n),t||(r=Le(n,"click",Hr),t=!0)},d(i){i&&B(e),t=!1,r()}}}function Fn(o){let e,n,t,r,i,s=o[3].question+"",a,c,l,p;function y(){return o[2](o[3])}return{c(){e=O("li"),n=O("button"),t=Ke("svg"),r=Ke("path"),i=F(),a=ge(s),c=F(),g(r,"stroke-linecap","round"),g(r,"stroke-linejoin","round"),g(r,"d","M7.5 8.25h9m-9 3H12m-9.75 1.51c0 1.6 1.123 2.994 2.707 3.227 1.129.166 2.27.293 3.423.379.35.026.67.21.865.501L12 21l2.755-4.133a1.14 1.14 0 01.865-.501 48.172 48.172 0 003.423-.379c1.584-.233 2.707-1.626 2.707-3.228V6.741c0-1.602-1.123-2.995-2.707-3.228A48.394 48.394 0 0012 3c-2.392 0-4.744.175-7.043.513C3.373 3.746 2.25 5.14 2.25 6.741v6.018z"),g(t,"class","w-3.5 h-3.5"),g(t,"fill","none"),g(t,"stroke","currentColor"),g(t,"stroke-width","1.5"),g(t,"viewBox","0 0 24 24"),g(t,"xmlns","http://www.w3.org/2000/svg"),g(t,"aria-hidden","true"),g(n,"class","flex items-center text-left gap-x-3 py-2 px-3 text-sm text-slate-700 rounded-md hover:bg-gray-100 dark:hover:bg-gray-900 dark:text-slate-400 dark:hover:text-slate-300")},m(C,S){N(C,e,S),_(e,n),_(n,t),_(t,r),_(n,i),_(n,a),_(e,c),l||(p=Le(n,"click",y),l=!0)},p(C,S){o=C,S&2&&s!==(s=o[3].question+"")&&Ne(a,s)},d(C){C&&B(e),l=!1,p()}}}function jo(o){let e,n,t,r,i,s,a,c,l,p,y,C,S,A,E=o[0].show_training_data&&Wn(),b=xe(o[1]),d=[];for(let m=0;m<b.length;m+=1)d[m]=Fn(Qn(o,b,m));return{c(){e=O("div"),n=O("nav"),t=O("div"),t.innerHTML='<img class="w-28 h-auto" src="https://img.vanna.ai/vanna-flask.svg" alt="Vanna Logo"/> <div class="lg:hidden"><button type="button" class="w-8 h-8 inline-flex justify-center items-center gap-2 rounded-md text-gray-700 align-middle focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-offset-white focus:ring-blue-600 transition-all dark:text-gray-400 dark:focus:ring-offset-gray-800" data-hs-overlay="#application-sidebar" aria-controls="application-sidebar" aria-label="Toggle navigation"><svg class="w-4 h-4" width="16" height="16" fill="currentColor" viewBox="0 0 16 16"><path d="M2.146 2.854a.5.5 0 1 1 .708-.708L8 7.293l5.146-5.147a.5.5 0 0 1 .708.708L8.707 8l5.147 5.146a.5.5 0 0 1-.708.708L8 8.707l-5.146 5.147a.5.5 0 0 1-.708-.708L7.293 8 2.146 2.854Z"></path></svg> <span class="sr-only">Sidebar</span></button></div>',r=F(),i=O("div"),s=O("ul"),E&&E.c(),a=F(),c=O("li"),l=O("button"),l.innerHTML=`<svg class="w-3.5 h-3.5" xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" viewBox="0 0 16 16"><path fill-rule="evenodd" clip-rule="evenodd" d="M8 2C8.47339 2 8.85714 2.38376 8.85714 2.85714V7.14286L13.1429 7.14286C13.6162 7.14286 14 7.52661 14 8C14 8.47339 13.6162 8.85714 13.1429 8.85714L8.85714 8.85715V13.1429C8.85714 13.6162 8.47339 14 8 14C7.52661 14 7.14286 13.6162 7.14286 13.1429V8.85715L2.85714 8.85715C2.38376 8.85715 2 8.4734 2 8.00001C2 7.52662 2.38376 7.14287 2.85714 7.14287L7.14286 7.14286V2.85714C7.14286 2.38376 7.52661 2 8 2Z" fill="currentColor"></path></svg>
              New question`,p=F();for(let m=0;m<d.length;m+=1)d[m].c();y=F(),C=O("div"),C.innerHTML=`<div class="py-2.5 px-7"><p class="inline-flex items-center gap-x-2 text-xs text-green-600"><span class="block w-1.5 h-1.5 rounded-full bg-green-600"></span>
            Connected</p></div> <div class="p-4 border-t border-gray-200 dark:border-gray-700"><a class="flex justify-between items-center gap-x-3 py-2 px-3 text-sm text-slate-700 rounded-md hover:bg-gray-100 dark:hover:bg-gray-900 dark:text-slate-400 dark:hover:text-slate-300" href="#replace">Sign out
            <svg class="w-3.5 h-3.5" xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" viewBox="0 0 16 16"><path fill-rule="evenodd" d="M10 3.5a.5.5 0 0 0-.5-.5h-8a.5.5 0 0 0-.5.5v9a.5.5 0 0 0 .5.5h8a.5.5 0 0 0 .5-.5v-2a.5.5 0 0 1 1 0v2A1.5 1.5 0 0 1 9.5 14h-8A1.5 1.5 0 0 1 0 12.5v-9A1.5 1.5 0 0 1 1.5 2h8A1.5 1.5 0 0 1 11 3.5v2a.5.5 0 0 1-1 0v-2z"></path><path fill-rule="evenodd" d="M4.146 8.354a.5.5 0 0 1 0-.708l3-3a.5.5 0 1 1 .708.708L5.707 7.5H14.5a.5.5 0 0 1 0 1H5.707l2.147 2.146a.5.5 0 0 1-.708.708l-3-3z"></path></svg></a></div>`,g(t,"class","flex items-center justify-between py-4 pr-4 pl-7"),g(l,"class","flex items-center gap-x-3 py-2 px-3 text-sm text-slate-700 rounded-md hover:bg-gray-100 dark:hover:bg-gray-900 dark:text-slate-400 dark:hover:text-slate-300"),g(s,"class","space-y-1.5 p-4"),g(i,"class","h-full"),g(C,"class","mt-auto"),g(n,"class","hs-accordion-group w-full h-full flex flex-col"),g(n,"data-hs-accordion-always-open",""),g(e,"id","application-sidebar"),g(e,"class","hs-overlay hs-overlay-open:translate-x-0 -translate-x-full transition-all duration-300 transform hidden fixed top-0 left-0 bottom-0 z-[60] w-64 bg-white border-r border-gray-200 overflow-y-auto scrollbar-y lg:block lg:translate-x-0 lg:right-auto lg:bottom-0 dark:scrollbar-y dark:bg-slate-900 dark:border-gray-700")},m(m,w){N(m,e,w),_(e,n),_(n,t),_(n,r),_(n,i),_(i,s),E&&E.m(s,null),_(s,a),_(s,c),_(c,l),_(s,p);for(let q=0;q<d.length;q+=1)d[q]&&d[q].m(s,null);_(n,y),_(n,C),S||(A=Le(l,"click",Br),S=!0)},p(m,[w]){if(m[0].show_training_data?E||(E=Wn(),E.c(),E.m(s,a)):E&&(E.d(1),E=null),w&2){b=xe(m[1]);let q;for(q=0;q<b.length;q+=1){const R=Qn(m,b,q);d[q]?d[q].p(R,w):(d[q]=Fn(R),d[q].c(),d[q].m(s,null))}for(;q<d.length;q+=1)d[q].d(1);d.length=b.length}},i:K,o:K,d(m){m&&B(e),E&&E.d(),tt(d,m),S=!1,A()}}}function Po(o,e,n){let t,r;return et(o,St,s=>n(0,t=s)),et(o,Sn,s=>n(1,r=s)),[t,r,s=>{bo(s.id)}]}class qo extends we{constructor(e){super(),_e(this,e,Po,jo,ye,{})}}var Ao={exports:{}};/*! For license information please see preline.js.LICENSE.txt */(function(o,e){(function(n,t){o.exports=t()})(self,function(){return(()=>{var n={661:(s,a,c)=>{function l(E){return l=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(b){return typeof b}:function(b){return b&&typeof Symbol=="function"&&b.constructor===Symbol&&b!==Symbol.prototype?"symbol":typeof b},l(E)}function p(E,b){for(var d=0;d<b.length;d++){var m=b[d];m.enumerable=m.enumerable||!1,m.configurable=!0,"value"in m&&(m.writable=!0),Object.defineProperty(E,m.key,m)}}function y(E,b){return y=Object.setPrototypeOf||function(d,m){return d.__proto__=m,d},y(E,b)}function C(E,b){if(b&&(l(b)==="object"||typeof b=="function"))return b;if(b!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return function(d){if(d===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return d}(E)}function S(E){return S=Object.setPrototypeOf?Object.getPrototypeOf:function(b){return b.__proto__||Object.getPrototypeOf(b)},S(E)}var A=function(E){(function(T,u){if(typeof u!="function"&&u!==null)throw new TypeError("Super expression must either be null or a function");T.prototype=Object.create(u&&u.prototype,{constructor:{value:T,writable:!0,configurable:!0}}),Object.defineProperty(T,"prototype",{writable:!1}),u&&y(T,u)})(R,E);var b,d,m,w,q=(m=R,w=function(){if(typeof Reflect>"u"||!Reflect.construct||Reflect.construct.sham)return!1;if(typeof Proxy=="function")return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){})),!0}catch{return!1}}(),function(){var T,u=S(m);if(w){var f=S(this).constructor;T=Reflect.construct(u,arguments,f)}else T=u.apply(this,arguments);return C(this,T)});function R(){return function(T,u){if(!(T instanceof u))throw new TypeError("Cannot call a class as a function")}(this,R),q.call(this,".hs-accordion")}return b=R,(d=[{key:"init",value:function(){var T=this;document.addEventListener("click",function(u){var f=u.target,x=f.closest(T.selector),j=f.closest(".hs-accordion-toggle"),k=f.closest(".hs-accordion-group");x&&k&&j&&(T._hideAll(x),T.show(x))})}},{key:"show",value:function(T){var u=this;if(T.classList.contains("active"))return this.hide(T);T.classList.add("active");var f=T.querySelector(".hs-accordion-content");f.style.display="block",f.style.height=0,setTimeout(function(){f.style.height="".concat(f.scrollHeight,"px")}),this.afterTransition(f,function(){T.classList.contains("active")&&(f.style.height="",u._fireEvent("open",T),u._dispatch("open.hs.accordion",T,T))})}},{key:"hide",value:function(T){var u=this,f=T.querySelector(".hs-accordion-content");f.style.height="".concat(f.scrollHeight,"px"),setTimeout(function(){f.style.height=0}),this.afterTransition(f,function(){T.classList.contains("active")||(f.style.display="",u._fireEvent("hide",T),u._dispatch("hide.hs.accordion",T,T))}),T.classList.remove("active")}},{key:"_hideAll",value:function(T){var u=this,f=T.closest(".hs-accordion-group");f.hasAttribute("data-hs-accordion-always-open")||f.querySelectorAll(this.selector).forEach(function(x){T!==x&&u.hide(x)})}}])&&p(b.prototype,d),Object.defineProperty(b,"prototype",{writable:!1}),R}(c(765).Z);window.HSAccordion=new A,document.addEventListener("load",window.HSAccordion.init())},795:(s,a,c)=>{function l(b){return l=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(d){return typeof d}:function(d){return d&&typeof Symbol=="function"&&d.constructor===Symbol&&d!==Symbol.prototype?"symbol":typeof d},l(b)}function p(b,d){(d==null||d>b.length)&&(d=b.length);for(var m=0,w=new Array(d);m<d;m++)w[m]=b[m];return w}function y(b,d){for(var m=0;m<d.length;m++){var w=d[m];w.enumerable=w.enumerable||!1,w.configurable=!0,"value"in w&&(w.writable=!0),Object.defineProperty(b,w.key,w)}}function C(b,d){return C=Object.setPrototypeOf||function(m,w){return m.__proto__=w,m},C(b,d)}function S(b,d){if(d&&(l(d)==="object"||typeof d=="function"))return d;if(d!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return function(m){if(m===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return m}(b)}function A(b){return A=Object.setPrototypeOf?Object.getPrototypeOf:function(d){return d.__proto__||Object.getPrototypeOf(d)},A(b)}var E=function(b){(function(u,f){if(typeof f!="function"&&f!==null)throw new TypeError("Super expression must either be null or a function");u.prototype=Object.create(f&&f.prototype,{constructor:{value:u,writable:!0,configurable:!0}}),Object.defineProperty(u,"prototype",{writable:!1}),f&&C(u,f)})(T,b);var d,m,w,q,R=(w=T,q=function(){if(typeof Reflect>"u"||!Reflect.construct||Reflect.construct.sham)return!1;if(typeof Proxy=="function")return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){})),!0}catch{return!1}}(),function(){var u,f=A(w);if(q){var x=A(this).constructor;u=Reflect.construct(f,arguments,x)}else u=f.apply(this,arguments);return S(this,u)});function T(){return function(u,f){if(!(u instanceof f))throw new TypeError("Cannot call a class as a function")}(this,T),R.call(this,"[data-hs-collapse]")}return d=T,(m=[{key:"init",value:function(){var u=this;document.addEventListener("click",function(f){var x=f.target.closest(u.selector);if(x){var j=document.querySelectorAll(x.getAttribute("data-hs-collapse"));u.toggle(j)}})}},{key:"toggle",value:function(u){var f,x=this;u.length&&(f=u,function(j){if(Array.isArray(j))return p(j)}(f)||function(j){if(typeof Symbol<"u"&&j[Symbol.iterator]!=null||j["@@iterator"]!=null)return Array.from(j)}(f)||function(j,k){if(j){if(typeof j=="string")return p(j,k);var P=Object.prototype.toString.call(j).slice(8,-1);return P==="Object"&&j.constructor&&(P=j.constructor.name),P==="Map"||P==="Set"?Array.from(j):P==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(P)?p(j,k):void 0}}(f)||function(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}()).forEach(function(j){j.classList.contains("hidden")?x.show(j):x.hide(j)})}},{key:"show",value:function(u){var f=this;u.classList.add("open"),u.classList.remove("hidden"),u.style.height=0,document.querySelectorAll(this.selector).forEach(function(x){u.closest(x.getAttribute("data-hs-collapse"))&&x.classList.add("open")}),u.style.height="".concat(u.scrollHeight,"px"),this.afterTransition(u,function(){u.classList.contains("open")&&(u.style.height="",f._fireEvent("open",u),f._dispatch("open.hs.collapse",u,u))})}},{key:"hide",value:function(u){var f=this;u.style.height="".concat(u.scrollHeight,"px"),setTimeout(function(){u.style.height=0}),u.classList.remove("open"),this.afterTransition(u,function(){u.classList.contains("open")||(u.classList.add("hidden"),u.style.height=null,f._fireEvent("hide",u),f._dispatch("hide.hs.collapse",u,u),u.querySelectorAll(".hs-mega-menu-content.block").forEach(function(x){x.classList.remove("block"),x.classList.add("hidden")}))}),document.querySelectorAll(this.selector).forEach(function(x){u.closest(x.getAttribute("data-hs-collapse"))&&x.classList.remove("open")})}}])&&y(d.prototype,m),Object.defineProperty(d,"prototype",{writable:!1}),T}(c(765).Z);window.HSCollapse=new E,document.addEventListener("load",window.HSCollapse.init())},682:(s,a,c)=>{var l=c(714),p=c(765);const y={historyIndex:-1,addHistory:function(q){this.historyIndex=q},existsInHistory:function(q){return q>this.historyIndex},clearHistory:function(){this.historyIndex=-1}};function C(q){return C=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(R){return typeof R}:function(R){return R&&typeof Symbol=="function"&&R.constructor===Symbol&&R!==Symbol.prototype?"symbol":typeof R},C(q)}function S(q){return function(R){if(Array.isArray(R))return A(R)}(q)||function(R){if(typeof Symbol<"u"&&R[Symbol.iterator]!=null||R["@@iterator"]!=null)return Array.from(R)}(q)||function(R,T){if(R){if(typeof R=="string")return A(R,T);var u=Object.prototype.toString.call(R).slice(8,-1);return u==="Object"&&R.constructor&&(u=R.constructor.name),u==="Map"||u==="Set"?Array.from(R):u==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(u)?A(R,T):void 0}}(q)||function(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}()}function A(q,R){(R==null||R>q.length)&&(R=q.length);for(var T=0,u=new Array(R);T<R;T++)u[T]=q[T];return u}function E(q,R){for(var T=0;T<R.length;T++){var u=R[T];u.enumerable=u.enumerable||!1,u.configurable=!0,"value"in u&&(u.writable=!0),Object.defineProperty(q,u.key,u)}}function b(q,R){return b=Object.setPrototypeOf||function(T,u){return T.__proto__=u,T},b(q,R)}function d(q,R){if(R&&(C(R)==="object"||typeof R=="function"))return R;if(R!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return function(T){if(T===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return T}(q)}function m(q){return m=Object.setPrototypeOf?Object.getPrototypeOf:function(R){return R.__proto__||Object.getPrototypeOf(R)},m(q)}var w=function(q){(function(k,P){if(typeof P!="function"&&P!==null)throw new TypeError("Super expression must either be null or a function");k.prototype=Object.create(P&&P.prototype,{constructor:{value:k,writable:!0,configurable:!0}}),Object.defineProperty(k,"prototype",{writable:!1}),P&&b(k,P)})(j,q);var R,T,u,f,x=(u=j,f=function(){if(typeof Reflect>"u"||!Reflect.construct||Reflect.construct.sham)return!1;if(typeof Proxy=="function")return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){})),!0}catch{return!1}}(),function(){var k,P=m(u);if(f){var H=m(this).constructor;k=Reflect.construct(P,arguments,H)}else k=P.apply(this,arguments);return d(this,k)});function j(){var k;return function(P,H){if(!(P instanceof H))throw new TypeError("Cannot call a class as a function")}(this,j),(k=x.call(this,".hs-dropdown")).positions={top:"top","top-left":"top-start","top-right":"top-end",bottom:"bottom","bottom-left":"bottom-start","bottom-right":"bottom-end",right:"right","right-top":"right-start","right-bottom":"right-end",left:"left","left-top":"left-start","left-bottom":"left-end"},k.absoluteStrategyModifiers=function(P){return[{name:"applyStyles",fn:function(H){var I=(window.getComputedStyle(P).getPropertyValue("--strategy")||"absolute").replace(" ",""),W=(window.getComputedStyle(P).getPropertyValue("--adaptive")||"adaptive").replace(" ","");H.state.elements.popper.style.position=I,H.state.elements.popper.style.transform=W==="adaptive"?H.state.styles.popper.transform:null,H.state.elements.popper.style.top=null,H.state.elements.popper.style.bottom=null,H.state.elements.popper.style.left=null,H.state.elements.popper.style.right=null,H.state.elements.popper.style.margin=0}},{name:"computeStyles",options:{adaptive:!1}}]},k._history=y,k}return R=j,T=[{key:"init",value:function(){var k=this;document.addEventListener("click",function(P){var H=P.target,I=H.closest(k.selector),W=H.closest(".hs-dropdown-menu");if(I&&I.classList.contains("open")||k._closeOthers(I),W){var J=(window.getComputedStyle(I).getPropertyValue("--auto-close")||"").replace(" ","");if((J=="false"||J=="inside")&&!I.parentElement.closest(k.selector))return}I&&(I.classList.contains("open")?k.close(I):k.open(I))}),document.addEventListener("mousemove",function(P){var H=P.target,I=H.closest(k.selector);if(H.closest(".hs-dropdown-menu"),I){var W=(window.getComputedStyle(I).getPropertyValue("--trigger")||"click").replace(" ","");if(W!=="hover")return;I&&I.classList.contains("open")||k._closeOthers(I),W!=="hover"||I.classList.contains("open")||/iPad|iPhone|iPod/.test(navigator.platform)||navigator.maxTouchPoints&&navigator.maxTouchPoints>2&&/MacIntel/.test(navigator.platform)||navigator.maxTouchPoints&&navigator.maxTouchPoints>2&&/MacIntel/.test(navigator.platform)||k._hover(H)}}),document.addEventListener("keydown",this._keyboardSupport.bind(this)),window.addEventListener("resize",function(){document.querySelectorAll(".hs-dropdown.open").forEach(function(P){k.close(P,!0)})})}},{key:"_closeOthers",value:function(){var k=this,P=arguments.length>0&&arguments[0]!==void 0?arguments[0]:null,H=document.querySelectorAll("".concat(this.selector,".open"));H.forEach(function(I){if(!P||P.closest(".hs-dropdown.open")!==I){var W=(window.getComputedStyle(I).getPropertyValue("--auto-close")||"").replace(" ","");W!="false"&&W!="outside"&&k.close(I)}})}},{key:"_hover",value:function(k){var P=this,H=k.closest(this.selector);this.open(H),document.addEventListener("mousemove",function I(W){W.target.closest(P.selector)&&W.target.closest(P.selector)!==H.parentElement.closest(P.selector)||(P.close(H),document.removeEventListener("mousemove",I,!0))},!0)}},{key:"close",value:function(k){var P=this,H=arguments.length>1&&arguments[1]!==void 0&&arguments[1],I=k.querySelector(".hs-dropdown-menu"),W=function(){k.classList.contains("open")||(I.classList.remove("block"),I.classList.add("hidden"),I.style.inset=null,I.style.position=null,k._popper&&k._popper.destroy())};H||this.afterTransition(k.querySelector("[data-hs-dropdown-transition]")||I,function(){W()}),I.style.margin=null,k.classList.remove("open"),H&&W(),this._fireEvent("close",k),this._dispatch("close.hs.dropdown",k,k);var J=I.querySelectorAll(".hs-dropdown.open");J.forEach(function(Oe){P.close(Oe,!0)})}},{key:"open",value:function(k){var P=k.querySelector(".hs-dropdown-menu"),H=(window.getComputedStyle(k).getPropertyValue("--placement")||"").replace(" ",""),I=(window.getComputedStyle(k).getPropertyValue("--strategy")||"fixed").replace(" ",""),W=((window.getComputedStyle(k).getPropertyValue("--adaptive")||"adaptive").replace(" ",""),parseInt((window.getComputedStyle(k).getPropertyValue("--offset")||"10").replace(" ","")));if(I!=="static"){k._popper&&k._popper.destroy();var J=(0,l.fi)(k,P,{placement:this.positions[H]||"bottom-start",strategy:I,modifiers:[].concat(S(I!=="fixed"?this.absoluteStrategyModifiers(k):[]),[{name:"offset",options:{offset:[0,W]}}])});k._popper=J}P.style.margin=null,P.classList.add("block"),P.classList.remove("hidden"),setTimeout(function(){k.classList.add("open")}),this._fireEvent("open",k),this._dispatch("open.hs.dropdown",k,k)}},{key:"_keyboardSupport",value:function(k){var P=document.querySelector(".hs-dropdown.open");if(P)return k.keyCode===27?(k.preventDefault(),this._esc(P)):k.keyCode===40?(k.preventDefault(),this._down(P)):k.keyCode===38?(k.preventDefault(),this._up(P)):k.keyCode===36?(k.preventDefault(),this._start(P)):k.keyCode===35?(k.preventDefault(),this._end(P)):void this._byChar(P,k.key)}},{key:"_esc",value:function(k){this.close(k)}},{key:"_up",value:function(k){var P=k.querySelector(".hs-dropdown-menu"),H=S(P.querySelectorAll("a")).reverse().filter(function(J){return!J.disabled}),I=P.querySelector("a:focus"),W=H.findIndex(function(J){return J===I});W+1<H.length&&W++,H[W].focus()}},{key:"_down",value:function(k){var P=k.querySelector(".hs-dropdown-menu"),H=S(P.querySelectorAll("a")).filter(function(J){return!J.disabled}),I=P.querySelector("a:focus"),W=H.findIndex(function(J){return J===I});W+1<H.length&&W++,H[W].focus()}},{key:"_start",value:function(k){var P=S(k.querySelector(".hs-dropdown-menu").querySelectorAll("a")).filter(function(H){return!H.disabled});P.length&&P[0].focus()}},{key:"_end",value:function(k){var P=S(k.querySelector(".hs-dropdown-menu").querySelectorAll("a")).reverse().filter(function(H){return!H.disabled});P.length&&P[0].focus()}},{key:"_byChar",value:function(k,P){var H=this,I=S(k.querySelector(".hs-dropdown-menu").querySelectorAll("a")),W=function(){return I.findIndex(function(Oe,ae){return Oe.innerText.toLowerCase().charAt(0)===P.toLowerCase()&&H._history.existsInHistory(ae)})},J=W();J===-1&&(this._history.clearHistory(),J=W()),J!==-1&&(I[J].focus(),this._history.addHistory(J))}},{key:"toggle",value:function(k){k.classList.contains("open")?this.close(k):this.open(k)}}],T&&E(R.prototype,T),Object.defineProperty(R,"prototype",{writable:!1}),j}(p.Z);window.HSDropdown=new w,document.addEventListener("load",window.HSDropdown.init())},284:(s,a,c)=>{function l(b){return l=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(d){return typeof d}:function(d){return d&&typeof Symbol=="function"&&d.constructor===Symbol&&d!==Symbol.prototype?"symbol":typeof d},l(b)}function p(b,d){(d==null||d>b.length)&&(d=b.length);for(var m=0,w=new Array(d);m<d;m++)w[m]=b[m];return w}function y(b,d){for(var m=0;m<d.length;m++){var w=d[m];w.enumerable=w.enumerable||!1,w.configurable=!0,"value"in w&&(w.writable=!0),Object.defineProperty(b,w.key,w)}}function C(b,d){return C=Object.setPrototypeOf||function(m,w){return m.__proto__=w,m},C(b,d)}function S(b,d){if(d&&(l(d)==="object"||typeof d=="function"))return d;if(d!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return function(m){if(m===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return m}(b)}function A(b){return A=Object.setPrototypeOf?Object.getPrototypeOf:function(d){return d.__proto__||Object.getPrototypeOf(d)},A(b)}var E=function(b){(function(u,f){if(typeof f!="function"&&f!==null)throw new TypeError("Super expression must either be null or a function");u.prototype=Object.create(f&&f.prototype,{constructor:{value:u,writable:!0,configurable:!0}}),Object.defineProperty(u,"prototype",{writable:!1}),f&&C(u,f)})(T,b);var d,m,w,q,R=(w=T,q=function(){if(typeof Reflect>"u"||!Reflect.construct||Reflect.construct.sham)return!1;if(typeof Proxy=="function")return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){})),!0}catch{return!1}}(),function(){var u,f=A(w);if(q){var x=A(this).constructor;u=Reflect.construct(f,arguments,x)}else u=f.apply(this,arguments);return S(this,u)});function T(){var u;return function(f,x){if(!(f instanceof x))throw new TypeError("Cannot call a class as a function")}(this,T),(u=R.call(this,"[data-hs-overlay]")).openNextOverlay=!1,u}return d=T,(m=[{key:"init",value:function(){var u=this;document.addEventListener("click",function(f){var x=f.target.closest(u.selector),j=f.target.closest("[data-hs-overlay-close]"),k=f.target.getAttribute("aria-overlay")==="true";return j?u.close(j.closest(".hs-overlay.open")):x?u.toggle(document.querySelector(x.getAttribute("data-hs-overlay"))):void(k&&u._onBackdropClick(f.target))}),document.addEventListener("keydown",function(f){if(f.keyCode===27){var x=document.querySelector(".hs-overlay.open");if(!x)return;setTimeout(function(){x.getAttribute("data-hs-overlay-keyboard")!=="false"&&u.close(x)})}})}},{key:"toggle",value:function(u){u&&(u.classList.contains("hidden")?this.open(u):this.close(u))}},{key:"open",value:function(u){var f=this;if(u){var x=document.querySelector(".hs-overlay.open"),j=this.getClassProperty(u,"--body-scroll","false")!=="true";if(x)return this.openNextOverlay=!0,this.close(x).then(function(){f.open(u),f.openNextOverlay=!1});j&&(document.body.style.overflow="hidden"),this._buildBackdrop(u),this._checkTimer(u),this._autoHide(u),u.classList.remove("hidden"),u.setAttribute("aria-overlay","true"),u.setAttribute("tabindex","-1"),setTimeout(function(){u.classList.contains("hidden")||(u.classList.add("open"),f._fireEvent("open",u),f._dispatch("open.hs.overlay",u,u),f._focusInput(u))},50)}}},{key:"close",value:function(u){var f=this;return new Promise(function(x){u&&(u.classList.remove("open"),u.removeAttribute("aria-overlay"),u.removeAttribute("tabindex","-1"),f.afterTransition(u,function(){u.classList.contains("open")||(u.classList.add("hidden"),f._destroyBackdrop(),f._fireEvent("close",u),f._dispatch("close.hs.overlay",u,u),document.body.style.overflow="",x(u))}))})}},{key:"_autoHide",value:function(u){var f=this,x=parseInt(this.getClassProperty(u,"--auto-hide","0"));x&&(u.autoHide=setTimeout(function(){f.close(u)},x))}},{key:"_checkTimer",value:function(u){u.autoHide&&(clearTimeout(u.autoHide),delete u.autoHide)}},{key:"_onBackdropClick",value:function(u){this.getClassProperty(u,"--overlay-backdrop","true")!=="static"&&this.close(u)}},{key:"_buildBackdrop",value:function(u){var f,x=this,j=u.getAttribute("data-hs-overlay-backdrop-container")||!1,k=document.createElement("div"),P="transition duration fixed inset-0 z-50 bg-gray-900 bg-opacity-50 dark:bg-opacity-80 hs-overlay-backdrop",H=function(J,Oe){var ae=typeof Symbol<"u"&&J[Symbol.iterator]||J["@@iterator"];if(!ae){if(Array.isArray(J)||(ae=function(be,ft){if(be){if(typeof be=="string")return p(be,ft);var Qe=Object.prototype.toString.call(be).slice(8,-1);return Qe==="Object"&&be.constructor&&(Qe=be.constructor.name),Qe==="Map"||Qe==="Set"?Array.from(be):Qe==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(Qe)?p(be,ft):void 0}}(J))||Oe&&J&&typeof J.length=="number"){ae&&(J=ae);var rt=0,nt=function(){};return{s:nt,n:function(){return rt>=J.length?{done:!0}:{done:!1,value:J[rt++]}},e:function(be){throw be},f:nt}}throw new TypeError(`Invalid attempt to iterate non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}var Ge,Ue=!0,ht=!1;return{s:function(){ae=ae.call(J)},n:function(){var be=ae.next();return Ue=be.done,be},e:function(be){ht=!0,Ge=be},f:function(){try{Ue||ae.return==null||ae.return()}finally{if(ht)throw Ge}}}}(u.classList.values());try{for(H.s();!(f=H.n()).done;){var I=f.value;I.startsWith("hs-overlay-backdrop-open:")&&(P+=" ".concat(I))}}catch(J){H.e(J)}finally{H.f()}var W=this.getClassProperty(u,"--overlay-backdrop","true")!=="static";this.getClassProperty(u,"--overlay-backdrop","true")==="false"||(j&&((k=document.querySelector(j).cloneNode(!0)).classList.remove("hidden"),P=k.classList,k.classList=""),W&&k.addEventListener("click",function(){return x.close(u)},!0),k.setAttribute("data-hs-overlay-backdrop-template",""),document.body.appendChild(k),setTimeout(function(){k.classList=P}))}},{key:"_destroyBackdrop",value:function(){var u=document.querySelector("[data-hs-overlay-backdrop-template]");u&&(this.openNextOverlay&&(u.style.transitionDuration="".concat(1.8*parseFloat(window.getComputedStyle(u).transitionDuration.replace(/[^\d.-]/g,"")),"s")),u.classList.add("opacity-0"),this.afterTransition(u,function(){u.remove()}))}},{key:"_focusInput",value:function(u){var f=u.querySelector("[autofocus]");f&&f.focus()}}])&&y(d.prototype,m),Object.defineProperty(d,"prototype",{writable:!1}),T}(c(765).Z);window.HSOverlay=new E,document.addEventListener("load",window.HSOverlay.init())},181:(s,a,c)=>{function l(E){return l=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(b){return typeof b}:function(b){return b&&typeof Symbol=="function"&&b.constructor===Symbol&&b!==Symbol.prototype?"symbol":typeof b},l(E)}function p(E,b){for(var d=0;d<b.length;d++){var m=b[d];m.enumerable=m.enumerable||!1,m.configurable=!0,"value"in m&&(m.writable=!0),Object.defineProperty(E,m.key,m)}}function y(E,b){return y=Object.setPrototypeOf||function(d,m){return d.__proto__=m,d},y(E,b)}function C(E,b){if(b&&(l(b)==="object"||typeof b=="function"))return b;if(b!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return function(d){if(d===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return d}(E)}function S(E){return S=Object.setPrototypeOf?Object.getPrototypeOf:function(b){return b.__proto__||Object.getPrototypeOf(b)},S(E)}var A=function(E){(function(T,u){if(typeof u!="function"&&u!==null)throw new TypeError("Super expression must either be null or a function");T.prototype=Object.create(u&&u.prototype,{constructor:{value:T,writable:!0,configurable:!0}}),Object.defineProperty(T,"prototype",{writable:!1}),u&&y(T,u)})(R,E);var b,d,m,w,q=(m=R,w=function(){if(typeof Reflect>"u"||!Reflect.construct||Reflect.construct.sham)return!1;if(typeof Proxy=="function")return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){})),!0}catch{return!1}}(),function(){var T,u=S(m);if(w){var f=S(this).constructor;T=Reflect.construct(u,arguments,f)}else T=u.apply(this,arguments);return C(this,T)});function R(){return function(T,u){if(!(T instanceof u))throw new TypeError("Cannot call a class as a function")}(this,R),q.call(this,"[data-hs-remove-element]")}return b=R,(d=[{key:"init",value:function(){var T=this;document.addEventListener("click",function(u){var f=u.target.closest(T.selector);if(f){var x=document.querySelector(f.getAttribute("data-hs-remove-element"));x&&(x.classList.add("hs-removing"),T.afterTransition(x,function(){x.remove()}))}})}}])&&p(b.prototype,d),Object.defineProperty(b,"prototype",{writable:!1}),R}(c(765).Z);window.HSRemoveElement=new A,document.addEventListener("load",window.HSRemoveElement.init())},778:(s,a,c)=>{function l(E){return l=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(b){return typeof b}:function(b){return b&&typeof Symbol=="function"&&b.constructor===Symbol&&b!==Symbol.prototype?"symbol":typeof b},l(E)}function p(E,b){for(var d=0;d<b.length;d++){var m=b[d];m.enumerable=m.enumerable||!1,m.configurable=!0,"value"in m&&(m.writable=!0),Object.defineProperty(E,m.key,m)}}function y(E,b){return y=Object.setPrototypeOf||function(d,m){return d.__proto__=m,d},y(E,b)}function C(E,b){if(b&&(l(b)==="object"||typeof b=="function"))return b;if(b!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return function(d){if(d===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return d}(E)}function S(E){return S=Object.setPrototypeOf?Object.getPrototypeOf:function(b){return b.__proto__||Object.getPrototypeOf(b)},S(E)}var A=function(E){(function(T,u){if(typeof u!="function"&&u!==null)throw new TypeError("Super expression must either be null or a function");T.prototype=Object.create(u&&u.prototype,{constructor:{value:T,writable:!0,configurable:!0}}),Object.defineProperty(T,"prototype",{writable:!1}),u&&y(T,u)})(R,E);var b,d,m,w,q=(m=R,w=function(){if(typeof Reflect>"u"||!Reflect.construct||Reflect.construct.sham)return!1;if(typeof Proxy=="function")return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){})),!0}catch{return!1}}(),function(){var T,u=S(m);if(w){var f=S(this).constructor;T=Reflect.construct(u,arguments,f)}else T=u.apply(this,arguments);return C(this,T)});function R(){var T;return function(u,f){if(!(u instanceof f))throw new TypeError("Cannot call a class as a function")}(this,R),(T=q.call(this,"[data-hs-scrollspy] ")).activeSection=null,T}return b=R,(d=[{key:"init",value:function(){var T=this;document.querySelectorAll(this.selector).forEach(function(u){var f=document.querySelector(u.getAttribute("data-hs-scrollspy")),x=u.querySelectorAll("[href]"),j=f.children,k=u.getAttribute("data-hs-scrollspy-scrollable-parent")?document.querySelector(u.getAttribute("data-hs-scrollspy-scrollable-parent")):document;Array.from(j).forEach(function(P){P.getAttribute("id")&&k.addEventListener("scroll",function(H){return T._update({$scrollspyEl:u,$scrollspyContentEl:f,links:x,$sectionEl:P,sections:j,ev:H})})}),x.forEach(function(P){P.addEventListener("click",function(H){H.preventDefault(),P.getAttribute("href")!=="javascript:;"&&T._scrollTo({$scrollspyEl:u,$scrollableEl:k,$link:P})})})})}},{key:"_update",value:function(T){var u=T.ev,f=T.$scrollspyEl,x=(T.sections,T.links),j=T.$sectionEl,k=parseInt(this.getClassProperty(f,"--scrollspy-offset","0")),P=this.getClassProperty(j,"--scrollspy-offset")||k,H=u.target===document?0:parseInt(u.target.getBoundingClientRect().top),I=parseInt(j.getBoundingClientRect().top)-P-H,W=j.offsetHeight;if(I<=0&&I+W>0){if(this.activeSection===j)return;x.forEach(function(rt){rt.classList.remove("active")});var J=f.querySelector('[href="#'.concat(j.getAttribute("id"),'"]'));if(J){J.classList.add("active");var Oe=J.closest("[data-hs-scrollspy-group]");if(Oe){var ae=Oe.querySelector("[href]");ae&&ae.classList.add("active")}}this.activeSection=j}}},{key:"_scrollTo",value:function(T){var u=T.$scrollspyEl,f=T.$scrollableEl,x=T.$link,j=document.querySelector(x.getAttribute("href")),k=parseInt(this.getClassProperty(u,"--scrollspy-offset","0")),P=this.getClassProperty(j,"--scrollspy-offset")||k,H=f===document?0:f.offsetTop,I=j.offsetTop-P-H,W=f===document?window:f;this._fireEvent("scroll",u),this._dispatch("scroll.hs.scrollspy",u,u),window.history.replaceState(null,null,x.getAttribute("href")),W.scrollTo({top:I,left:0,behavior:"smooth"})}}])&&p(b.prototype,d),Object.defineProperty(b,"prototype",{writable:!1}),R}(c(765).Z);window.HSScrollspy=new A,document.addEventListener("load",window.HSScrollspy.init())},51:(s,a,c)=>{function l(d){return l=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(m){return typeof m}:function(m){return m&&typeof Symbol=="function"&&m.constructor===Symbol&&m!==Symbol.prototype?"symbol":typeof m},l(d)}function p(d){return function(m){if(Array.isArray(m))return y(m)}(d)||function(m){if(typeof Symbol<"u"&&m[Symbol.iterator]!=null||m["@@iterator"]!=null)return Array.from(m)}(d)||function(m,w){if(m){if(typeof m=="string")return y(m,w);var q=Object.prototype.toString.call(m).slice(8,-1);return q==="Object"&&m.constructor&&(q=m.constructor.name),q==="Map"||q==="Set"?Array.from(m):q==="Arguments"||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(q)?y(m,w):void 0}}(d)||function(){throw new TypeError(`Invalid attempt to spread non-iterable instance.
In order to be iterable, non-array objects must have a [Symbol.iterator]() method.`)}()}function y(d,m){(m==null||m>d.length)&&(m=d.length);for(var w=0,q=new Array(m);w<m;w++)q[w]=d[w];return q}function C(d,m){for(var w=0;w<m.length;w++){var q=m[w];q.enumerable=q.enumerable||!1,q.configurable=!0,"value"in q&&(q.writable=!0),Object.defineProperty(d,q.key,q)}}function S(d,m){return S=Object.setPrototypeOf||function(w,q){return w.__proto__=q,w},S(d,m)}function A(d,m){if(m&&(l(m)==="object"||typeof m=="function"))return m;if(m!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return function(w){if(w===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return w}(d)}function E(d){return E=Object.setPrototypeOf?Object.getPrototypeOf:function(m){return m.__proto__||Object.getPrototypeOf(m)},E(d)}var b=function(d){(function(f,x){if(typeof x!="function"&&x!==null)throw new TypeError("Super expression must either be null or a function");f.prototype=Object.create(x&&x.prototype,{constructor:{value:f,writable:!0,configurable:!0}}),Object.defineProperty(f,"prototype",{writable:!1}),x&&S(f,x)})(u,d);var m,w,q,R,T=(q=u,R=function(){if(typeof Reflect>"u"||!Reflect.construct||Reflect.construct.sham)return!1;if(typeof Proxy=="function")return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){})),!0}catch{return!1}}(),function(){var f,x=E(q);if(R){var j=E(this).constructor;f=Reflect.construct(x,arguments,j)}else f=x.apply(this,arguments);return A(this,f)});function u(){return function(f,x){if(!(f instanceof x))throw new TypeError("Cannot call a class as a function")}(this,u),T.call(this,"[data-hs-tab]")}return m=u,(w=[{key:"init",value:function(){var f=this;document.addEventListener("keydown",this._keyboardSupport.bind(this)),document.addEventListener("click",function(x){var j=x.target.closest(f.selector);j&&f.open(j)}),document.querySelectorAll("[hs-data-tab-select]").forEach(function(x){var j=document.querySelector(x.getAttribute("hs-data-tab-select"));j&&j.addEventListener("change",function(k){var P=document.querySelector('[data-hs-tab="'.concat(k.target.value,'"]'));P&&f.open(P)})})}},{key:"open",value:function(f){var x=document.querySelector(f.getAttribute("data-hs-tab")),j=p(f.parentElement.children),k=p(x.parentElement.children),P=f.closest("[hs-data-tab-select]"),H=P?document.querySelector(P.getAttribute("data-hs-tab")):null;j.forEach(function(I){return I.classList.remove("active")}),k.forEach(function(I){return I.classList.add("hidden")}),f.classList.add("active"),x.classList.remove("hidden"),this._fireEvent("change",f),this._dispatch("change.hs.tab",f,f),H&&(H.value=f.getAttribute("data-hs-tab"))}},{key:"_keyboardSupport",value:function(f){var x=f.target.closest(this.selector);if(x){var j=x.closest('[role="tablist"]').getAttribute("data-hs-tabs-vertical")==="true";return(j?f.keyCode===38:f.keyCode===37)?(f.preventDefault(),this._left(x)):(j?f.keyCode===40:f.keyCode===39)?(f.preventDefault(),this._right(x)):f.keyCode===36?(f.preventDefault(),this._start(x)):f.keyCode===35?(f.preventDefault(),this._end(x)):void 0}}},{key:"_right",value:function(f){var x=f.closest('[role="tablist"]');if(x){var j=p(x.querySelectorAll(this.selector)).filter(function(H){return!H.disabled}),k=x.querySelector("button:focus"),P=j.findIndex(function(H){return H===k});P+1<j.length?P++:P=0,j[P].focus(),this.open(j[P])}}},{key:"_left",value:function(f){var x=f.closest('[role="tablist"]');if(x){var j=p(x.querySelectorAll(this.selector)).filter(function(H){return!H.disabled}).reverse(),k=x.querySelector("button:focus"),P=j.findIndex(function(H){return H===k});P+1<j.length?P++:P=0,j[P].focus(),this.open(j[P])}}},{key:"_start",value:function(f){var x=f.closest('[role="tablist"]');if(x){var j=p(x.querySelectorAll(this.selector)).filter(function(k){return!k.disabled});j.length&&(j[0].focus(),this.open(j[0]))}}},{key:"_end",value:function(f){var x=f.closest('[role="tablist"]');if(x){var j=p(x.querySelectorAll(this.selector)).reverse().filter(function(k){return!k.disabled});j.length&&(j[0].focus(),this.open(j[0]))}}}])&&C(m.prototype,w),Object.defineProperty(m,"prototype",{writable:!1}),u}(c(765).Z);window.HSTabs=new b,document.addEventListener("load",window.HSTabs.init())},185:(s,a,c)=>{var l=c(765),p=c(714);function y(d){return y=typeof Symbol=="function"&&typeof Symbol.iterator=="symbol"?function(m){return typeof m}:function(m){return m&&typeof Symbol=="function"&&m.constructor===Symbol&&m!==Symbol.prototype?"symbol":typeof m},y(d)}function C(d,m){for(var w=0;w<m.length;w++){var q=m[w];q.enumerable=q.enumerable||!1,q.configurable=!0,"value"in q&&(q.writable=!0),Object.defineProperty(d,q.key,q)}}function S(d,m){return S=Object.setPrototypeOf||function(w,q){return w.__proto__=q,w},S(d,m)}function A(d,m){if(m&&(y(m)==="object"||typeof m=="function"))return m;if(m!==void 0)throw new TypeError("Derived constructors may only return object or undefined");return function(w){if(w===void 0)throw new ReferenceError("this hasn't been initialised - super() hasn't been called");return w}(d)}function E(d){return E=Object.setPrototypeOf?Object.getPrototypeOf:function(m){return m.__proto__||Object.getPrototypeOf(m)},E(d)}var b=function(d){(function(f,x){if(typeof x!="function"&&x!==null)throw new TypeError("Super expression must either be null or a function");f.prototype=Object.create(x&&x.prototype,{constructor:{value:f,writable:!0,configurable:!0}}),Object.defineProperty(f,"prototype",{writable:!1}),x&&S(f,x)})(u,d);var m,w,q,R,T=(q=u,R=function(){if(typeof Reflect>"u"||!Reflect.construct||Reflect.construct.sham)return!1;if(typeof Proxy=="function")return!0;try{return Boolean.prototype.valueOf.call(Reflect.construct(Boolean,[],function(){})),!0}catch{return!1}}(),function(){var f,x=E(q);if(R){var j=E(this).constructor;f=Reflect.construct(x,arguments,j)}else f=x.apply(this,arguments);return A(this,f)});function u(){return function(f,x){if(!(f instanceof x))throw new TypeError("Cannot call a class as a function")}(this,u),T.call(this,".hs-tooltip")}return m=u,(w=[{key:"init",value:function(){var f=this;document.addEventListener("click",function(x){var j=x.target.closest(f.selector);j&&f.getClassProperty(j,"--trigger")==="focus"&&f._focus(j),j&&f.getClassProperty(j,"--trigger")==="click"&&f._click(j)}),document.addEventListener("mousemove",function(x){var j=x.target.closest(f.selector);j&&f.getClassProperty(j,"--trigger")!=="focus"&&f.getClassProperty(j,"--trigger")!=="click"&&f._hover(j)})}},{key:"_hover",value:function(f){var x=this;if(!f.classList.contains("show")){var j=f.querySelector(".hs-tooltip-toggle"),k=f.querySelector(".hs-tooltip-content"),P=this.getClassProperty(f,"--placement");(0,p.fi)(j,k,{placement:P||"top",strategy:"fixed",modifiers:[{name:"offset",options:{offset:[0,5]}}]}),this.show(f),f.addEventListener("mouseleave",function H(I){I.relatedTarget.closest(x.selector)&&I.relatedTarget.closest(x.selector)==f||(x.hide(f),f.removeEventListener("mouseleave",H,!0))},!0)}}},{key:"_focus",value:function(f){var x=this,j=f.querySelector(".hs-tooltip-toggle"),k=f.querySelector(".hs-tooltip-content"),P=this.getClassProperty(f,"--placement"),H=this.getClassProperty(f,"--strategy");(0,p.fi)(j,k,{placement:P||"top",strategy:H||"fixed",modifiers:[{name:"offset",options:{offset:[0,5]}}]}),this.show(f),f.addEventListener("blur",function I(){x.hide(f),f.removeEventListener("blur",I,!0)},!0)}},{key:"_click",value:function(f){var x=this;if(!f.classList.contains("show")){var j=f.querySelector(".hs-tooltip-toggle"),k=f.querySelector(".hs-tooltip-content"),P=this.getClassProperty(f,"--placement"),H=this.getClassProperty(f,"--strategy");(0,p.fi)(j,k,{placement:P||"top",strategy:H||"fixed",modifiers:[{name:"offset",options:{offset:[0,5]}}]}),this.show(f);var I=function W(J){setTimeout(function(){x.hide(f),f.removeEventListener("click",W,!0),f.removeEventListener("blur",W,!0)})};f.addEventListener("blur",I,!0),f.addEventListener("click",I,!0)}}},{key:"show",value:function(f){var x=this;f.querySelector(".hs-tooltip-content").classList.remove("hidden"),setTimeout(function(){f.classList.add("show"),x._fireEvent("show",f),x._dispatch("show.hs.tooltip",f,f)})}},{key:"hide",value:function(f){var x=f.querySelector(".hs-tooltip-content");f.classList.remove("show"),this._fireEvent("hide",f),this._dispatch("hide.hs.tooltip",f,f),this.afterTransition(x,function(){f.classList.contains("show")||x.classList.add("hidden")})}}])&&C(m.prototype,w),Object.defineProperty(m,"prototype",{writable:!1}),u}(l.Z);window.HSTooltip=new b,document.addEventListener("load",window.HSTooltip.init())},765:(s,a,c)=>{function l(y,C){for(var S=0;S<C.length;S++){var A=C[S];A.enumerable=A.enumerable||!1,A.configurable=!0,"value"in A&&(A.writable=!0),Object.defineProperty(y,A.key,A)}}c.d(a,{Z:()=>p});var p=function(){function y(A,E){(function(b,d){if(!(b instanceof d))throw new TypeError("Cannot call a class as a function")})(this,y),this.$collection=[],this.selector=A,this.config=E,this.events={}}var C,S;return C=y,S=[{key:"_fireEvent",value:function(A){var E=arguments.length>1&&arguments[1]!==void 0?arguments[1]:null;this.events.hasOwnProperty(A)&&this.events[A](E)}},{key:"_dispatch",value:function(A,E){var b=arguments.length>2&&arguments[2]!==void 0?arguments[2]:null,d=new CustomEvent(A,{detail:{payload:b},bubbles:!0,cancelable:!0,composed:!1});E.dispatchEvent(d)}},{key:"on",value:function(A,E){this.events[A]=E}},{key:"afterTransition",value:function(A,E){window.getComputedStyle(A,null).getPropertyValue("transition")!=="all 0s ease 0s"?A.addEventListener("transitionend",function b(){E(),A.removeEventListener("transitionend",b,!0)},!0):E()}},{key:"getClassProperty",value:function(A,E){var b=arguments.length>2&&arguments[2]!==void 0?arguments[2]:"",d=(window.getComputedStyle(A).getPropertyValue(E)||b).replace(" ","");return d}}],S&&l(C.prototype,S),Object.defineProperty(C,"prototype",{writable:!1}),y}()},714:(s,a,c)=>{function l(v){if(v==null)return window;if(v.toString()!=="[object Window]"){var h=v.ownerDocument;return h&&h.defaultView||window}return v}function p(v){return v instanceof l(v).Element||v instanceof Element}function y(v){return v instanceof l(v).HTMLElement||v instanceof HTMLElement}function C(v){return typeof ShadowRoot<"u"&&(v instanceof l(v).ShadowRoot||v instanceof ShadowRoot)}c.d(a,{fi:()=>Ur});var S=Math.max,A=Math.min,E=Math.round;function b(v,h){h===void 0&&(h=!1);var $=v.getBoundingClientRect(),D=1,G=1;if(y(v)&&h){var z=v.offsetHeight,V=v.offsetWidth;V>0&&(D=E($.width)/V||1),z>0&&(G=E($.height)/z||1)}return{width:$.width/D,height:$.height/G,top:$.top/G,right:$.right/D,bottom:$.bottom/G,left:$.left/D,x:$.left/D,y:$.top/G}}function d(v){var h=l(v);return{scrollLeft:h.pageXOffset,scrollTop:h.pageYOffset}}function m(v){return v?(v.nodeName||"").toLowerCase():null}function w(v){return((p(v)?v.ownerDocument:v.document)||window.document).documentElement}function q(v){return b(w(v)).left+d(v).scrollLeft}function R(v){return l(v).getComputedStyle(v)}function T(v){var h=R(v),$=h.overflow,D=h.overflowX,G=h.overflowY;return/auto|scroll|overlay|hidden/.test($+G+D)}function u(v,h,$){$===void 0&&($=!1);var D,G,z=y(h),V=y(h)&&function(te){var Ae=te.getBoundingClientRect(),se=E(Ae.width)/te.offsetWidth||1,he=E(Ae.height)/te.offsetHeight||1;return se!==1||he!==1}(h),Y=w(h),X=b(v,V),ne={scrollLeft:0,scrollTop:0},re={x:0,y:0};return(z||!z&&!$)&&((m(h)!=="body"||T(Y))&&(ne=(D=h)!==l(D)&&y(D)?{scrollLeft:(G=D).scrollLeft,scrollTop:G.scrollTop}:d(D)),y(h)?((re=b(h,!0)).x+=h.clientLeft,re.y+=h.clientTop):Y&&(re.x=q(Y))),{x:X.left+ne.scrollLeft-re.x,y:X.top+ne.scrollTop-re.y,width:X.width,height:X.height}}function f(v){var h=b(v),$=v.offsetWidth,D=v.offsetHeight;return Math.abs(h.width-$)<=1&&($=h.width),Math.abs(h.height-D)<=1&&(D=h.height),{x:v.offsetLeft,y:v.offsetTop,width:$,height:D}}function x(v){return m(v)==="html"?v:v.assignedSlot||v.parentNode||(C(v)?v.host:null)||w(v)}function j(v){return["html","body","#document"].indexOf(m(v))>=0?v.ownerDocument.body:y(v)&&T(v)?v:j(x(v))}function k(v,h){var $;h===void 0&&(h=[]);var D=j(v),G=D===(($=v.ownerDocument)==null?void 0:$.body),z=l(D),V=G?[z].concat(z.visualViewport||[],T(D)?D:[]):D,Y=h.concat(V);return G?Y:Y.concat(k(x(V)))}function P(v){return["table","td","th"].indexOf(m(v))>=0}function H(v){return y(v)&&R(v).position!=="fixed"?v.offsetParent:null}function I(v){for(var h=l(v),$=H(v);$&&P($)&&R($).position==="static";)$=H($);return $&&(m($)==="html"||m($)==="body"&&R($).position==="static")?h:$||function(D){var G=navigator.userAgent.toLowerCase().indexOf("firefox")!==-1;if(navigator.userAgent.indexOf("Trident")!==-1&&y(D)&&R(D).position==="fixed")return null;for(var z=x(D);y(z)&&["html","body"].indexOf(m(z))<0;){var V=R(z);if(V.transform!=="none"||V.perspective!=="none"||V.contain==="paint"||["transform","perspective"].indexOf(V.willChange)!==-1||G&&V.willChange==="filter"||G&&V.filter&&V.filter!=="none")return z;z=z.parentNode}return null}(v)||h}var W="top",J="bottom",Oe="right",ae="left",rt="auto",nt=[W,J,Oe,ae],Ge="start",Ue="end",ht="viewport",be="popper",ft=nt.reduce(function(v,h){return v.concat([h+"-"+Ge,h+"-"+Ue])},[]),Qe=[].concat(nt,[rt]).reduce(function(v,h){return v.concat([h,h+"-"+Ge,h+"-"+Ue])},[]),yt=["beforeRead","read","afterRead","beforeMain","main","afterMain","beforeWrite","write","afterWrite"];function Bt(v){var h=new Map,$=new Set,D=[];function G(z){$.add(z.name),[].concat(z.requires||[],z.requiresIfExists||[]).forEach(function(V){if(!$.has(V)){var Y=h.get(V);Y&&G(Y)}}),D.push(z)}return v.forEach(function(z){h.set(z.name,z)}),v.forEach(function(z){$.has(z.name)||G(z)}),D}var Nt={placement:"bottom",modifiers:[],strategy:"absolute"};function qe(){for(var v=arguments.length,h=new Array(v),$=0;$<v;$++)h[$]=arguments[$];return!h.some(function(D){return!(D&&typeof D.getBoundingClientRect=="function")})}function bt(v){v===void 0&&(v={});var h=v,$=h.defaultModifiers,D=$===void 0?[]:$,G=h.defaultOptions,z=G===void 0?Nt:G;return function(V,Y,X){X===void 0&&(X=z);var ne,re,te={placement:"bottom",orderedModifiers:[],options:Object.assign({},Nt,z),modifiersData:{},elements:{reference:V,popper:Y},attributes:{},styles:{}},Ae=[],se=!1,he={state:te,setOptions:function(ie){var Me=typeof ie=="function"?ie(te.options):ie;pe(),te.options=Object.assign({},z,te.options,Me),te.scrollParents={reference:p(V)?k(V):V.contextElement?k(V.contextElement):[],popper:k(Y)};var ke,fe,ve=function(le){var ce=Bt(le);return yt.reduce(function(de,me){return de.concat(ce.filter(function($e){return $e.phase===me}))},[])}((ke=[].concat(D,te.options.modifiers),fe=ke.reduce(function(le,ce){var de=le[ce.name];return le[ce.name]=de?Object.assign({},de,ce,{options:Object.assign({},de.options,ce.options),data:Object.assign({},de.data,ce.data)}):ce,le},{}),Object.keys(fe).map(function(le){return fe[le]})));return te.orderedModifiers=ve.filter(function(le){return le.enabled}),te.orderedModifiers.forEach(function(le){var ce=le.name,de=le.options,me=de===void 0?{}:de,$e=le.effect;if(typeof $e=="function"){var Be=$e({state:te,name:ce,instance:he,options:me});Ae.push(Be||function(){})}}),he.update()},forceUpdate:function(){if(!se){var ie=te.elements,Me=ie.reference,ke=ie.popper;if(qe(Me,ke)){te.rects={reference:u(Me,I(ke),te.options.strategy==="fixed"),popper:f(ke)},te.reset=!1,te.placement=te.options.placement,te.orderedModifiers.forEach(function($e){return te.modifiersData[$e.name]=Object.assign({},$e.data)});for(var fe=0;fe<te.orderedModifiers.length;fe++)if(te.reset!==!0){var ve=te.orderedModifiers[fe],le=ve.fn,ce=ve.options,de=ce===void 0?{}:ce,me=ve.name;typeof le=="function"&&(te=le({state:te,options:de,name:me,instance:he})||te)}else te.reset=!1,fe=-1}}},update:(ne=function(){return new Promise(function(ie){he.forceUpdate(),ie(te)})},function(){return re||(re=new Promise(function(ie){Promise.resolve().then(function(){re=void 0,ie(ne())})})),re}),destroy:function(){pe(),se=!0}};if(!qe(V,Y))return he;function pe(){Ae.forEach(function(ie){return ie()}),Ae=[]}return he.setOptions(X).then(function(ie){!se&&X.onFirstUpdate&&X.onFirstUpdate(ie)}),he}}var De={passive:!0};function Ve(v){return v.split("-")[0]}function Ee(v){return v.split("-")[1]}function Te(v){return["top","bottom"].indexOf(v)>=0?"x":"y"}function ee(v){var h,$=v.reference,D=v.element,G=v.placement,z=G?Ve(G):null,V=G?Ee(G):null,Y=$.x+$.width/2-D.width/2,X=$.y+$.height/2-D.height/2;switch(z){case W:h={x:Y,y:$.y-D.height};break;case J:h={x:Y,y:$.y+$.height};break;case Oe:h={x:$.x+$.width,y:X};break;case ae:h={x:$.x-D.width,y:X};break;default:h={x:$.x,y:$.y}}var ne=z?Te(z):null;if(ne!=null){var re=ne==="y"?"height":"width";switch(V){case Ge:h[ne]=h[ne]-($[re]/2-D[re]/2);break;case Ue:h[ne]=h[ne]+($[re]/2-D[re]/2)}}return h}var He={top:"auto",right:"auto",bottom:"auto",left:"auto"};function oe(v){var h,$=v.popper,D=v.popperRect,G=v.placement,z=v.variation,V=v.offsets,Y=v.position,X=v.gpuAcceleration,ne=v.adaptive,re=v.roundOffsets,te=v.isFixed,Ae=V.x,se=Ae===void 0?0:Ae,he=V.y,pe=he===void 0?0:he,ie=typeof re=="function"?re({x:se,y:pe}):{x:se,y:pe};se=ie.x,pe=ie.y;var Me=V.hasOwnProperty("x"),ke=V.hasOwnProperty("y"),fe=ae,ve=W,le=window;if(ne){var ce=I($),de="clientHeight",me="clientWidth";ce===l($)&&R(ce=w($)).position!=="static"&&Y==="absolute"&&(de="scrollHeight",me="scrollWidth"),ce=ce,(G===W||(G===ae||G===Oe)&&z===Ue)&&(ve=J,pe-=(te&&le.visualViewport?le.visualViewport.height:ce[de])-D.height,pe*=X?1:-1),G!==ae&&(G!==W&&G!==J||z!==Ue)||(fe=Oe,se-=(te&&le.visualViewport?le.visualViewport.width:ce[me])-D.width,se*=X?1:-1)}var $e,Be=Object.assign({position:Y},ne&&He),Ie=re===!0?function(Fe){var ot=Fe.x,dt=Fe.y,Je=window.devicePixelRatio||1;return{x:E(ot*Je)/Je||0,y:E(dt*Je)/Je||0}}({x:se,y:pe}):{x:se,y:pe};return se=Ie.x,pe=Ie.y,X?Object.assign({},Be,(($e={})[ve]=ke?"0":"",$e[fe]=Me?"0":"",$e.transform=(le.devicePixelRatio||1)<=1?"translate("+se+"px, "+pe+"px)":"translate3d("+se+"px, "+pe+"px, 0)",$e)):Object.assign({},Be,((h={})[ve]=ke?pe+"px":"",h[fe]=Me?se+"px":"",h.transform="",h))}var wt={left:"right",right:"left",bottom:"top",top:"bottom"};function Ft(v){return v.replace(/left|right|bottom|top/g,function(h){return wt[h]})}var Zr={start:"end",end:"start"};function Ln(v){return v.replace(/start|end/g,function(h){return Zr[h]})}function En(v,h){var $=h.getRootNode&&h.getRootNode();if(v.contains(h))return!0;if($&&C($)){var D=h;do{if(D&&v.isSameNode(D))return!0;D=D.parentNode||D.host}while(D)}return!1}function dn(v){return Object.assign({},v,{left:v.x,top:v.y,right:v.x+v.width,bottom:v.y+v.height})}function Tn(v,h){return h===ht?dn(function($){var D=l($),G=w($),z=D.visualViewport,V=G.clientWidth,Y=G.clientHeight,X=0,ne=0;return z&&(V=z.width,Y=z.height,/^((?!chrome|android).)*safari/i.test(navigator.userAgent)||(X=z.offsetLeft,ne=z.offsetTop)),{width:V,height:Y,x:X+q($),y:ne}}(v)):p(h)?function($){var D=b($);return D.top=D.top+$.clientTop,D.left=D.left+$.clientLeft,D.bottom=D.top+$.clientHeight,D.right=D.left+$.clientWidth,D.width=$.clientWidth,D.height=$.clientHeight,D.x=D.left,D.y=D.top,D}(h):dn(function($){var D,G=w($),z=d($),V=(D=$.ownerDocument)==null?void 0:D.body,Y=S(G.scrollWidth,G.clientWidth,V?V.scrollWidth:0,V?V.clientWidth:0),X=S(G.scrollHeight,G.clientHeight,V?V.scrollHeight:0,V?V.clientHeight:0),ne=-z.scrollLeft+q($),re=-z.scrollTop;return R(V||G).direction==="rtl"&&(ne+=S(G.clientWidth,V?V.clientWidth:0)-Y),{width:Y,height:X,x:ne,y:re}}(w(v)))}function jn(v){return Object.assign({},{top:0,right:0,bottom:0,left:0},v)}function Pn(v,h){return h.reduce(function($,D){return $[D]=v,$},{})}function It(v,h){h===void 0&&(h={});var $=h,D=$.placement,G=D===void 0?v.placement:D,z=$.boundary,V=z===void 0?"clippingParents":z,Y=$.rootBoundary,X=Y===void 0?ht:Y,ne=$.elementContext,re=ne===void 0?be:ne,te=$.altBoundary,Ae=te!==void 0&&te,se=$.padding,he=se===void 0?0:se,pe=jn(typeof he!="number"?he:Pn(he,nt)),ie=re===be?"reference":be,Me=v.rects.popper,ke=v.elements[Ae?ie:re],fe=function(Ie,Fe,ot){var dt=Fe==="clippingParents"?function(Ce){var vt=k(x(Ce)),Ye=["absolute","fixed"].indexOf(R(Ce).position)>=0&&y(Ce)?I(Ce):Ce;return p(Ye)?vt.filter(function(We){return p(We)&&En(We,Ye)&&m(We)!=="body"}):[]}(Ie):[].concat(Fe),Je=[].concat(dt,[ot]),Ze=Je[0],Re=Je.reduce(function(Ce,vt){var Ye=Tn(Ie,vt);return Ce.top=S(Ye.top,Ce.top),Ce.right=A(Ye.right,Ce.right),Ce.bottom=A(Ye.bottom,Ce.bottom),Ce.left=S(Ye.left,Ce.left),Ce},Tn(Ie,Ze));return Re.width=Re.right-Re.left,Re.height=Re.bottom-Re.top,Re.x=Re.left,Re.y=Re.top,Re}(p(ke)?ke:ke.contextElement||w(v.elements.popper),V,X),ve=b(v.elements.reference),le=ee({reference:ve,element:Me,strategy:"absolute",placement:G}),ce=dn(Object.assign({},Me,le)),de=re===be?ce:ve,me={top:fe.top-de.top+pe.top,bottom:de.bottom-fe.bottom+pe.bottom,left:fe.left-de.left+pe.left,right:de.right-fe.right+pe.right},$e=v.modifiersData.offset;if(re===be&&$e){var Be=$e[G];Object.keys(me).forEach(function(Ie){var Fe=[Oe,J].indexOf(Ie)>=0?1:-1,ot=[W,J].indexOf(Ie)>=0?"y":"x";me[Ie]+=Be[ot]*Fe})}return me}function zt(v,h,$){return S(v,A(h,$))}function qn(v,h,$){return $===void 0&&($={x:0,y:0}),{top:v.top-h.height-$.y,right:v.right-h.width+$.x,bottom:v.bottom-h.height+$.y,left:v.left-h.width-$.x}}function An(v){return[W,Oe,J,ae].some(function(h){return v[h]>=0})}var Ur=bt({defaultModifiers:[{name:"eventListeners",enabled:!0,phase:"write",fn:function(){},effect:function(v){var h=v.state,$=v.instance,D=v.options,G=D.scroll,z=G===void 0||G,V=D.resize,Y=V===void 0||V,X=l(h.elements.popper),ne=[].concat(h.scrollParents.reference,h.scrollParents.popper);return z&&ne.forEach(function(re){re.addEventListener("scroll",$.update,De)}),Y&&X.addEventListener("resize",$.update,De),function(){z&&ne.forEach(function(re){re.removeEventListener("scroll",$.update,De)}),Y&&X.removeEventListener("resize",$.update,De)}},data:{}},{name:"popperOffsets",enabled:!0,phase:"read",fn:function(v){var h=v.state,$=v.name;h.modifiersData[$]=ee({reference:h.rects.reference,element:h.rects.popper,strategy:"absolute",placement:h.placement})},data:{}},{name:"computeStyles",enabled:!0,phase:"beforeWrite",fn:function(v){var h=v.state,$=v.options,D=$.gpuAcceleration,G=D===void 0||D,z=$.adaptive,V=z===void 0||z,Y=$.roundOffsets,X=Y===void 0||Y,ne={placement:Ve(h.placement),variation:Ee(h.placement),popper:h.elements.popper,popperRect:h.rects.popper,gpuAcceleration:G,isFixed:h.options.strategy==="fixed"};h.modifiersData.popperOffsets!=null&&(h.styles.popper=Object.assign({},h.styles.popper,oe(Object.assign({},ne,{offsets:h.modifiersData.popperOffsets,position:h.options.strategy,adaptive:V,roundOffsets:X})))),h.modifiersData.arrow!=null&&(h.styles.arrow=Object.assign({},h.styles.arrow,oe(Object.assign({},ne,{offsets:h.modifiersData.arrow,position:"absolute",adaptive:!1,roundOffsets:X})))),h.attributes.popper=Object.assign({},h.attributes.popper,{"data-popper-placement":h.placement})},data:{}},{name:"applyStyles",enabled:!0,phase:"write",fn:function(v){var h=v.state;Object.keys(h.elements).forEach(function($){var D=h.styles[$]||{},G=h.attributes[$]||{},z=h.elements[$];y(z)&&m(z)&&(Object.assign(z.style,D),Object.keys(G).forEach(function(V){var Y=G[V];Y===!1?z.removeAttribute(V):z.setAttribute(V,Y===!0?"":Y)}))})},effect:function(v){var h=v.state,$={popper:{position:h.options.strategy,left:"0",top:"0",margin:"0"},arrow:{position:"absolute"},reference:{}};return Object.assign(h.elements.popper.style,$.popper),h.styles=$,h.elements.arrow&&Object.assign(h.elements.arrow.style,$.arrow),function(){Object.keys(h.elements).forEach(function(D){var G=h.elements[D],z=h.attributes[D]||{},V=Object.keys(h.styles.hasOwnProperty(D)?h.styles[D]:$[D]).reduce(function(Y,X){return Y[X]="",Y},{});y(G)&&m(G)&&(Object.assign(G.style,V),Object.keys(z).forEach(function(Y){G.removeAttribute(Y)}))})}},requires:["computeStyles"]},{name:"offset",enabled:!0,phase:"main",requires:["popperOffsets"],fn:function(v){var h=v.state,$=v.options,D=v.name,G=$.offset,z=G===void 0?[0,0]:G,V=Qe.reduce(function(re,te){return re[te]=function(Ae,se,he){var pe=Ve(Ae),ie=[ae,W].indexOf(pe)>=0?-1:1,Me=typeof he=="function"?he(Object.assign({},se,{placement:Ae})):he,ke=Me[0],fe=Me[1];return ke=ke||0,fe=(fe||0)*ie,[ae,Oe].indexOf(pe)>=0?{x:fe,y:ke}:{x:ke,y:fe}}(te,h.rects,z),re},{}),Y=V[h.placement],X=Y.x,ne=Y.y;h.modifiersData.popperOffsets!=null&&(h.modifiersData.popperOffsets.x+=X,h.modifiersData.popperOffsets.y+=ne),h.modifiersData[D]=V}},{name:"flip",enabled:!0,phase:"main",fn:function(v){var h=v.state,$=v.options,D=v.name;if(!h.modifiersData[D]._skip){for(var G=$.mainAxis,z=G===void 0||G,V=$.altAxis,Y=V===void 0||V,X=$.fallbackPlacements,ne=$.padding,re=$.boundary,te=$.rootBoundary,Ae=$.altBoundary,se=$.flipVariations,he=se===void 0||se,pe=$.allowedAutoPlacements,ie=h.options.placement,Me=Ve(ie),ke=X||(Me!==ie&&he?function(We){if(Ve(We)===rt)return[];var it=Ft(We);return[Ln(We),it,Ln(it)]}(ie):[Ft(ie)]),fe=[ie].concat(ke).reduce(function(We,it){return We.concat(Ve(it)===rt?function(Ct,_t){_t===void 0&&(_t={});var st=_t,Jt=st.placement,Yt=st.boundary,Lt=st.rootBoundary,pn=st.padding,mn=st.flipVariations,Et=st.allowedAutoPlacements,gn=Et===void 0?Qe:Et,Vt=Ee(Jt),Kt=Vt?mn?ft:ft.filter(function(at){return Ee(at)===Vt}):nt,Tt=Kt.filter(function(at){return gn.indexOf(at)>=0});Tt.length===0&&(Tt=Kt);var jt=Tt.reduce(function(at,$t){return at[$t]=It(Ct,{placement:$t,boundary:Yt,rootBoundary:Lt,padding:pn})[Ve($t)],at},{});return Object.keys(jt).sort(function(at,$t){return jt[at]-jt[$t]})}(h,{placement:it,boundary:re,rootBoundary:te,padding:ne,flipVariations:he,allowedAutoPlacements:pe}):it)},[]),ve=h.rects.reference,le=h.rects.popper,ce=new Map,de=!0,me=fe[0],$e=0;$e<fe.length;$e++){var Be=fe[$e],Ie=Ve(Be),Fe=Ee(Be)===Ge,ot=[W,J].indexOf(Ie)>=0,dt=ot?"width":"height",Je=It(h,{placement:Be,boundary:re,rootBoundary:te,altBoundary:Ae,padding:ne}),Ze=ot?Fe?Oe:ae:Fe?J:W;ve[dt]>le[dt]&&(Ze=Ft(Ze));var Re=Ft(Ze),Ce=[];if(z&&Ce.push(Je[Ie]<=0),Y&&Ce.push(Je[Ze]<=0,Je[Re]<=0),Ce.every(function(We){return We})){me=Be,de=!1;break}ce.set(Be,Ce)}if(de)for(var vt=function(We){var it=fe.find(function(Ct){var _t=ce.get(Ct);if(_t)return _t.slice(0,We).every(function(st){return st})});if(it)return me=it,"break"},Ye=he?3:1;Ye>0&&vt(Ye)!=="break";Ye--);h.placement!==me&&(h.modifiersData[D]._skip=!0,h.placement=me,h.reset=!0)}},requiresIfExists:["offset"],data:{_skip:!1}},{name:"preventOverflow",enabled:!0,phase:"main",fn:function(v){var h=v.state,$=v.options,D=v.name,G=$.mainAxis,z=G===void 0||G,V=$.altAxis,Y=V!==void 0&&V,X=$.boundary,ne=$.rootBoundary,re=$.altBoundary,te=$.padding,Ae=$.tether,se=Ae===void 0||Ae,he=$.tetherOffset,pe=he===void 0?0:he,ie=It(h,{boundary:X,rootBoundary:ne,padding:te,altBoundary:re}),Me=Ve(h.placement),ke=Ee(h.placement),fe=!ke,ve=Te(Me),le=ve==="x"?"y":"x",ce=h.modifiersData.popperOffsets,de=h.rects.reference,me=h.rects.popper,$e=typeof pe=="function"?pe(Object.assign({},h.rects,{placement:h.placement})):pe,Be=typeof $e=="number"?{mainAxis:$e,altAxis:$e}:Object.assign({mainAxis:0,altAxis:0},$e),Ie=h.modifiersData.offset?h.modifiersData.offset[h.placement]:null,Fe={x:0,y:0};if(ce){if(z){var ot,dt=ve==="y"?W:ae,Je=ve==="y"?J:Oe,Ze=ve==="y"?"height":"width",Re=ce[ve],Ce=Re+ie[dt],vt=Re-ie[Je],Ye=se?-me[Ze]/2:0,We=ke===Ge?de[Ze]:me[Ze],it=ke===Ge?-me[Ze]:-de[Ze],Ct=h.elements.arrow,_t=se&&Ct?f(Ct):{width:0,height:0},st=h.modifiersData["arrow#persistent"]?h.modifiersData["arrow#persistent"].padding:{top:0,right:0,bottom:0,left:0},Jt=st[dt],Yt=st[Je],Lt=zt(0,de[Ze],_t[Ze]),pn=fe?de[Ze]/2-Ye-Lt-Jt-Be.mainAxis:We-Lt-Jt-Be.mainAxis,mn=fe?-de[Ze]/2+Ye+Lt+Yt+Be.mainAxis:it+Lt+Yt+Be.mainAxis,Et=h.elements.arrow&&I(h.elements.arrow),gn=Et?ve==="y"?Et.clientTop||0:Et.clientLeft||0:0,Vt=(ot=Ie==null?void 0:Ie[ve])!=null?ot:0,Kt=Re+mn-Vt,Tt=zt(se?A(Ce,Re+pn-Vt-gn):Ce,Re,se?S(vt,Kt):vt);ce[ve]=Tt,Fe[ve]=Tt-Re}if(Y){var jt,at=ve==="x"?W:ae,$t=ve==="x"?J:Oe,kt=ce[le],Xt=le==="y"?"height":"width",Mn=kt+ie[at],Dn=kt-ie[$t],hn=[W,ae].indexOf(Me)!==-1,Rn=(jt=Ie==null?void 0:Ie[le])!=null?jt:0,Hn=hn?Mn:kt-de[Xt]-me[Xt]-Rn+Be.altAxis,Bn=hn?kt+de[Xt]+me[Xt]-Rn-Be.altAxis:Dn,Nn=se&&hn?function(Qr,Wr,yn){var In=zt(Qr,Wr,yn);return In>yn?yn:In}(Hn,kt,Bn):zt(se?Hn:Mn,kt,se?Bn:Dn);ce[le]=Nn,Fe[le]=Nn-kt}h.modifiersData[D]=Fe}},requiresIfExists:["offset"]},{name:"arrow",enabled:!0,phase:"main",fn:function(v){var h,$=v.state,D=v.name,G=v.options,z=$.elements.arrow,V=$.modifiersData.popperOffsets,Y=Ve($.placement),X=Te(Y),ne=[ae,Oe].indexOf(Y)>=0?"height":"width";if(z&&V){var re=function(me,$e){return jn(typeof(me=typeof me=="function"?me(Object.assign({},$e.rects,{placement:$e.placement})):me)!="number"?me:Pn(me,nt))}(G.padding,$),te=f(z),Ae=X==="y"?W:ae,se=X==="y"?J:Oe,he=$.rects.reference[ne]+$.rects.reference[X]-V[X]-$.rects.popper[ne],pe=V[X]-$.rects.reference[X],ie=I(z),Me=ie?X==="y"?ie.clientHeight||0:ie.clientWidth||0:0,ke=he/2-pe/2,fe=re[Ae],ve=Me-te[ne]-re[se],le=Me/2-te[ne]/2+ke,ce=zt(fe,le,ve),de=X;$.modifiersData[D]=((h={})[de]=ce,h.centerOffset=ce-le,h)}},effect:function(v){var h=v.state,$=v.options.element,D=$===void 0?"[data-popper-arrow]":$;D!=null&&(typeof D!="string"||(D=h.elements.popper.querySelector(D)))&&En(h.elements.popper,D)&&(h.elements.arrow=D)},requires:["popperOffsets"],requiresIfExists:["preventOverflow"]},{name:"hide",enabled:!0,phase:"main",requiresIfExists:["preventOverflow"],fn:function(v){var h=v.state,$=v.name,D=h.rects.reference,G=h.rects.popper,z=h.modifiersData.preventOverflow,V=It(h,{elementContext:"reference"}),Y=It(h,{altBoundary:!0}),X=qn(V,D),ne=qn(Y,G,z),re=An(X),te=An(ne);h.modifiersData[$]={referenceClippingOffsets:X,popperEscapeOffsets:ne,isReferenceHidden:re,hasPopperEscaped:te},h.attributes.popper=Object.assign({},h.attributes.popper,{"data-popper-reference-hidden":re,"data-popper-escaped":te})}}]})}},t={};function r(s){var a=t[s];if(a!==void 0)return a.exports;var c=t[s]={exports:{}};return n[s](c,c.exports,r),c.exports}r.d=(s,a)=>{for(var c in a)r.o(a,c)&&!r.o(s,c)&&Object.defineProperty(s,c,{enumerable:!0,get:a[c]})},r.o=(s,a)=>Object.prototype.hasOwnProperty.call(s,a),r.r=s=>{typeof Symbol<"u"&&Symbol.toStringTag&&Object.defineProperty(s,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(s,"__esModule",{value:!0})};var i={};return r.r(i),r(661),r(795),r(682),r(284),r(181),r(778),r(51),r(185),i})()})})(Ao);function Mo(o){let e=o[0].title+"",n;return{c(){n=ge(e)},m(t,r){N(t,n,r)},p(t,r){r&1&&e!==(e=t[0].title+"")&&Ne(n,e)},d(t){t&&B(n)}}}function Do(o){let e,n;return{c(){e=ge("Welcome to "),n=O("span"),n.textContent="Vanna.AI",g(n,"class","nav-title")},m(t,r){N(t,e,r),N(t,n,r)},p:K,d(t){t&&(B(e),B(n))}}}function Ro(o){let e,n,t,r,i=o[0].subtitle+"",s;function a(p,y){return p[0].title=="Welcome to Vanna.AI"?Do:Mo}let c=a(o),l=c(o);return{c(){e=O("div"),n=O("h1"),l.c(),t=F(),r=O("p"),s=ge(i),g(n,"class","text-3xl font-bold text-gray-800 sm:text-4xl dark:text-white"),g(r,"class","mt-3 text-gray-600 dark:text-gray-400"),g(e,"class","max-w-4xl px-4 sm:px-6 lg:px-8 mx-auto text-center")},m(p,y){N(p,e,y),_(e,n),l.m(n,null),_(e,t),_(e,r),_(r,s)},p(p,[y]){c===(c=a(p))&&l?l.p(p,y):(l.d(1),l=c(p),l&&(l.c(),l.m(n,null))),y&1&&i!==(i=p[0].subtitle+"")&&Ne(s,i)},i:K,o:K,d(p){p&&B(e),l.d()}}}function Ho(o,e,n){let t;return et(o,St,r=>n(0,t=r)),[t]}class Bo extends we{constructor(e){super(),_e(this,e,Ho,Ro,ye,{})}}function No(o){let e,n;const t=o[1].default,r=rn(t,o,o[0],null);return{c(){e=O("p"),r&&r.c(),g(e,"class","text-gray-800 dark:text-gray-200")},m(i,s){N(i,e,s),r&&r.m(e,null),n=!0},p(i,[s]){r&&r.p&&(!n||s&1)&&sn(r,t,i,i[0],n?on(t,i[0],s,null):ln(i[0]),null)},i(i){n||(L(r,i),n=!0)},o(i){M(r,i),n=!1},d(i){i&&B(e),r&&r.d(i)}}}function Io(o,e,n){let{$$slots:t={},$$scope:r}=e;return o.$$set=i=>{"$$scope"in i&&n(0,r=i.$$scope)},[r,t]}class ut extends we{constructor(e){super(),_e(this,e,Io,No,ye,{})}}function zo(o){let e;return{c(){e=ge(o[0])},m(n,t){N(n,e,t)},p(n,t){t&1&&Ne(e,n[0])},d(n){n&&B(e)}}}function Vo(o){let e,n,t,r,i,s,a,c,l;a=new ut({props:{$$slots:{default:[zo]},$$scope:{ctx:o}}});const p=o[1].default,y=rn(p,o,o[2],null);return{c(){e=O("li"),n=O("div"),t=O("div"),r=O("span"),r.innerHTML='<span class="text-sm font-medium text-white leading-none">You</span>',i=F(),s=O("div"),Q(a.$$.fragment),c=F(),y&&y.c(),g(r,"class","flex-shrink-0 inline-flex items-center justify-center h-[2.375rem] w-[2.375rem] rounded-full bg-gray-600"),g(s,"class","grow mt-2 space-y-3"),g(t,"class","max-w-2xl flex gap-x-2 sm:gap-x-4"),g(n,"class","max-w-4xl px-4 sm:px-6 lg:px-8 mx-auto"),g(e,"class","py-2 sm:py-4")},m(C,S){N(C,e,S),_(e,n),_(n,t),_(t,r),_(t,i),_(t,s),Z(a,s,null),_(s,c),y&&y.m(s,null),l=!0},p(C,[S]){const A={};S&5&&(A.$$scope={dirty:S,ctx:C}),a.$set(A),y&&y.p&&(!l||S&4)&&sn(y,p,C,C[2],l?on(p,C[2],S,null):ln(C[2]),null)},i(C){l||(L(a.$$.fragment,C),L(y,C),l=!0)},o(C){M(a.$$.fragment,C),M(y,C),l=!1},d(C){C&&B(e),U(a),y&&y.d(C)}}}function Go(o,e,n){let{$$slots:t={},$$scope:r}=e,{message:i}=e;return o.$$set=s=>{"message"in s&&n(0,i=s.message),"$$scope"in s&&n(2,r=s.$$scope)},[i,t,r]}class Ot extends we{constructor(e){super(),_e(this,e,Go,Vo,ye,{message:0})}}function Zo(o){let e,n,t;return{c(){e=O("button"),e.innerHTML='<svg class="flex-shrink-0 size-4" xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><path d="M12 2a3 3 0 0 0-3 3v7a3 3 0 0 0 6 0V5a3 3 0 0 0-3-3Z"></path><path d="M19 10v2a7 7 0 0 1-14 0v-2"></path><line x1="12" x2="12" y1="19" y2="22"></line></svg>',g(e,"type","button"),g(e,"class","inline-flex flex-shrink-0 justify-center items-center size-8 rounded-lg text-gray-500 hover:text-blue-600 focus:z-10 focus:outline-none focus:ring-2 focus:ring-blue-500 dark:hover:text-blue-500 dark:focus:outline-none dark:focus:ring-1 dark:focus:ring-gray-600")},m(r,i){N(r,e,i),n||(t=Le(e,"click",o[1]),n=!0)},p:K,d(r){r&&B(e),n=!1,t()}}}function Uo(o){let e;return{c(){e=O("button"),e.innerHTML='<svg class="flex-shrink-0 size-4" xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><path d="M12 2a3 3 0 0 0-3 3v7a3 3 0 0 0 6 0V5a3 3 0 0 0-3-3Z"></path><path d="M19 10v2a7 7 0 0 1-14 0v-2"></path><line x1="12" x2="12" y1="19" y2="22"></line></svg>',g(e,"type","button"),g(e,"class","animate-ping animate-pulse inline-flex flex-shrink-0 justify-center items-center size-8 rounded-lg text-red-500 hover:text-red-600 focus:z-10 focus:outline-none focus:ring-2 focus:ring-red-500 dark:hover:text-red-500 dark:focus:outline-none dark:focus:ring-1 dark:focus:ring-red-600")},m(n,t){N(n,e,t)},p:K,d(n){n&&B(e)}}}function Qo(o){let e;function n(i,s){return i[0]?Uo:Zo}let t=n(o),r=t(o);return{c(){r.c(),e=ze()},m(i,s){r.m(i,s),N(i,e,s)},p(i,[s]){t===(t=n(i))&&r?r.p(i,s):(r.d(1),r=t(i),r&&(r.c(),r.m(e.parentNode,e)))},i:K,o:K,d(i){i&&B(e),r.d(i)}}}function Wo(o,e,n){let{newMessage:t}=e,r=!1;function i(){if(n(0,r=!0),Rr.set(!0),"webkitSpeechRecognition"in window)var s=new window.webkitSpeechRecognition;else var s=new window.SpeechRecognition;s.lang="en-US",s.start(),s.onresult=a=>{const c=a.results[0][0].transcript;console.log(c),n(2,t=c),n(0,r=!1)},s.onend=()=>{n(0,r=!1)},s.onerror=()=>{n(0,r=!1)}}return o.$$set=s=>{"newMessage"in s&&n(2,t=s.newMessage)},[r,i,t]}class Fo extends we{constructor(e){super(),_e(this,e,Wo,Qo,ye,{newMessage:2})}}function Jo(o){let e,n,t,r,i,s,a,c,l,p,y,C,S,A,E;function b(m){o[5](m)}let d={};return o[0]!==void 0&&(d.newMessage=o[0]),l=new Fo({props:d}),_n.push(()=>lo(l,"newMessage",b)),{c(){e=O("div"),n=O("input"),t=F(),r=O("div"),i=O("div"),s=O("div"),s.innerHTML="",a=F(),c=O("div"),Q(l.$$.fragment),y=F(),C=O("button"),C.innerHTML='<svg class="h-3.5 w-3.5" xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" viewBox="0 0 16 16"><path d="M15.964.686a.5.5 0 0 0-.65-.65L.767 5.855H.766l-.452.18a.5.5 0 0 0-.082.887l.41.26.001.002 4.995 3.178 3.178 4.995.002.002.26.41a.5.5 0 0 0 .886-.083l6-15Zm-1.833 1.89L6.637 10.07l-.215-.338a.5.5 0 0 0-.154-.154l-.338-.215 7.494-7.494 1.178-.471-.47 1.178Z"></path></svg>',g(n,"type","text"),g(n,"class","p-4 pb-12 block w-full bg-gray-100 border-gray-200 rounded-md text-sm focus:border-blue-500 focus:ring-blue-500 dark:bg-slate-800 dark:border-gray-700 dark:text-gray-400"),g(n,"placeholder","Ask me a question about your data that I can turn into SQL."),g(s,"class","flex items-center"),g(C,"type","button"),g(C,"class","inline-flex flex-shrink-0 justify-center items-center h-8 w-8 rounded-md text-white bg-blue-600 hover:bg-blue-500 focus:z-10 focus:outline-none focus:ring-2 focus:ring-blue-500 transition-all"),g(c,"class","flex items-center gap-x-1"),g(i,"class","flex justify-between items-center"),g(r,"class","absolute bottom-px inset-x-px p-2 rounded-b-md bg-gray-100 dark:bg-slate-800"),g(e,"class","relative")},m(m,w){N(m,e,w),_(e,n),mt(n,o[0]),_(e,t),_(e,r),_(r,i),_(i,s),_(i,a),_(i,c),Z(l,c,null),_(c,y),_(c,C),S=!0,A||(E=[Le(n,"input",o[4]),Le(n,"keydown",o[1]),Le(C,"click",o[2])],A=!0)},p(m,[w]){w&1&&n.value!==m[0]&&mt(n,m[0]);const q={};!p&&w&1&&(p=!0,q.newMessage=m[0],oo(()=>p=!1)),l.$set(q)},i(m){S||(L(l.$$.fragment,m),S=!0)},o(m){M(l.$$.fragment,m),S=!1},d(m){m&&B(e),U(l),A=!1,gt(E)}}}function Yo(o,e,n){let{onSubmit:t}=e,r="";function i(l){l.key==="Enter"&&(t(r),l.preventDefault())}function s(){t(r)}function a(){r=this.value,n(0,r)}function c(l){r=l,n(0,r)}return o.$$set=l=>{"onSubmit"in l&&n(3,t=l.onSubmit)},[r,i,s,t,a,c]}class Ko extends we{constructor(e){super(),_e(this,e,Yo,Jo,ye,{onSubmit:3})}}function Xo(o){let e;return{c(){e=O("div"),e.innerHTML='<button type="button" class="p-2 inline-flex justify-center items-center gap-1.5 rounded-md border font-medium bg-white text-gray-700 shadow-sm align-middle hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-offset-white focus:ring-blue-600 transition-all text-xs dark:bg-slate-900 dark:hover:bg-slate-800 dark:border-gray-700 dark:text-gray-400 dark:hover:text-white dark:focus:ring-offset-gray-800" data-hs-overlay="#application-sidebar" aria-controls="application-sidebar" aria-label="Toggle navigation"><svg class="w-3.5 h-3.5" width="16" height="16" fill="currentColor" viewBox="0 0 16 16"><path fill-rule="evenodd" d="M2.5 12a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5zm0-4a.5.5 0 0 1 .5-.5h10a.5.5 0 0 1 0 1H3a.5.5 0 0 1-.5-.5z"></path></svg> <span>Sidebar</span></button>',g(e,"class","lg:hidden flex justify-end mb-2 sm:mb-3")},m(n,t){N(n,e,t)},p:K,i:K,o:K,d(n){n&&B(e)}}}class ei extends we{constructor(e){super(),_e(this,e,null,Xo,ye,{})}}function ti(o){let e,n,t,r;return{c(){e=O("button"),n=ge(o[0]),g(e,"type","button"),g(e,"class","mb-2.5 mr-1.5 py-2 px-3 inline-flex justify-center items-center gap-x-2 rounded-md border border-blue-600 bg-white text-blue-600 align-middle hover:bg-blue-50 text-sm dark:bg-slate-900 dark:text-blue-500 dark:border-blue-500 dark:hover:text-blue-400 dark:hover:border-blue-400")},m(i,s){N(i,e,s),_(e,n),t||(r=Le(e,"click",o[1]),t=!0)},p(i,[s]){s&1&&Ne(n,i[0])},i:K,o:K,d(i){i&&B(e),t=!1,r()}}}function ni(o,e,n){let{message:t}=e,{onSubmit:r}=e;function i(){r(t)}return o.$$set=s=>{"message"in s&&n(0,t=s.message),"onSubmit"in s&&n(2,r=s.onSubmit)},[t,i,r]}class ct extends we{constructor(e){super(),_e(this,e,ni,ti,ye,{message:0,onSubmit:2})}}function ri(o){let e,n,t,r,i,s,a,c,l,p,y;return{c(){e=O("span"),n=Ke("svg"),t=Ke("defs"),r=Ke("linearGradient"),i=Ke("stop"),s=Ke("stop"),a=Ke("g"),c=Ke("g"),l=Ke("path"),p=Ke("path"),g(i,"offset","0"),g(i,"stop-color","#009efd"),g(s,"offset","1"),g(s,"stop-color","#2af598"),g(r,"gradientTransform","matrix(1.09331 0 0 1.09331 -47.1838 -88.8946)"),g(r,"gradientUnits","userSpaceOnUse"),g(r,"id","LinearGradient"),g(r,"x1","237.82"),g(r,"x2","785.097"),g(r,"y1","549.609"),g(r,"y2","549.609"),g(l,"d","M117.718 228.798C117.718 119.455 206.358 30.8151 315.701 30.8151L708.299 30.8151C817.642 30.8151 906.282 119.455 906.282 228.798L906.282 795.202C906.282 904.545 817.642 993.185 708.299 993.185L315.701 993.185C206.358 993.185 117.718 904.545 117.718 795.202L117.718 228.798Z"),g(l,"fill","#0f172a"),g(l,"fill-rule","nonzero"),g(l,"opacity","1"),g(l,"stroke","#374151"),g(l,"stroke-linecap","butt"),g(l,"stroke-linejoin","round"),g(l,"stroke-width","20"),g(p,"d","M212.828 215.239C213.095 281.169 213.629 413.028 213.629 413.028C213.629 413.028 511.51 808.257 513.993 809.681C612.915 677.809 810.759 414.065 810.759 414.065C810.759 414.065 811.034 280.901 811.172 214.319C662.105 362.973 662.105 362.973 513.038 511.627C362.933 363.433 362.933 363.433 212.828 215.239Z"),g(p,"fill","url(#LinearGradient)"),g(p,"fill-rule","nonzero"),g(p,"opacity","1"),g(p,"stroke","none"),g(c,"opacity","1"),g(a,"id","Layer-1"),g(n,"height","100%"),g(n,"stroke-miterlimit","10"),en(n,"fill-rule","nonzero"),en(n,"clip-rule","evenodd"),en(n,"stroke-linecap","round"),en(n,"stroke-linejoin","round"),g(n,"version","1.1"),g(n,"viewBox","0 0 1024 1024"),g(n,"width","100%"),g(n,"xml:space","preserve"),g(n,"xmlns","http://www.w3.org/2000/svg"),g(e,"class",y="flex-shrink-0 w-[2.375rem] h-[2.375rem] "+o[0])},m(C,S){N(C,e,S),_(e,n),_(n,t),_(t,r),_(r,i),_(r,s),_(n,a),_(a,c),_(c,l),_(c,p)},p(C,[S]){S&1&&y!==(y="flex-shrink-0 w-[2.375rem] h-[2.375rem] "+C[0])&&g(e,"class",y)},i:K,o:K,d(C){C&&B(e)}}}function oi(o,e,n){let t,{animate:r=!1}=e;return o.$$set=i=>{"animate"in i&&n(1,r=i.animate)},o.$$.update=()=>{o.$$.dirty&2&&n(0,t=r?"animate-bounce":"")},[t,r]}class Nr extends we{constructor(e){super(),_e(this,e,oi,ri,ye,{animate:1})}}function ii(o){let e,n,t,r,i;n=new Nr({});const s=o[1].default,a=rn(s,o,o[0],null);return{c(){e=O("li"),Q(n.$$.fragment),t=F(),r=O("div"),a&&a.c(),g(r,"class","space-y-3 overflow-x-auto overflow-y-hidden whitespace-break-spaces"),g(e,"class","max-w-4xl py-2 px-4 sm:px-6 lg:px-8 mx-auto flex gap-x-2 sm:gap-x-4")},m(c,l){N(c,e,l),Z(n,e,null),_(e,t),_(e,r),a&&a.m(r,null),i=!0},p(c,[l]){a&&a.p&&(!i||l&1)&&sn(a,s,c,c[0],i?on(s,c[0],l,null):ln(c[0]),null)},i(c){i||(L(n.$$.fragment,c),L(a,c),i=!0)},o(c){M(n.$$.fragment,c),M(a,c),i=!1},d(c){c&&B(e),U(n),a&&a.d(c)}}}function si(o,e,n){let{$$slots:t={},$$scope:r}=e;return o.$$set=i=>{"$$scope"in i&&n(0,r=i.$$scope)},[r,t]}class Xe extends we{constructor(e){super(),_e(this,e,si,ii,ye,{})}}function li(o){let e;return{c(){e=ge("Thinking...")},m(n,t){N(n,e,t)},d(n){n&&B(e)}}}function ai(o){let e,n,t,r,i,s;return n=new Nr({props:{animate:!0}}),i=new ut({props:{$$slots:{default:[li]},$$scope:{ctx:o}}}),{c(){e=O("li"),Q(n.$$.fragment),t=F(),r=O("div"),Q(i.$$.fragment),g(r,"class","space-y-3"),g(e,"class","max-w-4xl py-2 px-4 sm:px-6 lg:px-8 mx-auto flex gap-x-2 sm:gap-x-4")},m(a,c){N(a,e,c),Z(n,e,null),_(e,t),_(e,r),Z(i,r,null),s=!0},p(a,[c]){const l={};c&1&&(l.$$scope={dirty:c,ctx:a}),i.$set(l)},i(a){s||(L(n.$$.fragment,a),L(i.$$.fragment,a),s=!0)},o(a){M(n.$$.fragment,a),M(i.$$.fragment,a),s=!1},d(a){a&&B(e),U(n),U(i)}}}class ci extends we{constructor(e){super(),_e(this,e,null,ai,ye,{})}}function ui(o){let e,n,t,r,i,s,a,c,l,p,y;return{c(){e=O("ul"),n=O("li"),t=O("div"),r=O("span"),r.textContent="CSV",i=F(),s=O("a"),a=Ke("svg"),c=Ke("path"),l=Ke("path"),p=ge(`
          Download`),g(r,"class","mr-3 flex-1 w-0 truncate"),g(c,"d","M.5 9.9a.5.5 0 0 1 .5.5v2.5a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-2.5a.5.5 0 0 1 1 0v2.5a2 2 0 0 1-2 2H2a2 2 0 0 1-2-2v-2.5a.5.5 0 0 1 .5-.5z"),g(l,"d","M7.646 11.854a.5.5 0 0 0 .708 0l3-3a.5.5 0 0 0-.708-.708L8.5 10.293V1.5a.5.5 0 0 0-1 0v8.793L5.354 8.146a.5.5 0 1 0-.708.708l3 3z"),g(a,"class","flex-shrink-0 w-3 h-3"),g(a,"width","16"),g(a,"height","16"),g(a,"viewBox","0 0 16 16"),g(a,"fill","currentColor"),g(s,"class","flex items-center gap-x-2 text-gray-500 hover:text-blue-500 whitespace-nowrap"),g(s,"href",y="/api/v0/download_csv?id="+o[0]),g(t,"class","w-full flex justify-between truncate"),g(n,"class","flex items-center gap-x-2 p-3 text-sm bg-white border text-gray-800 first:rounded-t-lg first:mt-0 last:rounded-b-lg dark:bg-slate-900 dark:border-gray-700 dark:text-gray-200"),g(e,"class","flex flex-col justify-end text-start -space-y-px")},m(C,S){N(C,e,S),_(e,n),_(n,t),_(t,r),_(t,i),_(t,s),_(s,a),_(a,c),_(a,l),_(s,p)},p(C,[S]){S&1&&y!==(y="/api/v0/download_csv?id="+C[0])&&g(s,"href",y)},i:K,o:K,d(C){C&&B(e)}}}function fi(o,e,n){let{id:t}=e;return o.$$set=r=>{"id"in r&&n(0,t=r.id)},[t]}class di extends we{constructor(e){super(),_e(this,e,fi,ui,ye,{id:0})}}function Jn(o,e,n){const t=o.slice();return t[5]=e[n],t}function Yn(o,e,n){const t=o.slice();return t[8]=e[n],t}function Kn(o,e,n){const t=o.slice();return t[8]=e[n],t}function Xn(o){let e,n,t,r;return{c(){e=O("th"),n=O("div"),t=O("span"),t.textContent=`${o[8]}`,r=F(),g(t,"class","text-xs font-semibold uppercase tracking-wide text-gray-800 dark:text-gray-200"),g(n,"class","flex items-center gap-x-2"),g(e,"scope","col"),g(e,"class","px-6 py-3 text-left")},m(i,s){N(i,e,s),_(e,n),_(n,t),_(e,r)},p:K,d(i){i&&B(e)}}}function er(o){let e,n,t;return{c(){e=O("td"),n=O("div"),t=O("span"),t.textContent=`${o[5][o[8]]}`,g(t,"class","text-gray-800 dark:text-gray-200"),g(n,"class","px-6 py-3"),g(e,"class","h-px w-px whitespace-nowrap")},m(r,i){N(r,e,i),_(e,n),_(n,t)},p:K,d(r){r&&B(e)}}}function tr(o){let e,n,t=xe(o[3]),r=[];for(let i=0;i<t.length;i+=1)r[i]=er(Yn(o,t,i));return{c(){e=O("tr");for(let i=0;i<r.length;i+=1)r[i].c();n=F()},m(i,s){N(i,e,s);for(let a=0;a<r.length;a+=1)r[a]&&r[a].m(e,null);_(e,n)},p(i,s){if(s&12){t=xe(i[3]);let a;for(a=0;a<t.length;a+=1){const c=Yn(i,t,a);r[a]?r[a].p(c,s):(r[a]=er(c),r[a].c(),r[a].m(e,n))}for(;a<r.length;a+=1)r[a].d(1);r.length=t.length}},d(i){i&&B(e),tt(r,i)}}}function nr(o){let e,n;return e=new di({props:{id:o[0]}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&1&&(i.id=t[0]),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function pi(o){let e,n,t,r,i,s,a,c,l,p,y,C=xe(o[3]),S=[];for(let d=0;d<C.length;d+=1)S[d]=Xn(Kn(o,C,d));let A=xe(o[2]),E=[];for(let d=0;d<A.length;d+=1)E[d]=tr(Jn(o,A,d));let b=o[1].csv_download&&nr(o);return{c(){e=O("div"),n=O("div"),t=O("div"),r=O("table"),i=O("thead"),s=O("tr");for(let d=0;d<S.length;d+=1)S[d].c();a=F(),c=O("tbody");for(let d=0;d<E.length;d+=1)E[d].c();l=F(),b&&b.c(),p=ze(),g(i,"class","bg-gray-50 dark:bg-slate-800"),g(c,"class","divide-y divide-gray-200 dark:divide-gray-700"),g(r,"class","min-w-full divide-y divide-gray-200 dark:divide-gray-700"),g(t,"class","p-1.5 min-w-full inline-block align-middle"),g(n,"class","-m-1.5 overflow-x-auto"),g(e,"class","bg-white border border-gray-200 rounded-xl shadow-sm overflow-hidden dark:bg-slate-900 dark:border-gray-700")},m(d,m){N(d,e,m),_(e,n),_(n,t),_(t,r),_(r,i),_(i,s);for(let w=0;w<S.length;w+=1)S[w]&&S[w].m(s,null);_(r,a),_(r,c);for(let w=0;w<E.length;w+=1)E[w]&&E[w].m(c,null);N(d,l,m),b&&b.m(d,m),N(d,p,m),y=!0},p(d,[m]){if(m&8){C=xe(d[3]);let w;for(w=0;w<C.length;w+=1){const q=Kn(d,C,w);S[w]?S[w].p(q,m):(S[w]=Xn(q),S[w].c(),S[w].m(s,null))}for(;w<S.length;w+=1)S[w].d(1);S.length=C.length}if(m&12){A=xe(d[2]);let w;for(w=0;w<A.length;w+=1){const q=Jn(d,A,w);E[w]?E[w].p(q,m):(E[w]=tr(q),E[w].c(),E[w].m(c,null))}for(;w<E.length;w+=1)E[w].d(1);E.length=A.length}d[1].csv_download?b?(b.p(d,m),m&2&&L(b,1)):(b=nr(d),b.c(),L(b,1),b.m(p.parentNode,p)):b&&(je(),M(b,1,1,()=>{b=null}),Pe())},i(d){y||(L(b),y=!0)},o(d){M(b),y=!1},d(d){d&&(B(e),B(l),B(p)),tt(S,d),tt(E,d),b&&b.d(d)}}}function mi(o,e,n){let t;et(o,St,c=>n(1,t=c));let{id:r}=e,{df:i}=e,s=JSON.parse(i),a=s.length>0?Object.keys(s[0]):[];return o.$$set=c=>{"id"in c&&n(0,r=c.id),"df"in c&&n(4,i=c.df)},[r,t,s,a,i]}class Ir extends we{constructor(e){super(),_e(this,e,mi,pi,ye,{id:0,df:4})}}function gi(o){let e;return{c(){e=O("div"),g(e,"id",o[0])},m(n,t){N(n,e,t)},p:K,i:K,o:K,d(n){n&&B(e)}}}function hi(o,e,n){let{fig:t}=e,r=JSON.parse(t),i=Math.random().toString(36).substring(2,15)+Math.random().toString(36).substring(2,15);return Mr(()=>{Plotly.newPlot(document.getElementById(i),r,{responsive:!0})}),o.$$set=s=>{"fig"in s&&n(1,t=s.fig)},[i,t]}class zr extends we{constructor(e){super(),_e(this,e,hi,gi,ye,{fig:1})}}function yi(o){let e,n,t,r;return{c(){e=O("button"),n=ge(o[0]),g(e,"type","button"),g(e,"class","mb-2.5 mr-1.5 py-3 px-4 inline-flex justify-center items-center gap-2 rounded-md border-2 border-green-200 font-semibold text-green-500 hover:text-white hover:bg-green-500 hover:border-green-500 focus:outline-none focus:ring-2 focus:ring-green-200 focus:ring-offset-2 transition-all text-sm dark:focus:ring-offset-gray-800")},m(i,s){N(i,e,s),_(e,n),t||(r=Le(e,"click",o[1]),t=!0)},p(i,[s]){s&1&&Ne(n,i[0])},i:K,o:K,d(i){i&&B(e),t=!1,r()}}}function bi(o,e,n){let{message:t}=e,{onSubmit:r}=e;function i(){r(t)}return o.$$set=s=>{"message"in s&&n(0,t=s.message),"onSubmit"in s&&n(2,r=s.onSubmit)},[t,i,r]}class Vr extends we{constructor(e){super(),_e(this,e,bi,yi,ye,{message:0,onSubmit:2})}}function vi(o){let e,n,t,r,i,s,a,c,l;return{c(){e=O("div"),n=O("div"),t=O("div"),t.innerHTML='<svg class="h-4 w-4 text-yellow-400 mt-0.5" xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" viewBox="0 0 16 16"><path d="M8.982 1.566a1.13 1.13 0 0 0-1.96 0L.165 13.233c-.457.778.091 1.767.98 1.767h13.713c.889 0 1.438-.99.98-1.767L8.982 1.566zM8 5c.535 0 .954.462.9.995l-.35 3.507a.552.552 0 0 1-1.1 0L7.1 5.995A.905.905 0 0 1 8 5zm.002 6a1 1 0 1 1 0 2 1 1 0 0 1 0-2z"></path></svg>',r=F(),i=O("div"),s=O("h3"),s.textContent="Error",a=F(),c=O("div"),l=ge(o[0]),g(t,"class","flex-shrink-0"),g(s,"class","text-sm text-yellow-800 font-semibold"),g(c,"class","mt-1 text-sm text-yellow-700"),g(i,"class","ml-4"),g(n,"class","flex"),g(e,"class","bg-yellow-50 border border-yellow-200 rounded-md p-4"),g(e,"role","alert")},m(p,y){N(p,e,y),_(e,n),_(n,t),_(n,r),_(n,i),_(i,s),_(i,a),_(i,c),_(c,l)},p(p,[y]){y&1&&Ne(l,p[0])},i:K,o:K,d(p){p&&B(e)}}}function _i(o,e,n){let{message:t}=e;return o.$$set=r=>{"message"in r&&n(0,t=r.message)},[t]}let Cn=class extends we{constructor(e){super(),_e(this,e,_i,vi,ye,{message:0})}};function wi(o){let e,n;const t=o[1].default,r=rn(t,o,o[0],null);return{c(){e=O("div"),r&&r.c(),g(e,"class","font-mono whitespace-pre-wrap")},m(i,s){N(i,e,s),r&&r.m(e,null),n=!0},p(i,[s]){r&&r.p&&(!n||s&1)&&sn(r,t,i,i[0],n?on(t,i[0],s,null):ln(i[0]),null)},i(i){n||(L(r,i),n=!0)},o(i){M(r,i),n=!1},d(i){i&&B(e),r&&r.d(i)}}}function $i(o,e,n){let{$$slots:t={},$$scope:r}=e;return o.$$set=i=>{"$$scope"in i&&n(0,r=i.$$scope)},[r,t]}class Gr extends we{constructor(e){super(),_e(this,e,$i,wi,ye,{})}}function ki(o){let e;return{c(){e=ge(o[1])},m(n,t){N(n,e,t)},p(n,t){t&2&&Ne(e,n[1])},d(n){n&&B(e)}}}function xi(o){let e,n,t,r,i,s,a,c;return t=new ct({props:{message:"Run SQL",onSubmit:o[3]}}),i=new ut({props:{$$slots:{default:[ki]},$$scope:{ctx:o}}}),{c(){e=O("textarea"),n=F(),Q(t.$$.fragment),r=F(),Q(i.$$.fragment),g(e,"rows","6"),g(e,"class","block p-2.5 w-full text-blue-600 hover:text-blue-500 dark:text-blue-500 dark:hover:text-blue-400 bg-gray-50 rounded-lg border border-gray-300 focus:ring-blue-500 focus:border-blue-500 dark:bg-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:focus:ring-blue-500 dark:focus:border-blue-500 font-mono"),g(e,"placeholder","SELECT col1, col2, col3 FROM ...")},m(l,p){N(l,e,p),mt(e,o[1]),N(l,n,p),Z(t,l,p),N(l,r,p),Z(i,l,p),s=!0,a||(c=Le(e,"input",o[2]),a=!0)},p(l,[p]){p&2&&mt(e,l[1]);const y={};p&3&&(y.onSubmit=l[3]),t.$set(y);const C={};p&18&&(C.$$scope={dirty:p,ctx:l}),i.$set(C)},i(l){s||(L(t.$$.fragment,l),L(i.$$.fragment,l),s=!0)},o(l){M(t.$$.fragment,l),M(i.$$.fragment,l),s=!1},d(l){l&&(B(e),B(n),B(r)),U(t,l),U(i,l),a=!1,c()}}}function Si(o,e,n){let t;et(o,Qt,a=>n(1,t=a));let{onSubmit:r}=e;function i(){t=this.value,Qt.set(t)}const s=()=>r(t);return o.$$set=a=>{"onSubmit"in a&&n(0,r=a.onSubmit)},[r,t,i,s]}class Oi extends we{constructor(e){super(),_e(this,e,Si,xi,ye,{onSubmit:0})}}function Ci(o){let e,n,t,r,i,s;return t=new ct({props:{message:o[3],onSubmit:o[5]}}),{c(){e=O("textarea"),n=F(),Q(t.$$.fragment),g(e,"rows","6"),g(e,"class","block p-2.5 w-full text-blue-600 hover:text-blue-500 dark:text-blue-500 dark:hover:text-blue-400 bg-gray-50 rounded-lg border border-gray-300 focus:ring-blue-500 focus:border-blue-500 dark:bg-gray-700 dark:border-gray-600 dark:placeholder-gray-400 dark:focus:ring-blue-500 dark:focus:border-blue-500 font-mono"),g(e,"placeholder",o[2])},m(a,c){N(a,e,c),mt(e,o[0]),N(a,n,c),Z(t,a,c),r=!0,i||(s=Le(e,"input",o[4]),i=!0)},p(a,[c]){(!r||c&4)&&g(e,"placeholder",a[2]),c&1&&mt(e,a[0]);const l={};c&8&&(l.message=a[3]),c&3&&(l.onSubmit=a[5]),t.$set(l)},i(a){r||(L(t.$$.fragment,a),r=!0)},o(a){M(t.$$.fragment,a),r=!1},d(a){a&&(B(e),B(n)),U(t,a),i=!1,s()}}}function Li(o,e,n){let{onSubmit:t}=e,{currentValue:r}=e,{placeholder:i}=e,{buttonText:s}=e;function a(){r=this.value,n(0,r)}const c=()=>t(r);return o.$$set=l=>{"onSubmit"in l&&n(1,t=l.onSubmit),"currentValue"in l&&n(0,r=l.currentValue),"placeholder"in l&&n(2,i=l.placeholder),"buttonText"in l&&n(3,s=l.buttonText)},[r,t,i,s,a,c]}class Ei extends we{constructor(e){super(),_e(this,e,Li,Ci,ye,{onSubmit:1,currentValue:0,placeholder:2,buttonText:3})}}function Ti(o){let e,n;return e=new ct({props:{message:"Play",onSubmit:o[2]}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,[r]){const i={};r&1&&(i.onSubmit=t[2]),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function rr(o){if("speechSynthesis"in window){const e=new SpeechSynthesisUtterance(o);e.lang="en-US",e.volume=1,e.rate=1,e.pitch=1,window.speechSynthesis.speak(e)}else console.error("SpeechSynthesis API is not supported in this browser.")}function ji(o,e,n){let t;et(o,Rr,s=>n(1,t=s));let{message:r}=e;const i=()=>rr(r);return o.$$set=s=>{"message"in s&&n(0,r=s.message)},o.$$.update=()=>{o.$$.dirty&3&&t&&rr(r)},[r,t,i]}class Pi extends we{constructor(e){super(),_e(this,e,ji,Ti,ye,{message:0})}}function or(o,e,n){const t=o.slice();return t[11]=e[n],t}function ir(o,e,n){const t=o.slice();return t[14]=e[n],t}function sr(o,e,n){const t=o.slice();return t[17]=e[n],t}function lr(o,e,n){const t=o.slice();return t[17]=e[n],t}function ar(o){let e,n;return e=new Xe({props:{$$slots:{default:[Ai]},$$scope:{ctx:o}}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4194305&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function cr(o){let e,n;return e=new ct({props:{message:o[17],onSubmit:On}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&1&&(i.message=t[17]),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function qi(o){let e=o[0].header+"",n,t,r,i,s=xe(o[0].questions),a=[];for(let l=0;l<s.length;l+=1)a[l]=cr(lr(o,s,l));const c=l=>M(a[l],1,1,()=>{a[l]=null});return{c(){n=ge(e),t=F();for(let l=0;l<a.length;l+=1)a[l].c();r=ze()},m(l,p){N(l,n,p),N(l,t,p);for(let y=0;y<a.length;y+=1)a[y]&&a[y].m(l,p);N(l,r,p),i=!0},p(l,p){if((!i||p&1)&&e!==(e=l[0].header+"")&&Ne(n,e),p&1){s=xe(l[0].questions);let y;for(y=0;y<s.length;y+=1){const C=lr(l,s,y);a[y]?(a[y].p(C,p),L(a[y],1)):(a[y]=cr(C),a[y].c(),L(a[y],1),a[y].m(r.parentNode,r))}for(je(),y=s.length;y<a.length;y+=1)c(y);Pe()}},i(l){if(!i){for(let p=0;p<s.length;p+=1)L(a[p]);i=!0}},o(l){a=a.filter(Boolean);for(let p=0;p<a.length;p+=1)M(a[p]);i=!1},d(l){l&&(B(n),B(t),B(r)),tt(a,l)}}}function Ai(o){let e,n;return e=new ut({props:{$$slots:{default:[qi]},$$scope:{ctx:o}}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4194305&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function Mi(o){let e,n;return e=new Xe({props:{$$slots:{default:[Ki]},$$scope:{ctx:o}}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4194308&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function Di(o){let e,n;return e=new Xe({props:{$$slots:{default:[es]},$$scope:{ctx:o}}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4194308&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function Ri(o){let e,n;return e=new Ot({props:{message:"Put your SQL here",$$slots:{default:[ts]},$$scope:{ctx:o}}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4194304&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function Hi(o){let e,n,t,r,i,s,a,c;return e=new Ot({props:{message:o[14].question}}),t=new Xe({props:{$$slots:{default:[os]},$$scope:{ctx:o}}}),i=new Xe({props:{$$slots:{default:[is]},$$scope:{ctx:o}}}),a=new Xe({props:{$$slots:{default:[ss]},$$scope:{ctx:o}}}),{c(){Q(e.$$.fragment),n=F(),Q(t.$$.fragment),r=F(),Q(i.$$.fragment),s=F(),Q(a.$$.fragment)},m(l,p){Z(e,l,p),N(l,n,p),Z(t,l,p),N(l,r,p),Z(i,l,p),N(l,s,p),Z(a,l,p),c=!0},p(l,p){const y={};p&4&&(y.message=l[14].question),e.$set(y);const C={};p&4194308&&(C.$$scope={dirty:p,ctx:l}),t.$set(C);const S={};p&4194308&&(S.$$scope={dirty:p,ctx:l}),i.$set(S);const A={};p&4194308&&(A.$$scope={dirty:p,ctx:l}),a.$set(A)},i(l){c||(L(e.$$.fragment,l),L(t.$$.fragment,l),L(i.$$.fragment,l),L(a.$$.fragment,l),c=!0)},o(l){M(e.$$.fragment,l),M(t.$$.fragment,l),M(i.$$.fragment,l),M(a.$$.fragment,l),c=!1},d(l){l&&(B(n),B(r),B(s)),U(e,l),U(t,l),U(i,l),U(a,l)}}}function Bi(o){let e,n;return e=new Xe({props:{$$slots:{default:[ls]},$$scope:{ctx:o}}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4194316&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function Ni(o){let e,n;return e=new Xe({props:{$$slots:{default:[as]},$$scope:{ctx:o}}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4194308&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function Ii(o){let e,n;return e=new Ot({props:{message:"No, the results were not correct."}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p:K,i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function zi(o){let e,n;return e=new Ot({props:{message:"Yes, the results were correct."}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p:K,i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function Vi(o){let e,n,t=o[3].ask_results_correct&&fr(o);return{c(){t&&t.c(),e=ze()},m(r,i){t&&t.m(r,i),N(r,e,i),n=!0},p(r,i){r[3].ask_results_correct?t?i&8&&L(t,1):(t=fr(r),t.c(),L(t,1),t.m(e.parentNode,e)):t&&(je(),M(t,1,1,()=>{t=null}),Pe())},i(r){n||(L(t),n=!0)},o(r){M(t),n=!1},d(r){r&&B(e),t&&t.d(r)}}}function Gi(o){let e,n,t=o[3].ask_results_correct&&dr(o);return{c(){t&&t.c(),e=ze()},m(r,i){t&&t.m(r,i),N(r,e,i),n=!0},p(r,i){r[3].ask_results_correct?t?i&8&&L(t,1):(t=dr(r),t.c(),L(t,1),t.m(e.parentNode,e)):t&&(je(),M(t,1,1,()=>{t=null}),Pe())},i(r){n||(L(t),n=!0)},o(r){M(t),n=!1},d(r){r&&B(e),t&&t.d(r)}}}function Zi(o){let e,n;return e=new Ot({props:{message:"Change the chart based on these instructions",$$slots:{default:[ds]},$$scope:{ctx:o}}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4194304&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function Ui(o){let e,n,t=o[3].chart&&pr(o);return{c(){t&&t.c(),e=ze()},m(r,i){t&&t.m(r,i),N(r,e,i),n=!0},p(r,i){r[3].chart?t?(t.p(r,i),i&8&&L(t,1)):(t=pr(r),t.c(),L(t,1),t.m(e.parentNode,e)):t&&(je(),M(t,1,1,()=>{t=null}),Pe())},i(r){n||(L(t),n=!0)},o(r){M(t),n=!1},d(r){r&&B(e),t&&t.d(r)}}}function Qi(o){let e,n,t=o[3].table&&gr(o);return{c(){t&&t.c(),e=ze()},m(r,i){t&&t.m(r,i),N(r,e,i),n=!0},p(r,i){r[3].table?t?(t.p(r,i),i&8&&L(t,1)):(t=gr(r),t.c(),L(t,1),t.m(e.parentNode,e)):t&&(je(),M(t,1,1,()=>{t=null}),Pe())},i(r){n||(L(t),n=!0)},o(r){M(t),n=!1},d(r){r&&B(e),t&&t.d(r)}}}function Wi(o){let e,n;return e=new Xe({props:{$$slots:{default:[ys]},$$scope:{ctx:o}}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4194308&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function Fi(o){let e,n,t=o[3].sql==!0&&yr(o);return{c(){t&&t.c(),e=ze()},m(r,i){t&&t.m(r,i),N(r,e,i),n=!0},p(r,i){r[3].sql==!0?t?(t.p(r,i),i&8&&L(t,1)):(t=yr(r),t.c(),L(t,1),t.m(e.parentNode,e)):t&&(je(),M(t,1,1,()=>{t=null}),Pe())},i(r){n||(L(t),n=!0)},o(r){M(t),n=!1},d(r){r&&B(e),t&&t.d(r)}}}function Ji(o){let e,n;return e=new Ot({props:{message:o[14].question}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4&&(i.message=t[14].question),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function Yi(o){let e=JSON.stringify(o[14])+"",n;return{c(){n=ge(e)},m(t,r){N(t,n,r)},p(t,r){r&4&&e!==(e=JSON.stringify(t[14])+"")&&Ne(n,e)},d(t){t&&B(n)}}}function Ki(o){let e,n;return e=new ut({props:{$$slots:{default:[Yi]},$$scope:{ctx:o}}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4194308&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function Xi(o){let e=o[14].text+"",n;return{c(){n=ge(e)},m(t,r){N(t,n,r)},p(t,r){r&4&&e!==(e=t[14].text+"")&&Ne(n,e)},d(t){t&&B(n)}}}function es(o){let e,n,t,r;return e=new ut({props:{$$slots:{default:[Xi]},$$scope:{ctx:o}}}),t=new Pi({props:{message:o[14].text}}),{c(){Q(e.$$.fragment),n=F(),Q(t.$$.fragment)},m(i,s){Z(e,i,s),N(i,n,s),Z(t,i,s),r=!0},p(i,s){const a={};s&4194308&&(a.$$scope={dirty:s,ctx:i}),e.$set(a);const c={};s&4&&(c.message=i[14].text),t.$set(c)},i(i){r||(L(e.$$.fragment,i),L(t.$$.fragment,i),r=!0)},o(i){M(e.$$.fragment,i),M(t.$$.fragment,i),r=!1},d(i){i&&B(n),U(e,i),U(t,i)}}}function ts(o){let e,n;return e=new Oi({props:{onSubmit:Co}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p:K,i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function ns(o){let e=o[14].sql+"",n;return{c(){n=ge(e)},m(t,r){N(t,n,r)},p(t,r){r&4&&e!==(e=t[14].sql+"")&&Ne(n,e)},d(t){t&&B(n)}}}function rs(o){let e,n;return e=new Gr({props:{$$slots:{default:[ns]},$$scope:{ctx:o}}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4194308&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function os(o){let e,n;return e=new ut({props:{$$slots:{default:[rs]},$$scope:{ctx:o}}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4194308&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function is(o){let e,n;return e=new Ir({props:{id:o[14].id,df:o[14].df}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4&&(i.id=t[14].id),r&4&&(i.df=t[14].df),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function ss(o){let e,n;return e=new zr({props:{fig:o[14].fig}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4&&(i.fig=t[14].fig),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function ur(o){let e,n;function t(){return o[9](o[14])}return e=new ct({props:{message:"Auto Fix",onSubmit:t}}),{c(){Q(e.$$.fragment)},m(r,i){Z(e,r,i),n=!0},p(r,i){o=r;const s={};i&4&&(s.onSubmit=t),e.$set(s)},i(r){n||(L(e.$$.fragment,r),n=!0)},o(r){M(e.$$.fragment,r),n=!1},d(r){U(e,r)}}}function ls(o){let e,n,t,r,i,s;e=new Cn({props:{message:o[14].error}}),t=new ct({props:{message:"Manually Fix",onSubmit:o[8]}});let a=o[3].auto_fix_sql&&ur(o);return{c(){Q(e.$$.fragment),n=F(),Q(t.$$.fragment),r=F(),a&&a.c(),i=ze()},m(c,l){Z(e,c,l),N(c,n,l),Z(t,c,l),N(c,r,l),a&&a.m(c,l),N(c,i,l),s=!0},p(c,l){const p={};l&4&&(p.message=c[14].error),e.$set(p),c[3].auto_fix_sql?a?(a.p(c,l),l&8&&L(a,1)):(a=ur(c),a.c(),L(a,1),a.m(i.parentNode,i)):a&&(je(),M(a,1,1,()=>{a=null}),Pe())},i(c){s||(L(e.$$.fragment,c),L(t.$$.fragment,c),L(a),s=!0)},o(c){M(e.$$.fragment,c),M(t.$$.fragment,c),M(a),s=!1},d(c){c&&(B(n),B(r),B(i)),U(e,c),U(t,c),a&&a.d(c)}}}function as(o){let e,n;return e=new Cn({props:{message:o[14].error}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4&&(i.message=t[14].error),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function fr(o){let e,n;return e=new Ot({props:{message:"",$$slots:{default:[cs]},$$scope:{ctx:o}}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function cs(o){let e,n,t,r;return e=new ct({props:{message:"Yes",onSubmit:o[6]}}),t=new ct({props:{message:"No",onSubmit:o[7]}}),{c(){Q(e.$$.fragment),n=F(),Q(t.$$.fragment)},m(i,s){Z(e,i,s),N(i,n,s),Z(t,i,s),r=!0},p:K,i(i){r||(L(e.$$.fragment,i),L(t.$$.fragment,i),r=!0)},o(i){M(e.$$.fragment,i),M(t.$$.fragment,i),r=!1},d(i){i&&B(n),U(e,i),U(t,i)}}}function dr(o){let e,n;return e=new Xe({props:{$$slots:{default:[fs]},$$scope:{ctx:o}}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function us(o){let e;return{c(){e=ge("Were the results correct?")},m(n,t){N(n,e,t)},d(n){n&&B(e)}}}function fs(o){let e,n;return e=new ut({props:{$$slots:{default:[us]},$$scope:{ctx:o}}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4194304&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function ds(o){let e,n;return e=new Ei({props:{onSubmit:o[5],placeholder:"Make the line red",buttonText:"Update Chart",currentValue:""}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p:K,i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function pr(o){let e,n,t,r;e=new Xe({props:{$$slots:{default:[ps]},$$scope:{ctx:o}}});let i=o[3].redraw_chart&&mr(o);return{c(){Q(e.$$.fragment),n=F(),i&&i.c(),t=ze()},m(s,a){Z(e,s,a),N(s,n,a),i&&i.m(s,a),N(s,t,a),r=!0},p(s,a){const c={};a&4194308&&(c.$$scope={dirty:a,ctx:s}),e.$set(c),s[3].redraw_chart?i?a&8&&L(i,1):(i=mr(s),i.c(),L(i,1),i.m(t.parentNode,t)):i&&(je(),M(i,1,1,()=>{i=null}),Pe())},i(s){r||(L(e.$$.fragment,s),L(i),r=!0)},o(s){M(e.$$.fragment,s),M(i),r=!1},d(s){s&&(B(n),B(t)),U(e,s),i&&i.d(s)}}}function ps(o){let e,n;return e=new zr({props:{fig:o[14].fig}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4&&(i.fig=t[14].fig),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function mr(o){let e,n;return e=new Xe({props:{$$slots:{default:[ms]},$$scope:{ctx:o}}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function ms(o){let e,n;return e=new ct({props:{message:"Redraw Chart",onSubmit:Lo}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p:K,i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function gr(o){let e,n;return e=new Xe({props:{$$slots:{default:[gs]},$$scope:{ctx:o}}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4194308&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function gs(o){let e,n;return e=new Ir({props:{id:o[14].id,df:o[14].df}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4&&(i.id=t[14].id),r&4&&(i.df=t[14].df),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function hr(o){let e,n;return e=new ct({props:{message:o[17],onSubmit:On}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4&&(i.message=t[17]),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function hs(o){let e=o[14].header+"",n,t,r,i,s=xe(o[14].questions),a=[];for(let l=0;l<s.length;l+=1)a[l]=hr(sr(o,s,l));const c=l=>M(a[l],1,1,()=>{a[l]=null});return{c(){n=ge(e),t=F();for(let l=0;l<a.length;l+=1)a[l].c();r=ze()},m(l,p){N(l,n,p),N(l,t,p);for(let y=0;y<a.length;y+=1)a[y]&&a[y].m(l,p);N(l,r,p),i=!0},p(l,p){if((!i||p&4)&&e!==(e=l[14].header+"")&&Ne(n,e),p&4){s=xe(l[14].questions);let y;for(y=0;y<s.length;y+=1){const C=sr(l,s,y);a[y]?(a[y].p(C,p),L(a[y],1)):(a[y]=hr(C),a[y].c(),L(a[y],1),a[y].m(r.parentNode,r))}for(je(),y=s.length;y<a.length;y+=1)c(y);Pe()}},i(l){if(!i){for(let p=0;p<s.length;p+=1)L(a[p]);i=!0}},o(l){a=a.filter(Boolean);for(let p=0;p<a.length;p+=1)M(a[p]);i=!1},d(l){l&&(B(n),B(t),B(r)),tt(a,l)}}}function ys(o){let e,n;return e=new ut({props:{$$slots:{default:[hs]},$$scope:{ctx:o}}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4194308&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function yr(o){let e,n;return e=new Xe({props:{$$slots:{default:[_s]},$$scope:{ctx:o}}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4194308&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function bs(o){let e,n;return e=new po({props:{text:o[14].text}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4&&(i.text=t[14].text),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function vs(o){let e,n;return e=new Gr({props:{$$slots:{default:[bs]},$$scope:{ctx:o}}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4194308&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function _s(o){let e,n;return e=new ut({props:{$$slots:{default:[vs]},$$scope:{ctx:o}}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&4194308&&(i.$$scope={dirty:r,ctx:t}),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function br(o){let e,n,t,r;const i=[Ji,Fi,Wi,Qi,Ui,Zi,Gi,Vi,zi,Ii,Ni,Bi,Hi,Ri,Di,Mi],s=[];function a(c,l){return c[14].type==="user_question"?0:c[14].type==="sql"?1:c[14].type==="question_list"?2:c[14].type==="df"?3:c[14].type==="plotly_figure"?4:c[14].type==="chart_modification"?5:c[14].type==="feedback_question"?6:c[14].type==="feedback_buttons"?7:c[14].type==="feedback_correct"?8:c[14].type==="feedback_incorrect"?9:c[14].type==="error"?10:c[14].type==="sql_error"?11:c[14].type==="question_cache"?12:c[14].type==="user_sql"?13:c[14].type==="text"?14:15}return e=a(o),n=s[e]=i[e](o),{c(){n.c(),t=ze()},m(c,l){s[e].m(c,l),N(c,t,l),r=!0},p(c,l){let p=e;e=a(c),e===p?s[e].p(c,l):(je(),M(s[p],1,1,()=>{s[p]=null}),Pe(),n=s[e],n?n.p(c,l):(n=s[e]=i[e](c),n.c()),L(n,1),n.m(t.parentNode,t))},i(c){r||(L(n),r=!0)},o(c){M(n),r=!1},d(c){c&&B(t),s[e].d(c)}}}function vr(o){let e,n;return e=new ci({}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function ws(o){let e,n;return e=new Ko({props:{onSubmit:On}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p:K,i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function $s(o){let e,n,t,r;e=new Vr({props:{message:"New Question",onSubmit:un}});let i=xe(o[2]),s=[];for(let c=0;c<i.length;c+=1)s[c]=wr(or(o,i,c));const a=c=>M(s[c],1,1,()=>{s[c]=null});return{c(){Q(e.$$.fragment),n=F();for(let c=0;c<s.length;c+=1)s[c].c();t=ze()},m(c,l){Z(e,c,l),N(c,n,l);for(let p=0;p<s.length;p+=1)s[p]&&s[p].m(c,l);N(c,t,l),r=!0},p(c,l){if(l&4){i=xe(c[2]);let p;for(p=0;p<i.length;p+=1){const y=or(c,i,p);s[p]?(s[p].p(y,l),L(s[p],1)):(s[p]=wr(y),s[p].c(),L(s[p],1),s[p].m(t.parentNode,t))}for(je(),p=i.length;p<s.length;p+=1)a(p);Pe()}},i(c){if(!r){L(e.$$.fragment,c);for(let l=0;l<i.length;l+=1)L(s[l]);r=!0}},o(c){M(e.$$.fragment,c),s=s.filter(Boolean);for(let l=0;l<s.length;l+=1)M(s[l]);r=!1},d(c){c&&(B(n),B(t)),U(e,c),tt(s,c)}}}function _r(o){let e,n;function t(){return o[10](o[11])}return e=new Vr({props:{message:"Re-Run SQL",onSubmit:t}}),{c(){Q(e.$$.fragment)},m(r,i){Z(e,r,i),n=!0},p(r,i){o=r;const s={};i&4&&(s.onSubmit=t),e.$set(s)},i(r){n||(L(e.$$.fragment,r),n=!0)},o(r){M(e.$$.fragment,r),n=!1},d(r){U(e,r)}}}function wr(o){let e,n,t=o[11].type==="question_cache"&&_r(o);return{c(){t&&t.c(),e=ze()},m(r,i){t&&t.m(r,i),N(r,e,i),n=!0},p(r,i){r[11].type==="question_cache"?t?(t.p(r,i),i&4&&L(t,1)):(t=_r(r),t.c(),L(t,1),t.m(e.parentNode,e)):t&&(je(),M(t,1,1,()=>{t=null}),Pe())},i(r){n||(L(t),n=!0)},o(r){M(t),n=!1},d(r){r&&B(e),t&&t.d(r)}}}function ks(o){let e,n,t,r,i,s,a,c,l,p,y,C,S,A;t=new Bo({});let E=o[0]&&o[0].type=="question_list"&&!o[1]&&ar(o),b=xe(o[2]),d=[];for(let u=0;u<b.length;u+=1)d[u]=br(ir(o,b,u));const m=u=>M(d[u],1,1,()=>{d[u]=null});let w=o[4]&&vr();p=new ei({});const q=[$s,ws],R=[];function T(u,f){return u[1]?0:1}return C=T(o),S=R[C]=q[C](o),{c(){e=O("div"),n=O("div"),Q(t.$$.fragment),r=F(),E&&E.c(),i=F(),s=O("ul");for(let u=0;u<d.length;u+=1)d[u].c();a=F(),w&&w.c(),c=F(),l=O("footer"),Q(p.$$.fragment),y=F(),S.c(),g(s,"class","mt-16 space-y-5"),g(n,"class","py-10 lg:py-14"),g(l,"class","max-w-4xl mx-auto sticky bottom-0 z-10 p-3 sm:py-6"),g(e,"class","relative h-screen w-full lg:pl-64")},m(u,f){N(u,e,f),_(e,n),Z(t,n,null),_(n,r),E&&E.m(n,null),_(n,i),_(n,s);for(let x=0;x<d.length;x+=1)d[x]&&d[x].m(s,null);_(s,a),w&&w.m(s,null),_(e,c),_(e,l),Z(p,l,null),_(l,y),R[C].m(l,null),A=!0},p(u,[f]){if(u[0]&&u[0].type=="question_list"&&!u[1]?E?(E.p(u,f),f&3&&L(E,1)):(E=ar(u),E.c(),L(E,1),E.m(n,i)):E&&(je(),M(E,1,1,()=>{E=null}),Pe()),f&12){b=xe(u[2]);let j;for(j=0;j<b.length;j+=1){const k=ir(u,b,j);d[j]?(d[j].p(k,f),L(d[j],1)):(d[j]=br(k),d[j].c(),L(d[j],1),d[j].m(s,a))}for(je(),j=b.length;j<d.length;j+=1)m(j);Pe()}u[4]?w?f&16&&L(w,1):(w=vr(),w.c(),L(w,1),w.m(s,null)):w&&(je(),M(w,1,1,()=>{w=null}),Pe());let x=C;C=T(u),C===x?R[C].p(u,f):(je(),M(R[x],1,1,()=>{R[x]=null}),Pe(),S=R[C],S?S.p(u,f):(S=R[C]=q[C](u),S.c()),L(S,1),S.m(l,null))},i(u){if(!A){L(t.$$.fragment,u),L(E);for(let f=0;f<b.length;f+=1)L(d[f]);L(w),L(p.$$.fragment,u),L(S),A=!0}},o(u){M(t.$$.fragment,u),M(E),d=d.filter(Boolean);for(let f=0;f<d.length;f+=1)M(d[f]);M(w),M(p.$$.fragment,u),M(S),A=!1},d(u){u&&B(e),U(t),E&&E.d(),tt(d,u),w&&w.d(),U(p),R[C].d()}}}function xs(o,e,n){let t,r,i,s,a;return et(o,xn,A=>n(0,t=A)),et(o,cn,A=>n(1,r=A)),et(o,Ht,A=>n(2,i=A)),et(o,St,A=>n(3,s=A)),et(o,Zt,A=>n(4,a=A)),[t,r,i,s,a,A=>{To(A)},()=>{Eo()},()=>{Un()},()=>{Un()},A=>{Oo(A.error)},A=>A.type==="question_cache"?go(A.id):void 0]}class Ss extends we{constructor(e){super(),_e(this,e,xs,ks,ye,{})}}function Os(o){let e,n,t,r,i,s,a,c,l,p,y,C,S,A,E,b,d,m,w;return{c(){e=O("div"),n=O("div"),t=O("div"),r=O("div"),i=O("h3"),i.textContent="Are you sure?",s=F(),a=O("button"),a.innerHTML='<span class="sr-only">Close</span> <svg class="w-3.5 h-3.5" width="8" height="8" viewBox="0 0 8 8" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M0.258206 1.00652C0.351976 0.912791 0.479126 0.860131 0.611706 0.860131C0.744296 0.860131 0.871447 0.912791 0.965207 1.00652L3.61171 3.65302L6.25822 1.00652C6.30432 0.958771 6.35952 0.920671 6.42052 0.894471C6.48152 0.868271 6.54712 0.854471 6.61352 0.853901C6.67992 0.853321 6.74572 0.865971 6.80722 0.891111C6.86862 0.916251 6.92442 0.953381 6.97142 1.00032C7.01832 1.04727 7.05552 1.1031 7.08062 1.16454C7.10572 1.22599 7.11842 1.29183 7.11782 1.35822C7.11722 1.42461 7.10342 1.49022 7.07722 1.55122C7.05102 1.61222 7.01292 1.6674 6.96522 1.71352L4.31871 4.36002L6.96522 7.00648C7.05632 7.10078 7.10672 7.22708 7.10552 7.35818C7.10442 7.48928 7.05182 7.61468 6.95912 7.70738C6.86642 7.80018 6.74102 7.85268 6.60992 7.85388C6.47882 7.85498 6.35252 7.80458 6.25822 7.71348L3.61171 5.06702L0.965207 7.71348C0.870907 7.80458 0.744606 7.85498 0.613506 7.85388C0.482406 7.85268 0.357007 7.80018 0.264297 7.70738C0.171597 7.61468 0.119017 7.48928 0.117877 7.35818C0.116737 7.22708 0.167126 7.10078 0.258206 7.00648L2.90471 4.36002L0.258206 1.71352C0.164476 1.61976 0.111816 1.4926 0.111816 1.36002C0.111816 1.22744 0.164476 1.10028 0.258206 1.00652Z" fill="currentColor"></path></svg>',c=F(),l=O("div"),p=O("p"),y=ge(o[0]),C=F(),S=O("div"),A=O("button"),A.textContent="Close",E=F(),b=O("button"),d=ge(o[1]),g(i,"class","font-bold text-gray-800 dark:text-white"),g(a,"type","button"),g(a,"class","hs-dropdown-toggle inline-flex flex-shrink-0 justify-center items-center h-8 w-8 rounded-md text-gray-500 hover:text-gray-400 focus:outline-none focus:ring-2 focus:ring-gray-400 focus:ring-offset-2 focus:ring-offset-white transition-all text-sm dark:focus:ring-gray-700 dark:focus:ring-offset-gray-800"),g(a,"data-hs-overlay","#hs-vertically-centered-modal"),g(r,"class","flex justify-between items-center py-3 px-4 border-b dark:border-gray-700"),g(p,"class","text-gray-800 dark:text-gray-400"),g(l,"class","p-4 overflow-y-auto"),g(A,"type","button"),g(A,"class","hs-dropdown-toggle py-3 px-4 inline-flex justify-center items-center gap-2 rounded-md border font-medium bg-white text-gray-700 shadow-sm align-middle hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-offset-white focus:ring-blue-600 transition-all text-sm dark:bg-slate-900 dark:hover:bg-slate-800 dark:border-gray-700 dark:text-gray-400 dark:hover:text-white dark:focus:ring-offset-gray-800"),g(A,"data-hs-overlay","#hs-vertically-centered-modal"),g(b,"class","py-3 px-4 inline-flex justify-center items-center gap-2 rounded-md border border-transparent font-semibold bg-blue-500 text-white hover:bg-blue-600 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 transition-all text-sm dark:focus:ring-offset-gray-800"),g(S,"class","flex justify-end items-center gap-x-2 py-3 px-4 border-t dark:border-gray-700"),g(t,"class","flex flex-col bg-white border shadow-sm rounded-xl dark:bg-gray-800 dark:border-gray-700 dark:shadow-slate-700/[.7]"),g(n,"class","hs-overlay-open:mt-7 hs-overlay-open:opacity-100 hs-overlay-open:duration-500 mt-0 opacity-0 ease-out transition-all sm:max-w-lg sm:w-full m-3 sm:mx-auto min-h-[calc(100%-3.5rem)] flex items-center"),g(e,"class","hs-overlay open w-full h-full fixed top-0 left-0 z-[60] overflow-x-hidden overflow-y-auto")},m(q,R){N(q,e,R),_(e,n),_(n,t),_(t,r),_(r,i),_(r,s),_(r,a),_(t,c),_(t,l),_(l,p),_(p,y),_(t,C),_(t,S),_(S,A),_(S,E),_(S,b),_(b,d),m||(w=[Le(a,"click",function(){Mt(o[2])&&o[2].apply(this,arguments)}),Le(A,"click",function(){Mt(o[2])&&o[2].apply(this,arguments)}),Le(b,"click",function(){Mt(o[3])&&o[3].apply(this,arguments)})],m=!0)},p(q,[R]){o=q,R&1&&Ne(y,o[0]),R&2&&Ne(d,o[1])},i:K,o:K,d(q){q&&B(e),m=!1,gt(w)}}}function Cs(o,e,n){let{message:t}=e,{buttonLabel:r}=e,{onClose:i}=e,{onConfirm:s}=e;return o.$$set=a=>{"message"in a&&n(0,t=a.message),"buttonLabel"in a&&n(1,r=a.buttonLabel),"onClose"in a&&n(2,i=a.onClose),"onConfirm"in a&&n(3,s=a.onConfirm)},[t,r,i,s]}class Ls extends we{constructor(e){super(),_e(this,e,Cs,Os,ye,{message:0,buttonLabel:1,onClose:2,onConfirm:3})}}function $r(o,e,n){const t=o.slice();return t[10]=e[n].name,t[11]=e[n].description,t[12]=e[n].example,t}function kr(o){let e,n,t,r,i,s,a,c,l,p,y,C;return p=Xr(o[7][0]),{c(){e=O("div"),n=O("div"),t=O("input"),r=F(),i=O("label"),s=O("span"),s.textContent=`${o[10]}`,a=F(),c=O("span"),c.textContent=`${o[11]}`,l=F(),g(t,"id","hs-radio-"+o[10]),t.__value=o[10],mt(t,t.__value),g(t,"name","hs-radio-with-description"),g(t,"type","radio"),g(t,"class","border-gray-200 rounded-full text-blue-600 focus:ring-blue-500 dark:bg-gray-800 dark:border-gray-700 dark:checked:bg-blue-500 dark:checked:border-blue-500 dark:focus:ring-offset-gray-800"),g(t,"aria-describedby","hs-radio-delete-description"),g(n,"class","flex items-center h-5 mt-1"),g(s,"class","block text-sm font-semibold text-gray-800 dark:text-gray-300"),g(c,"id","hs-radio-ddl-description"),g(c,"class","block text-sm text-gray-600 dark:text-gray-500"),g(i,"for","hs-radio-"+o[10]),g(i,"class","ml-3"),g(e,"class","relative flex items-start"),p.p(t)},m(S,A){N(S,e,A),_(e,n),_(n,t),t.checked=t.__value===o[0],_(e,r),_(e,i),_(i,s),_(i,a),_(i,c),_(e,l),y||(C=Le(t,"change",o[6]),y=!0)},p(S,A){A&1&&(t.checked=t.__value===S[0])},d(S){S&&B(e),p.r(),y=!1,C()}}}function Es(o){let e,n,t,r,i,s,a,c,l,p,y,C,S,A,E,b,d,m,w,q,R,T,u,f,x,j=xe(o[3]),k=[];for(let P=0;P<j.length;P+=1)k[P]=kr($r(o,j,P));return{c(){var P;e=O("div"),n=O("div"),t=O("div"),r=O("div"),i=O("h2"),i.textContent="Add Training Data",s=F(),a=O("button"),a.innerHTML='<span class="sr-only">Close</span> <svg class="w-3.5 h-3.5" width="8" height="8" viewBox="0 0 8 8" fill="none" xmlns="http://www.w3.org/2000/svg"><path d="M0.258206 1.00652C0.351976 0.912791 0.479126 0.860131 0.611706 0.860131C0.744296 0.860131 0.871447 0.912791 0.965207 1.00652L3.61171 3.65302L6.25822 1.00652C6.30432 0.958771 6.35952 0.920671 6.42052 0.894471C6.48152 0.868271 6.54712 0.854471 6.61352 0.853901C6.67992 0.853321 6.74572 0.865971 6.80722 0.891111C6.86862 0.916251 6.92442 0.953381 6.97142 1.00032C7.01832 1.04727 7.05552 1.1031 7.08062 1.16454C7.10572 1.22599 7.11842 1.29183 7.11782 1.35822C7.11722 1.42461 7.10342 1.49022 7.07722 1.55122C7.05102 1.61222 7.01292 1.6674 6.96522 1.71352L4.31871 4.36002L6.96522 7.00648C7.05632 7.10078 7.10672 7.22708 7.10552 7.35818C7.10442 7.48928 7.05182 7.61468 6.95912 7.70738C6.86642 7.80018 6.74102 7.85268 6.60992 7.85388C6.47882 7.85498 6.35252 7.80458 6.25822 7.71348L3.61171 5.06702L0.965207 7.71348C0.870907 7.80458 0.744606 7.85498 0.613506 7.85388C0.482406 7.85268 0.357007 7.80018 0.264297 7.70738C0.171597 7.61468 0.119017 7.48928 0.117877 7.35818C0.116737 7.22708 0.167126 7.10078 0.258206 7.00648L2.90471 4.36002L0.258206 1.71352C0.164476 1.61976 0.111816 1.4926 0.111816 1.36002C0.111816 1.22744 0.164476 1.10028 0.258206 1.00652Z" fill="currentColor"></path></svg>',c=F(),l=O("span"),l.textContent="Training Data Type",p=F(),y=O("div");for(let H=0;H<k.length;H+=1)k[H].c();C=F(),S=O("div"),A=O("label"),E=ge("Your "),b=ge(o[0]),d=F(),m=O("div"),w=O("textarea"),R=F(),T=O("div"),u=O("button"),u.textContent="Save",g(i,"class","text-xl text-gray-800 font-bold sm:text-3xl dark:text-white"),g(a,"type","button"),g(a,"class","hs-dropdown-toggle inline-flex flex-shrink-0 justify-center items-center h-8 w-8 rounded-md text-gray-500 hover:text-gray-400 focus:outline-none focus:ring-2 focus:ring-gray-400 focus:ring-offset-2 focus:ring-offset-white transition-all text-sm dark:focus:ring-gray-700 dark:focus:ring-offset-gray-800"),g(a,"data-hs-overlay","#hs-vertically-centered-modal"),g(r,"class","flex justify-between items-center py-3 px-4 border-b dark:border-gray-700 mb-2"),g(l,"class","block mb-2 text-sm font-medium dark:text-white"),g(y,"class","grid space-y-3 mb-1"),g(A,"for","hs-feedback-post-comment-textarea-1"),g(A,"class","block mt-2 mb-2 text-sm font-medium dark:text-white"),g(w,"id","hs-feedback-post-comment-textarea-1"),g(w,"name","hs-feedback-post-comment-textarea-1"),g(w,"rows","3"),g(w,"class","py-3 px-4 block w-full border border-gray-200 rounded-md text-sm focus:border-blue-500 focus:ring-blue-500 sm:p-4 dark:bg-gray-800 dark:border-gray-700 dark:text-gray-400"),g(w,"placeholder",q=((P=o[3].find(o[8]))==null?void 0:P.example)??"No example available"),g(m,"class","mt-1"),g(S,"class","mt-2 border-t dark:border-gray-700"),g(u,"class","py-3 px-4 inline-flex justify-center items-center gap-2 rounded-md border border-transparent font-semibold bg-blue-500 text-white hover:bg-blue-600 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 transition-all dark:focus:ring-offset-gray-800"),g(T,"class","mt-6 grid"),g(t,"class","mt-5 p-4 relative z-10 bg-white border rounded-xl sm:mt-10 md:p-10 dark:bg-gray-800 dark:border-gray-700"),g(n,"class","mx-auto max-w-2xl"),g(e,"class","max-w-[85rem] px-4 py-10 sm:px-6 lg:px-8 lg:py-14 mx-auto")},m(P,H){N(P,e,H),_(e,n),_(n,t),_(t,r),_(r,i),_(r,s),_(r,a),_(t,c),_(t,l),_(t,p),_(t,y);for(let I=0;I<k.length;I+=1)k[I]&&k[I].m(y,null);_(t,C),_(t,S),_(S,A),_(A,E),_(A,b),_(S,d),_(S,m),_(m,w),mt(w,o[2]),_(t,R),_(t,T),_(T,u),f||(x=[Le(a,"click",function(){Mt(o[1])&&o[1].apply(this,arguments)}),Le(w,"input",o[9]),Le(u,"click",o[4])],f=!0)},p(P,[H]){var I;if(o=P,H&9){j=xe(o[3]);let W;for(W=0;W<j.length;W+=1){const J=$r(o,j,W);k[W]?k[W].p(J,H):(k[W]=kr(J),k[W].c(),k[W].m(y,null))}for(;W<k.length;W+=1)k[W].d(1);k.length=j.length}H&1&&Ne(b,o[0]),H&1&&q!==(q=((I=o[3].find(o[8]))==null?void 0:I.example)??"No example available")&&g(w,"placeholder",q),H&4&&mt(w,o[2])},i:K,o:K,d(P){P&&B(e),tt(k,P),f=!1,gt(x)}}}function Ts(o,e,n){let{onDismiss:t}=e,{onTrain:r}=e,{selectedTrainingDataType:i="SQL"}=e,s=[{name:"DDL",description:"These are the CREATE TABLE statements that define your database structure.",example:"CREATE TABLE table_name (column_1 datatype, column_2 datatype, column_3 datatype);"},{name:"Documentation",description:"This can be any text-based documentation. Keep the chunks small and focused on a single topic.",example:"Our definition of ABC is XYZ."},{name:"SQL",description:"This can be any SQL statement that works. The more the merrier.",example:"SELECT column_1, column_2 FROM table_name;"}],a="";const c=()=>{r(a,i.toLowerCase())},l=[[]];function p(){i=this.__value,n(0,i)}const y=S=>S.name===i;function C(){a=this.value,n(2,a)}return o.$$set=S=>{"onDismiss"in S&&n(1,t=S.onDismiss),"onTrain"in S&&n(5,r=S.onTrain),"selectedTrainingDataType"in S&&n(0,i=S.selectedTrainingDataType)},[i,t,a,s,c,r,p,l,y,C]}class js extends we{constructor(e){super(),_e(this,e,Ts,Es,ye,{onDismiss:1,onTrain:5,selectedTrainingDataType:0})}}function xr(o,e,n){const t=o.slice();return t[21]=e[n],t}function Sr(o,e,n){const t=o.slice();return t[24]=e[n],t}function Or(o,e,n){const t=o.slice();return t[24]=e[n],t}function Cr(o){let e,n;return e=new js({props:{onDismiss:o[13],onTrain:o[0]}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&1&&(i.onTrain=t[0]),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function Ps(o){let e;return{c(){e=ge("Action")},m(n,t){N(n,e,t)},p:K,d(n){n&&B(e)}}}function qs(o){let e=o[24]+"",n;return{c(){n=ge(e)},m(t,r){N(t,n,r)},p:K,d(t){t&&B(n)}}}function Lr(o){let e,n,t,r;function i(c,l){return c[24]!="id"?qs:Ps}let a=i(o)(o);return{c(){e=O("th"),n=O("div"),t=O("span"),a.c(),r=F(),g(t,"class","text-xs font-semibold uppercase tracking-wide text-gray-800 dark:text-gray-200"),g(n,"class","flex items-center gap-x-2"),g(e,"scope","col"),g(e,"class","px-6 py-3 text-left")},m(c,l){N(c,e,l),_(e,n),_(n,t),a.m(t,null),_(e,r)},p(c,l){a.p(c,l)},d(c){c&&B(e),a.d()}}}function As(o){let e,n,t;function r(){return o[18](o[21],o[24])}return{c(){e=O("button"),e.textContent="Delete",g(e,"type","button"),g(e,"class","py-2 px-3 inline-flex justify-center items-center gap-2 rounded-md border-2 border-red-200 font-semibold text-red-500 hover:text-white hover:bg-red-500 hover:border-red-500 focus:outline-none focus:ring-2 focus:ring-red-200 focus:ring-offset-2 transition-all text-sm dark:focus:ring-offset-gray-800")},m(i,s){N(i,e,s),n||(t=Le(e,"click",r),n=!0)},p(i,s){o=i},d(i){i&&B(e),n=!1,t()}}}function Ms(o){let e,n=o[21][o[24]]+"",t;return{c(){e=O("span"),t=ge(n),g(e,"class","text-gray-800 dark:text-gray-200")},m(r,i){N(r,e,i),_(e,t)},p(r,i){i&16&&n!==(n=r[21][r[24]]+"")&&Ne(t,n)},d(r){r&&B(e)}}}function Er(o){let e,n;function t(s,a){return s[24]!="id"?Ms:As}let i=t(o)(o);return{c(){e=O("td"),n=O("div"),i.c(),g(n,"class","px-6 py-3"),g(e,"class","h-px w-px ")},m(s,a){N(s,e,a),_(e,n),i.m(n,null)},p(s,a){i.p(s,a)},d(s){s&&B(e),i.d()}}}function Tr(o){let e,n,t=xe(o[8]),r=[];for(let i=0;i<t.length;i+=1)r[i]=Er(Sr(o,t,i));return{c(){e=O("tr");for(let i=0;i<r.length;i+=1)r[i].c();n=F()},m(i,s){N(i,e,s);for(let a=0;a<r.length;a+=1)r[a]&&r[a].m(e,null);_(e,n)},p(i,s){if(s&304){t=xe(i[8]);let a;for(a=0;a<t.length;a+=1){const c=Sr(i,t,a);r[a]?r[a].p(c,s):(r[a]=Er(c),r[a].c(),r[a].m(e,n))}for(;a<r.length;a+=1)r[a].d(1);r.length=t.length}},d(i){i&&B(e),tt(r,i)}}}function jr(o){let e,n;return e=new Ls({props:{message:"Are you sure you want to delete this?",buttonLabel:"Delete",onClose:o[19],onConfirm:o[20]}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&32&&(i.onClose=t[19]),r&34&&(i.onConfirm=t[20]),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function Ds(o){let e,n,t,r,i,s,a,c,l,p,y,C,S,A,E,b,d,m,w,q,R,T,u,f,x,j,k,P=o[2]+1+"",H,I,W=Math.min(o[3],o[7].length)+"",J,Oe,ae,rt,nt,Ge,Ue,ht,be,ft,Qe,yt,Bt,Nt,qe=o[6]&&Cr(o),bt=xe(o[8]),De=[];for(let ee=0;ee<bt.length;ee+=1)De[ee]=Lr(Or(o,bt,ee));let Ve=xe(o[4]),Ee=[];for(let ee=0;ee<Ve.length;ee+=1)Ee[ee]=Tr(xr(o,Ve,ee));let Te=o[5]!=null&&jr(o);return{c(){qe&&qe.c(),e=F(),n=O("div"),t=O("div"),r=O("div"),i=O("div"),s=O("div"),a=O("div"),c=O("div"),c.innerHTML='<h2 class="text-xl font-semibold text-gray-800 dark:text-gray-200">Training Data</h2> <p class="text-sm text-gray-600 dark:text-gray-400">Add or remove training data. Good training data is the key to accuracy.</p>',l=F(),p=O("div"),y=O("div"),C=O("button"),C.textContent="View all",S=F(),A=O("button"),A.innerHTML=`<svg class="w-3 h-3" xmlns="http://www.w3.org/2000/svg" width="16" height="16" viewBox="0 0 16 16" fill="none"><path d="M2.63452 7.50001L13.6345 7.5M8.13452 13V2" stroke="currentColor" stroke-width="2" stroke-linecap="round"></path></svg>
                    Add training data`,E=F(),b=O("table"),d=O("thead"),m=O("tr");for(let ee=0;ee<De.length;ee+=1)De[ee].c();w=F(),q=O("tbody");for(let ee=0;ee<Ee.length;ee+=1)Ee[ee].c();R=F(),T=O("div"),u=O("div"),f=O("p"),f.textContent="Showing:",x=F(),j=O("div"),k=O("span"),H=ge(P),I=ge(" - "),J=ge(W),Oe=F(),ae=O("p"),ae.textContent=`of ${o[7].length}`,rt=F(),nt=O("div"),Ge=O("div"),Ue=O("button"),Ue.innerHTML=`<svg class="w-3 h-3" xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" viewBox="0 0 16 16"><path fill-rule="evenodd" d="M11.354 1.646a.5.5 0 0 1 0 .708L5.707 8l5.647 5.646a.5.5 0 0 1-.708.708l-6-6a.5.5 0 0 1 0-.708l6-6a.5.5 0 0 1 .708 0z"></path></svg>
                    Prev`,ht=F(),be=O("button"),be.innerHTML=`Next
                    <svg class="w-3 h-3" xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" viewBox="0 0 16 16"><path fill-rule="evenodd" d="M4.646 1.646a.5.5 0 0 1 .708 0l6 6a.5.5 0 0 1 0 .708l-6 6a.5.5 0 0 1-.708-.708L10.293 8 4.646 2.354a.5.5 0 0 1 0-.708z"></path></svg>`,ft=F(),Te&&Te.c(),Qe=ze(),g(C,"class","py-2 px-3 inline-flex justify-center items-center gap-2 rounded-md border font-medium bg-white text-gray-700 shadow-sm align-middle hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-offset-white focus:ring-blue-600 transition-all text-sm dark:bg-slate-900 dark:hover:bg-slate-800 dark:border-gray-700 dark:text-gray-400 dark:hover:text-white dark:focus:ring-offset-gray-800"),g(A,"class","py-2 px-3 inline-flex justify-center items-center gap-2 rounded-md border border-transparent font-semibold bg-blue-500 text-white hover:bg-blue-600 focus:outline-none focus:ring-2 focus:ring-blue-500 focus:ring-offset-2 transition-all text-sm dark:focus:ring-offset-gray-800"),g(y,"class","inline-flex gap-x-2"),g(a,"class","px-6 py-4 grid gap-3 md:flex md:justify-between md:items-center border-b border-gray-200 dark:border-gray-700"),g(d,"class","bg-gray-50 dark:bg-slate-800"),g(q,"class","divide-y divide-gray-200 dark:divide-gray-700"),g(b,"class","min-w-full divide-y divide-gray-200 dark:divide-gray-700"),g(f,"class","text-sm text-gray-600 dark:text-gray-400"),g(k,"class","py-2 px-3 pr-9 block w-full border-gray-200 rounded-md text-sm focus:border-blue-500 focus:ring-blue-500 dark:bg-slate-900 dark:border-gray-700 dark:text-gray-400"),g(j,"class","max-w-sm space-y-3"),g(ae,"class","text-sm text-gray-600 dark:text-gray-400"),g(u,"class","inline-flex items-center gap-x-2"),g(Ue,"type","button"),g(Ue,"class","py-2 px-3 inline-flex justify-center items-center gap-2 rounded-md border font-medium bg-white text-gray-700 shadow-sm align-middle hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-offset-white focus:ring-blue-600 transition-all text-sm dark:bg-slate-900 dark:hover:bg-slate-800 dark:border-gray-700 dark:text-gray-400 dark:hover:text-white dark:focus:ring-offset-gray-800"),g(be,"type","button"),g(be,"class","py-2 px-3 inline-flex justify-center items-center gap-2 rounded-md border font-medium bg-white text-gray-700 shadow-sm align-middle hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-offset-white focus:ring-blue-600 transition-all text-sm dark:bg-slate-900 dark:hover:bg-slate-800 dark:border-gray-700 dark:text-gray-400 dark:hover:text-white dark:focus:ring-offset-gray-800"),g(Ge,"class","inline-flex gap-x-2"),g(T,"class","px-6 py-4 grid gap-3 md:flex md:justify-between md:items-center border-t border-gray-200 dark:border-gray-700"),g(s,"class","bg-white border border-gray-200 rounded-xl shadow-sm overflow-hidden dark:bg-slate-900 dark:border-gray-700"),g(i,"class","p-1.5 min-w-full inline-block align-middle"),g(r,"class","-m-1.5 overflow-x-auto"),g(t,"class","flex flex-col"),g(n,"class","max-w-[85rem] px-4 py-10 sm:px-6 lg:px-8 lg:py-14 mx-auto")},m(ee,He){qe&&qe.m(ee,He),N(ee,e,He),N(ee,n,He),_(n,t),_(t,r),_(r,i),_(i,s),_(s,a),_(a,c),_(a,l),_(a,p),_(p,y),_(y,C),_(y,S),_(y,A),_(s,E),_(s,b),_(b,d),_(d,m);for(let oe=0;oe<De.length;oe+=1)De[oe]&&De[oe].m(m,null);_(b,w),_(b,q);for(let oe=0;oe<Ee.length;oe+=1)Ee[oe]&&Ee[oe].m(q,null);_(s,R),_(s,T),_(T,u),_(u,f),_(u,x),_(u,j),_(j,k),_(k,H),_(k,I),_(k,J),_(u,Oe),_(u,ae),_(T,rt),_(T,nt),_(nt,Ge),_(Ge,Ue),_(Ge,ht),_(Ge,be),N(ee,ft,He),Te&&Te.m(ee,He),N(ee,Qe,He),yt=!0,Bt||(Nt=[Le(C,"click",o[11]),Le(A,"click",o[12]),Le(Ue,"click",o[9]),Le(be,"click",o[10])],Bt=!0)},p(ee,[He]){if(ee[6]?qe?(qe.p(ee,He),He&64&&L(qe,1)):(qe=Cr(ee),qe.c(),L(qe,1),qe.m(e.parentNode,e)):qe&&(je(),M(qe,1,1,()=>{qe=null}),Pe()),He&256){bt=xe(ee[8]);let oe;for(oe=0;oe<bt.length;oe+=1){const wt=Or(ee,bt,oe);De[oe]?De[oe].p(wt,He):(De[oe]=Lr(wt),De[oe].c(),De[oe].m(m,null))}for(;oe<De.length;oe+=1)De[oe].d(1);De.length=bt.length}if(He&304){Ve=xe(ee[4]);let oe;for(oe=0;oe<Ve.length;oe+=1){const wt=xr(ee,Ve,oe);Ee[oe]?Ee[oe].p(wt,He):(Ee[oe]=Tr(wt),Ee[oe].c(),Ee[oe].m(q,null))}for(;oe<Ee.length;oe+=1)Ee[oe].d(1);Ee.length=Ve.length}(!yt||He&4)&&P!==(P=ee[2]+1+"")&&Ne(H,P),(!yt||He&8)&&W!==(W=Math.min(ee[3],ee[7].length)+"")&&Ne(J,W),ee[5]!=null?Te?(Te.p(ee,He),He&32&&L(Te,1)):(Te=jr(ee),Te.c(),L(Te,1),Te.m(Qe.parentNode,Qe)):Te&&(je(),M(Te,1,1,()=>{Te=null}),Pe())},i(ee){yt||(L(qe),L(Te),yt=!0)},o(ee){M(qe),M(Te),yt=!1},d(ee){ee&&(B(e),B(n),B(ft),B(Qe)),qe&&qe.d(ee),tt(De,ee),tt(Ee,ee),Te&&Te.d(ee),Bt=!1,gt(Nt)}}}function Rs(o,e,n){let{df:t}=e,{onTrain:r}=e,{removeTrainingData:i}=e,s=JSON.parse(t),a=s.length>0?Object.keys(s[0]):[],c=10,l=1,p=Math.ceil(s.length/c),y=(l-1)*c,C=l*c,S=s.slice(y,C);const A=()=>{l>1&&n(16,l--,l)},E=()=>{l<p&&n(16,l++,l)},b=()=>{n(16,l=1),n(15,c=s.length)};let d=null,m=!1;const w=()=>{n(6,m=!0)},q=()=>{n(6,m=!1)},R=(f,x)=>{n(5,d=f[x])},T=()=>{n(5,d=null)},u=()=>{d&&i(d)};return o.$$set=f=>{"df"in f&&n(14,t=f.df),"onTrain"in f&&n(0,r=f.onTrain),"removeTrainingData"in f&&n(1,i=f.removeTrainingData)},o.$$.update=()=>{o.$$.dirty&98304&&n(2,y=(l-1)*c),o.$$.dirty&98304&&n(3,C=l*c),o.$$.dirty&12&&n(4,S=s.slice(y,C)),o.$$.dirty&32768&&n(17,p=Math.ceil(s.length/c)),o.$$.dirty&196608&&console.log(l,p)},[r,i,y,C,S,d,m,s,a,A,E,b,w,q,t,c,l,p,R,T,u]}class Hs extends we{constructor(e){super(),_e(this,e,Rs,Ds,ye,{df:14,onTrain:0,removeTrainingData:1})}}function Bs(o){let e;return{c(){e=O("div"),e.innerHTML='<div class="flex flex-auto flex-col justify-center items-center p-4 md:p-5"><div class="flex justify-center"><div class="animate-spin inline-block w-6 h-6 border-[3px] border-current border-t-transparent text-blue-600 rounded-full" role="status" aria-label="loading"><span class="sr-only">Loading...</span></div></div></div>',g(e,"class","min-h-[15rem] flex flex-col bg-white border shadow-sm rounded-xl dark:bg-gray-800 dark:border-gray-700 dark:shadow-slate-700/[.7]")},m(n,t){N(n,e,t)},p:K,i:K,o:K,d(n){n&&B(e)}}}function Ns(o){let e,n,t,r;const i=[zs,Is],s=[];function a(c,l){return c[0].type==="df"?0:c[0].type==="error"?1:-1}return~(e=a(o))&&(n=s[e]=i[e](o)),{c(){n&&n.c(),t=ze()},m(c,l){~e&&s[e].m(c,l),N(c,t,l),r=!0},p(c,l){let p=e;e=a(c),e===p?~e&&s[e].p(c,l):(n&&(je(),M(s[p],1,1,()=>{s[p]=null}),Pe()),~e?(n=s[e],n?n.p(c,l):(n=s[e]=i[e](c),n.c()),L(n,1),n.m(t.parentNode,t)):n=null)},i(c){r||(L(n),r=!0)},o(c){M(n),r=!1},d(c){c&&B(t),~e&&s[e].d(c)}}}function Is(o){let e,n;return e=new Cn({props:{message:o[0].error}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&1&&(i.message=t[0].error),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function zs(o){let e,n;return e=new Hs({props:{df:o[0].df,removeTrainingData:vo,onTrain:ko}}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},p(t,r){const i={};r&1&&(i.df=t[0].df),e.$set(i)},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function Vs(o){let e,n,t,r,i;const s=[Ns,Bs],a=[];function c(l,p){return l[0]!==null?0:1}return t=c(o),r=a[t]=s[t](o),{c(){e=O("div"),n=O("div"),r.c(),g(n,"class","py-10 lg:py-14"),g(e,"class","relative h-screen w-full lg:pl-64")},m(l,p){N(l,e,p),_(e,n),a[t].m(n,null),i=!0},p(l,[p]){let y=t;t=c(l),t===y?a[t].p(l,p):(je(),M(a[y],1,1,()=>{a[y]=null}),Pe(),r=a[t],r?r.p(l,p):(r=a[t]=s[t](l),r.c()),L(r,1),r.m(n,null))},i(l){i||(L(r),i=!0)},o(l){M(r),i=!1},d(l){l&&B(e),a[t].d()}}}function Gs(o,e,n){let t;return et(o,an,r=>n(0,t=r)),[t]}class Zs extends we{constructor(e){super(),_e(this,e,Gs,Vs,ye,{})}}function Us(o){let e;return{c(){e=O("body"),e.innerHTML=`<div class="max-w-[50rem] flex flex-col mx-auto size-full"><header class="mb-auto flex justify-center z-50 w-full py-4"><nav class="px-4 sm:px-6 lg:px-8" aria-label="Global"><span class="flex-none text-xl font-semibold sm:text-3xl dark:text-white">Vanna.AI</span></nav></header> <div class="text-center py-10 px-4 sm:px-6 lg:px-8"><h1 class="block text-7xl font-bold text-gray-800 sm:text-9xl dark:text-white">No Training Data</h1> <h1 class="block text-2xl font-bold text-white">Did you read the docs?</h1> <p class="mt-3 text-gray-600 dark:text-gray-400">Oops, something went wrong.</p> <p class="text-gray-600 dark:text-gray-400">You need some training data before you can use Vanna</p> <div class="mt-5 flex flex-col justify-center items-center gap-2 sm:flex-row sm:gap-3"><a class="w-full sm:w-auto py-3 px-4 inline-flex justify-center items-center gap-x-2 text-sm font-semibold rounded-lg border border-transparent bg-blue-600 text-white hover:bg-blue-700 disabled:opacity-50 disabled:pointer-events-none dark:focus:outline-none dark:focus:ring-1 dark:focus:ring-gray-600" href="https://github.com/htmlstreamofficial/preline/tree/main/examples/html" target="_blank"><svg class="flex-shrink-0 size-4" xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" viewBox="0 0 16 16"><path d="M8 0C3.58 0 0 3.58 0 8c0 3.54 2.29 6.53 5.47 7.59.4.07.55-.17.55-.38 0-.19-.01-.82-.01-1.49-2.01.37-2.53-.49-2.69-.94-.09-.23-.48-.94-.82-1.13-.28-.15-.68-.52-.01-.53.63-.01 1.08.58 1.23.82.72 1.21 1.87.87 2.33.66.07-.52.28-.87.51-1.07-1.78-.2-3.64-.89-3.64-3.95 0-.87.31-1.59.82-2.15-.08-.2-.36-1.02.08-2.12 0 0 .67-.21 2.2.82.64-.18 1.32-.27 2-.27.68 0 1.36.09 2 .27 1.53-1.04 2.2-.82 2.2-.82.44 1.1.16 1.92.08 2.12.51.56.82 1.27.82 2.15 0 3.07-1.87 3.75-3.65 3.95.29.25.54.73.54 1.48 0 1.07-.01 1.93-.01 2.2 0 .21.15.46.55.38A8.012 8.012 0 0 0 16 8c0-4.42-3.58-8-8-8z"></path></svg>
            Get the source code</a> <a class="w-full sm:w-auto py-3 px-4 inline-flex justify-center items-center gap-x-2 text-sm font-semibold rounded-lg border border-transparent text-blue-600 hover:text-blue-800 disabled:opacity-50 disabled:pointer-events-none dark:text-blue-500 dark:hover:text-blue-400 dark:focus:outline-none dark:focus:ring-1 dark:focus:ring-gray-600" href="../examples.html"><svg class="flex-shrink-0 size-4" xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><path d="m15 18-6-6 6-6"></path></svg>
            Back to examples</a></div></div> <footer class="mt-auto text-center py-5"><div class="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8"><p class="text-sm text-gray-500">© All Rights Reserved. 2022.</p></div></footer></div>`,g(e,"class","flex h-full")},m(n,t){N(n,e,t)},p:K,i:K,o:K,d(n){n&&B(e)}}}class Qs extends we{constructor(e){super(),_e(this,e,null,Us,ye,{})}}function Ws(o){let e,n;return e=new Qs({}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function Fs(o){let e,n;return e=new Zs({}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function Js(o){let e,n;return e=new Ss({}),{c(){Q(e.$$.fragment)},m(t,r){Z(e,t,r),n=!0},i(t){n||(L(e.$$.fragment,t),n=!0)},o(t){M(e.$$.fragment,t),n=!1},d(t){U(e,t)}}}function Ys(o){let e,n,t,r,i,s;n=new qo({});const a=[Js,Fs,Ws],c=[];function l(p,y){return p[0]==="chat"?0:p[0]==="training-data"?1:p[0]==="no-training-data"?2:-1}return~(r=l(o))&&(i=c[r]=a[r](o)),{c(){e=O("main"),Q(n.$$.fragment),t=F(),i&&i.c()},m(p,y){N(p,e,y),Z(n,e,null),_(e,t),~r&&c[r].m(e,null),s=!0},p(p,[y]){let C=r;r=l(p),r!==C&&(i&&(je(),M(c[C],1,1,()=>{c[C]=null}),Pe()),~r?(i=c[r],i||(i=c[r]=a[r](p),i.c()),L(i,1),i.m(e,null)):i=null)},i(p){s||(L(n.$$.fragment,p),L(i),s=!0)},o(p){M(n.$$.fragment,p),M(i),s=!1},d(p){p&&B(e),U(n),~r&&c[r].d()}}}function Ks(o,e,n){let t;return et(o,Wt,r=>n(0,t=r)),Mr(async()=>{yo(),ho(),new URL(window.location.href).hash.slice(1)==="training-data"?Hr():Br()}),[t]}class Xs extends we{constructor(e){super(),_e(this,e,Ks,Ys,ye,{})}}new Xs({target:document.getElementById("app")});
'''